#include <vxWorks.h>
#include <semLib.h>
#include "ellLib.h"
#include "fast_lock.h"
#include "link.h"
#include "tsDefs.h"

#ifndef INCpulseCounterSGVH
#define INCpulseCounterSGVH
typedef enum {
	pulseCounterSGV_Inactive,
	pulseCounterSGV_Active
}pulseCounterSGV;
#endif /*INCpulseCounterSGVH*/

#ifndef INCpulseCounterGTYPH
#define INCpulseCounterGTYPH
typedef enum {
	pulseCounterGTYP_Hardware,
	pulseCounterGTYP_Software
}pulseCounterGTYP;
#endif /*INCpulseCounterGTYPH*/

#ifndef INCpulseCounterCSIZH
#define INCpulseCounterCSIZH
typedef enum {
	pulseCounterCSIZ_16_bit,
	pulseCounterCSIZ_32_bit
}pulseCounterCSIZ;
#endif /*INCpulseCounterCSIZH*/

#ifndef INCpulseCounterCNTEH
#define INCpulseCounterCNTEH
typedef enum {
	pulseCounterCNTE_Rising_Edge,
	pulseCounterCNTE_Falling_Edge
}pulseCounterCNTE;
#endif /*INCpulseCounterCNTEH*/

#ifndef INCpulseCounterCMDH
#define INCpulseCounterCMDH
typedef enum {
	pulseCounterCMD_Read,
	pulseCounterCMD_Clear,
	pulseCounterCMD_Start,
	pulseCounterCMD_Stop,
	pulseCounterCMD_Setup
}pulseCounterCMD;
#endif /*INCpulseCounterCMDH*/
#ifndef INCpulseCounterH
#define INCpulseCounterH
typedef struct pulseCounterRecord {
	char		name[29]; /*Record Name*/
	char		desc[29]; /*Descriptor*/
	char		asg[29]; /*Access Security Group*/
	unsigned short	scan;	/*Scan Mechanism*/
	unsigned short	pini;	/*Process at iocInit*/
	short		phas;	/*Scan Phase*/
	short		evnt;	/*Event Number*/
	short		tse;	/*Time Stamp Event*/
	DBLINK		tsel;	/*Time Stamp Link*/
	unsigned short	dtyp;	/*Device Type*/
	short		disv;	/*Disable Value*/
	short		disa;	/*Disable*/
	DBLINK		sdis;	/*Scanning Disable*/
	FAST_LOCK	mlok;	/*Monitor fastlock*/
	ELLLIST		mlis;	/*Monitor List*/
	unsigned char	disp;	/*Disable putField*/
	unsigned char	proc;	/*Force Processing*/
	unsigned short	stat;	/*Alarm Status*/
	unsigned short	sevr;	/*Alarm Severity*/
	unsigned short	nsta;	/*New Alarm Status*/
	unsigned short	nsev;	/*New Alarm Severity*/
	unsigned short	acks;	/*Alarm Ack Severity*/
	unsigned short	ackt;	/*Alarm Ack Transient*/
	unsigned short	diss;	/*Disable Alarm Sevrty*/
	unsigned char	lcnt;	/*Lock Count*/
	unsigned char	pact;	/*Record active*/
	unsigned char	putf;	/*dbPutField process*/
	unsigned char	rpro;	/*Reprocess */
	void		*asp;	/*Access Security Pvt*/
	void		*ppn;	/*addr of PUTNOTIFY*/
	void		*ppnn;	/*next record PUTNOTIFY*/
	void		*spvt;	/*Scan Private*/
	void		*rset;	/*Address of RSET*/
	struct dset	*dset;	/*DSET address*/
	void		*dpvt;	/*Device Private*/
	void		*rdes;	/*Address of dbRecordType*/
	void		*lset;	/*Lock Set*/
	unsigned short	prio;	/*Scheduling Priority*/
	unsigned char	tpro;	/*Trace Processing*/
	char bkpt;	/*Break Point*/
	unsigned char	udf;	/*Undefined*/
	TS_STAMP	time;	/*Time*/
	DBLINK		flnk;	/*Forward Process Link*/
	unsigned long	val;	/*Counter Value*/
	DBLINK		out;	/*Output Specification*/
	unsigned short	gtyp;	/*Gate Type*/
	short		hgv;	/*Hardware Gate Value*/
	DBLINK		sgl;	/*Soft Gate Location*/
	unsigned short	sgv;	/*Soft Gate Value*/
	unsigned short	osgv;	/*Old Soft Gate Value*/
	unsigned short	csiz;	/*Counter Size*/
	unsigned short	cnte;	/*Counter Sounce Edge*/
	short		cnts;	/*Count Source*/
	float		hopr;	/*High Operating Range*/
	float		lopr;	/*Low Operating Range*/
	unsigned short	cmd;	/*Command*/
	unsigned short	scmd;	/*Save Command*/
	unsigned long	cptr;	/*Callback*/
} pulseCounterRecord;
#define pulseCounterRecordNAME	0
#define pulseCounterRecordDESC	1
#define pulseCounterRecordASG	2
#define pulseCounterRecordSCAN	3
#define pulseCounterRecordPINI	4
#define pulseCounterRecordPHAS	5
#define pulseCounterRecordEVNT	6
#define pulseCounterRecordTSE	7
#define pulseCounterRecordTSEL	8
#define pulseCounterRecordDTYP	9
#define pulseCounterRecordDISV	10
#define pulseCounterRecordDISA	11
#define pulseCounterRecordSDIS	12
#define pulseCounterRecordMLOK	13
#define pulseCounterRecordMLIS	14
#define pulseCounterRecordDISP	15
#define pulseCounterRecordPROC	16
#define pulseCounterRecordSTAT	17
#define pulseCounterRecordSEVR	18
#define pulseCounterRecordNSTA	19
#define pulseCounterRecordNSEV	20
#define pulseCounterRecordACKS	21
#define pulseCounterRecordACKT	22
#define pulseCounterRecordDISS	23
#define pulseCounterRecordLCNT	24
#define pulseCounterRecordPACT	25
#define pulseCounterRecordPUTF	26
#define pulseCounterRecordRPRO	27
#define pulseCounterRecordASP	28
#define pulseCounterRecordPPN	29
#define pulseCounterRecordPPNN	30
#define pulseCounterRecordSPVT	31
#define pulseCounterRecordRSET	32
#define pulseCounterRecordDSET	33
#define pulseCounterRecordDPVT	34
#define pulseCounterRecordRDES	35
#define pulseCounterRecordLSET	36
#define pulseCounterRecordPRIO	37
#define pulseCounterRecordTPRO	38
#define pulseCounterRecordBKPT	39
#define pulseCounterRecordUDF	40
#define pulseCounterRecordTIME	41
#define pulseCounterRecordFLNK	42
#define pulseCounterRecordVAL	43
#define pulseCounterRecordOUT	44
#define pulseCounterRecordGTYP	45
#define pulseCounterRecordHGV	46
#define pulseCounterRecordSGL	47
#define pulseCounterRecordSGV	48
#define pulseCounterRecordOSGV	49
#define pulseCounterRecordCSIZ	50
#define pulseCounterRecordCNTE	51
#define pulseCounterRecordCNTS	52
#define pulseCounterRecordHOPR	53
#define pulseCounterRecordLOPR	54
#define pulseCounterRecordCMD	55
#define pulseCounterRecordSCMD	56
#define pulseCounterRecordCPTR	57
#endif /*INCpulseCounterH*/
#ifdef GEN_SIZE_OFFSET
int pulseCounterRecordSizeOffset(dbRecordType *pdbRecordType)
{
    pulseCounterRecord *prec = 0;
  pdbRecordType->papFldDes[0]->size=sizeof(prec->name);
  pdbRecordType->papFldDes[0]->offset=(short)((char *)&prec->name - (char *)prec);
  pdbRecordType->papFldDes[1]->size=sizeof(prec->desc);
  pdbRecordType->papFldDes[1]->offset=(short)((char *)&prec->desc - (char *)prec);
  pdbRecordType->papFldDes[2]->size=sizeof(prec->asg);
  pdbRecordType->papFldDes[2]->offset=(short)((char *)&prec->asg - (char *)prec);
  pdbRecordType->papFldDes[3]->size=sizeof(prec->scan);
  pdbRecordType->papFldDes[3]->offset=(short)((char *)&prec->scan - (char *)prec);
  pdbRecordType->papFldDes[4]->size=sizeof(prec->pini);
  pdbRecordType->papFldDes[4]->offset=(short)((char *)&prec->pini - (char *)prec);
  pdbRecordType->papFldDes[5]->size=sizeof(prec->phas);
  pdbRecordType->papFldDes[5]->offset=(short)((char *)&prec->phas - (char *)prec);
  pdbRecordType->papFldDes[6]->size=sizeof(prec->evnt);
  pdbRecordType->papFldDes[6]->offset=(short)((char *)&prec->evnt - (char *)prec);
  pdbRecordType->papFldDes[7]->size=sizeof(prec->tse);
  pdbRecordType->papFldDes[7]->offset=(short)((char *)&prec->tse - (char *)prec);
  pdbRecordType->papFldDes[8]->size=sizeof(prec->tsel);
  pdbRecordType->papFldDes[8]->offset=(short)((char *)&prec->tsel - (char *)prec);
  pdbRecordType->papFldDes[9]->size=sizeof(prec->dtyp);
  pdbRecordType->papFldDes[9]->offset=(short)((char *)&prec->dtyp - (char *)prec);
  pdbRecordType->papFldDes[10]->size=sizeof(prec->disv);
  pdbRecordType->papFldDes[10]->offset=(short)((char *)&prec->disv - (char *)prec);
  pdbRecordType->papFldDes[11]->size=sizeof(prec->disa);
  pdbRecordType->papFldDes[11]->offset=(short)((char *)&prec->disa - (char *)prec);
  pdbRecordType->papFldDes[12]->size=sizeof(prec->sdis);
  pdbRecordType->papFldDes[12]->offset=(short)((char *)&prec->sdis - (char *)prec);
  pdbRecordType->papFldDes[13]->size=sizeof(prec->mlok);
  pdbRecordType->papFldDes[13]->offset=(short)((char *)&prec->mlok - (char *)prec);
  pdbRecordType->papFldDes[14]->size=sizeof(prec->mlis);
  pdbRecordType->papFldDes[14]->offset=(short)((char *)&prec->mlis - (char *)prec);
  pdbRecordType->papFldDes[15]->size=sizeof(prec->disp);
  pdbRecordType->papFldDes[15]->offset=(short)((char *)&prec->disp - (char *)prec);
  pdbRecordType->papFldDes[16]->size=sizeof(prec->proc);
  pdbRecordType->papFldDes[16]->offset=(short)((char *)&prec->proc - (char *)prec);
  pdbRecordType->papFldDes[17]->size=sizeof(prec->stat);
  pdbRecordType->papFldDes[17]->offset=(short)((char *)&prec->stat - (char *)prec);
  pdbRecordType->papFldDes[18]->size=sizeof(prec->sevr);
  pdbRecordType->papFldDes[18]->offset=(short)((char *)&prec->sevr - (char *)prec);
  pdbRecordType->papFldDes[19]->size=sizeof(prec->nsta);
  pdbRecordType->papFldDes[19]->offset=(short)((char *)&prec->nsta - (char *)prec);
  pdbRecordType->papFldDes[20]->size=sizeof(prec->nsev);
  pdbRecordType->papFldDes[20]->offset=(short)((char *)&prec->nsev - (char *)prec);
  pdbRecordType->papFldDes[21]->size=sizeof(prec->acks);
  pdbRecordType->papFldDes[21]->offset=(short)((char *)&prec->acks - (char *)prec);
  pdbRecordType->papFldDes[22]->size=sizeof(prec->ackt);
  pdbRecordType->papFldDes[22]->offset=(short)((char *)&prec->ackt - (char *)prec);
  pdbRecordType->papFldDes[23]->size=sizeof(prec->diss);
  pdbRecordType->papFldDes[23]->offset=(short)((char *)&prec->diss - (char *)prec);
  pdbRecordType->papFldDes[24]->size=sizeof(prec->lcnt);
  pdbRecordType->papFldDes[24]->offset=(short)((char *)&prec->lcnt - (char *)prec);
  pdbRecordType->papFldDes[25]->size=sizeof(prec->pact);
  pdbRecordType->papFldDes[25]->offset=(short)((char *)&prec->pact - (char *)prec);
  pdbRecordType->papFldDes[26]->size=sizeof(prec->putf);
  pdbRecordType->papFldDes[26]->offset=(short)((char *)&prec->putf - (char *)prec);
  pdbRecordType->papFldDes[27]->size=sizeof(prec->rpro);
  pdbRecordType->papFldDes[27]->offset=(short)((char *)&prec->rpro - (char *)prec);
  pdbRecordType->papFldDes[28]->size=sizeof(prec->asp);
  pdbRecordType->papFldDes[28]->offset=(short)((char *)&prec->asp - (char *)prec);
  pdbRecordType->papFldDes[29]->size=sizeof(prec->ppn);
  pdbRecordType->papFldDes[29]->offset=(short)((char *)&prec->ppn - (char *)prec);
  pdbRecordType->papFldDes[30]->size=sizeof(prec->ppnn);
  pdbRecordType->papFldDes[30]->offset=(short)((char *)&prec->ppnn - (char *)prec);
  pdbRecordType->papFldDes[31]->size=sizeof(prec->spvt);
  pdbRecordType->papFldDes[31]->offset=(short)((char *)&prec->spvt - (char *)prec);
  pdbRecordType->papFldDes[32]->size=sizeof(prec->rset);
  pdbRecordType->papFldDes[32]->offset=(short)((char *)&prec->rset - (char *)prec);
  pdbRecordType->papFldDes[33]->size=sizeof(prec->dset);
  pdbRecordType->papFldDes[33]->offset=(short)((char *)&prec->dset - (char *)prec);
  pdbRecordType->papFldDes[34]->size=sizeof(prec->dpvt);
  pdbRecordType->papFldDes[34]->offset=(short)((char *)&prec->dpvt - (char *)prec);
  pdbRecordType->papFldDes[35]->size=sizeof(prec->rdes);
  pdbRecordType->papFldDes[35]->offset=(short)((char *)&prec->rdes - (char *)prec);
  pdbRecordType->papFldDes[36]->size=sizeof(prec->lset);
  pdbRecordType->papFldDes[36]->offset=(short)((char *)&prec->lset - (char *)prec);
  pdbRecordType->papFldDes[37]->size=sizeof(prec->prio);
  pdbRecordType->papFldDes[37]->offset=(short)((char *)&prec->prio - (char *)prec);
  pdbRecordType->papFldDes[38]->size=sizeof(prec->tpro);
  pdbRecordType->papFldDes[38]->offset=(short)((char *)&prec->tpro - (char *)prec);
  pdbRecordType->papFldDes[39]->size=sizeof(prec->bkpt);
  pdbRecordType->papFldDes[39]->offset=(short)((char *)&prec->bkpt - (char *)prec);
  pdbRecordType->papFldDes[40]->size=sizeof(prec->udf);
  pdbRecordType->papFldDes[40]->offset=(short)((char *)&prec->udf - (char *)prec);
  pdbRecordType->papFldDes[41]->size=sizeof(prec->time);
  pdbRecordType->papFldDes[41]->offset=(short)((char *)&prec->time - (char *)prec);
  pdbRecordType->papFldDes[42]->size=sizeof(prec->flnk);
  pdbRecordType->papFldDes[42]->offset=(short)((char *)&prec->flnk - (char *)prec);
  pdbRecordType->papFldDes[43]->size=sizeof(prec->val);
  pdbRecordType->papFldDes[43]->offset=(short)((char *)&prec->val - (char *)prec);
  pdbRecordType->papFldDes[44]->size=sizeof(prec->out);
  pdbRecordType->papFldDes[44]->offset=(short)((char *)&prec->out - (char *)prec);
  pdbRecordType->papFldDes[45]->size=sizeof(prec->gtyp);
  pdbRecordType->papFldDes[45]->offset=(short)((char *)&prec->gtyp - (char *)prec);
  pdbRecordType->papFldDes[46]->size=sizeof(prec->hgv);
  pdbRecordType->papFldDes[46]->offset=(short)((char *)&prec->hgv - (char *)prec);
  pdbRecordType->papFldDes[47]->size=sizeof(prec->sgl);
  pdbRecordType->papFldDes[47]->offset=(short)((char *)&prec->sgl - (char *)prec);
  pdbRecordType->papFldDes[48]->size=sizeof(prec->sgv);
  pdbRecordType->papFldDes[48]->offset=(short)((char *)&prec->sgv - (char *)prec);
  pdbRecordType->papFldDes[49]->size=sizeof(prec->osgv);
  pdbRecordType->papFldDes[49]->offset=(short)((char *)&prec->osgv - (char *)prec);
  pdbRecordType->papFldDes[50]->size=sizeof(prec->csiz);
  pdbRecordType->papFldDes[50]->offset=(short)((char *)&prec->csiz - (char *)prec);
  pdbRecordType->papFldDes[51]->size=sizeof(prec->cnte);
  pdbRecordType->papFldDes[51]->offset=(short)((char *)&prec->cnte - (char *)prec);
  pdbRecordType->papFldDes[52]->size=sizeof(prec->cnts);
  pdbRecordType->papFldDes[52]->offset=(short)((char *)&prec->cnts - (char *)prec);
  pdbRecordType->papFldDes[53]->size=sizeof(prec->hopr);
  pdbRecordType->papFldDes[53]->offset=(short)((char *)&prec->hopr - (char *)prec);
  pdbRecordType->papFldDes[54]->size=sizeof(prec->lopr);
  pdbRecordType->papFldDes[54]->offset=(short)((char *)&prec->lopr - (char *)prec);
  pdbRecordType->papFldDes[55]->size=sizeof(prec->cmd);
  pdbRecordType->papFldDes[55]->offset=(short)((char *)&prec->cmd - (char *)prec);
  pdbRecordType->papFldDes[56]->size=sizeof(prec->scmd);
  pdbRecordType->papFldDes[56]->offset=(short)((char *)&prec->scmd - (char *)prec);
  pdbRecordType->papFldDes[57]->size=sizeof(prec->cptr);
  pdbRecordType->papFldDes[57]->offset=(short)((char *)&prec->cptr - (char *)prec);
    pdbRecordType->rec_size = sizeof(*prec);
    return(0);
}
#endif /*GEN_SIZE_OFFSET*/
