#include <vxWorks.h>
#include <semLib.h>
#include "ellLib.h"
#include "fast_lock.h"
#include "link.h"
#include "tsDefs.h"

#ifndef INCpulseDelayVALH
#define INCpulseDelayVALH
typedef enum {
	pulseDelayVAL_Inactive,
	pulseDelayVAL_Active
}pulseDelayVAL;
#endif /*INCpulseDelayVALH*/

#ifndef INCpulseDelayUNITH
#define INCpulseDelayUNITH
typedef enum {
	pulseDelayUNIT_Seconds,
	pulseDelayUNIT_Milliseconds,
	pulseDelayUNIT_Microseconds,
	pulseDelayUNIT_Nanoseconds,
	pulseDelayUNIT_Picoseconds
}pulseDelayUNIT;
#endif /*INCpulseDelayUNITH*/

#ifndef INCpulseDelayTTYPH
#define INCpulseDelayTTYPH
typedef enum {
	pulseDelayTTYP_Hardware,
	pulseDelayTTYP_Software
}pulseDelayTTYP;
#endif /*INCpulseDelayTTYPH*/

#ifndef INCpulseDelaySTVH
#define INCpulseDelaySTVH
typedef enum {
	pulseDelaySTV_Disable,
	pulseDelaySTV_Enable
}pulseDelaySTV;
#endif /*INCpulseDelaySTVH*/

#ifndef INCpulseDelayLLOWH
#define INCpulseDelayLLOWH
typedef enum {
	pulseDelayLLOW_Logic_Low_0,
	pulseDelayLLOW_Logic_Low_1
}pulseDelayLLOW;
#endif /*INCpulseDelayLLOWH*/

#ifndef INCpulseDelayCTYPH
#define INCpulseDelayCTYPH
typedef enum {
	pulseDelayCTYP_Internal,
	pulseDelayCTYP_External
}pulseDelayCTYP;
#endif /*INCpulseDelayCTYPH*/

#ifndef INCpulseDelayCEDGH
#define INCpulseDelayCEDGH
typedef enum {
	pulseDelayCEDG_Rising_Edge,
	pulseDelayCEDG_Falling_Edge
}pulseDelayCEDG;
#endif /*INCpulseDelayCEDGH*/
#ifndef INCpulseDelayH
#define INCpulseDelayH
typedef struct pulseDelayRecord {
	char		name[29]; /*Record Name*/
	char		desc[29]; /*Descriptor*/
	char		asg[29]; /*Access Security Group*/
	unsigned short	scan;	/*Scan Mechanism*/
	unsigned short	pini;	/*Process at iocInit*/
	short		phas;	/*Scan Phase*/
	short		evnt;	/*Event Number*/
	short		tse;	/*Time Stamp Event*/
	DBLINK		tsel;	/*Time Stamp Link*/
	unsigned short	dtyp;	/*Device Type*/
	short		disv;	/*Disable Value*/
	short		disa;	/*Disable*/
	DBLINK		sdis;	/*Scanning Disable*/
	FAST_LOCK	mlok;	/*Monitor fastlock*/
	ELLLIST		mlis;	/*Monitor List*/
	unsigned char	disp;	/*Disable putField*/
	unsigned char	proc;	/*Force Processing*/
	unsigned short	stat;	/*Alarm Status*/
	unsigned short	sevr;	/*Alarm Severity*/
	unsigned short	nsta;	/*New Alarm Status*/
	unsigned short	nsev;	/*New Alarm Severity*/
	unsigned short	acks;	/*Alarm Ack Severity*/
	unsigned short	ackt;	/*Alarm Ack Transient*/
	unsigned short	diss;	/*Disable Alarm Sevrty*/
	unsigned char	lcnt;	/*Lock Count*/
	unsigned char	pact;	/*Record active*/
	unsigned char	putf;	/*dbPutField process*/
	unsigned char	rpro;	/*Reprocess */
	void		*asp;	/*Access Security Pvt*/
	void		*ppn;	/*addr of PUTNOTIFY*/
	void		*ppnn;	/*next record PUTNOTIFY*/
	void		*spvt;	/*Scan Private*/
	void		*rset;	/*Address of RSET*/
	struct dset	*dset;	/*DSET address*/
	void		*dpvt;	/*Device Private*/
	void		*rdes;	/*Address of dbRecordType*/
	void		*lset;	/*Lock Set*/
	unsigned short	prio;	/*Scheduling Priority*/
	unsigned char	tpro;	/*Trace Processing*/
	char bkpt;	/*Break Point*/
	unsigned char	udf;	/*Undefined*/
	TS_STAMP	time;	/*Time*/
	DBLINK		flnk;	/*Forward Process Link*/
	DBLINK		out;	/*Output Specification*/
	unsigned short	unit;	/*Delay Time Units*/
	double		dly;	/*Pulse Delay*/
	double		wide;	/*Pulse Width*/
	double		odly;	/*Old Pulse Delay*/
	double		owid;	/*Old Pulse Width*/
	unsigned short	ctyp;	/*Clock Type*/
	unsigned short	cedg;	/*Clock Signal Edge*/
	short		ecs;	/*Ext Clock Source*/
	double		ecr;	/*Ext Clock Rate (HZ)*/
	unsigned short	llow;	/*Low Logic Level*/
	unsigned short	val;	/*Trigger Detect*/
	unsigned short	ttyp;	/*Trigger Type*/
	unsigned short	hts;	/*Hardware Trigger Src*/
	DBLINK		stl;	/*Soft Trigger Location*/
	unsigned short	stv;	/*Soft Trigger Value*/
	DBLINK		glnk;	/*Soft Gate Location*/
	unsigned short	gate;	/*Soft Gate Value*/
	float		hopr;	/*High Operating Range*/
	float		lopr;	/*Low Operating Range*/
	short		prec;	/*Display Precision*/
	unsigned short	pfld;	/*Field Processing*/
} pulseDelayRecord;
#define pulseDelayRecordNAME	0
#define pulseDelayRecordDESC	1
#define pulseDelayRecordASG	2
#define pulseDelayRecordSCAN	3
#define pulseDelayRecordPINI	4
#define pulseDelayRecordPHAS	5
#define pulseDelayRecordEVNT	6
#define pulseDelayRecordTSE	7
#define pulseDelayRecordTSEL	8
#define pulseDelayRecordDTYP	9
#define pulseDelayRecordDISV	10
#define pulseDelayRecordDISA	11
#define pulseDelayRecordSDIS	12
#define pulseDelayRecordMLOK	13
#define pulseDelayRecordMLIS	14
#define pulseDelayRecordDISP	15
#define pulseDelayRecordPROC	16
#define pulseDelayRecordSTAT	17
#define pulseDelayRecordSEVR	18
#define pulseDelayRecordNSTA	19
#define pulseDelayRecordNSEV	20
#define pulseDelayRecordACKS	21
#define pulseDelayRecordACKT	22
#define pulseDelayRecordDISS	23
#define pulseDelayRecordLCNT	24
#define pulseDelayRecordPACT	25
#define pulseDelayRecordPUTF	26
#define pulseDelayRecordRPRO	27
#define pulseDelayRecordASP	28
#define pulseDelayRecordPPN	29
#define pulseDelayRecordPPNN	30
#define pulseDelayRecordSPVT	31
#define pulseDelayRecordRSET	32
#define pulseDelayRecordDSET	33
#define pulseDelayRecordDPVT	34
#define pulseDelayRecordRDES	35
#define pulseDelayRecordLSET	36
#define pulseDelayRecordPRIO	37
#define pulseDelayRecordTPRO	38
#define pulseDelayRecordBKPT	39
#define pulseDelayRecordUDF	40
#define pulseDelayRecordTIME	41
#define pulseDelayRecordFLNK	42
#define pulseDelayRecordOUT	43
#define pulseDelayRecordUNIT	44
#define pulseDelayRecordDLY	45
#define pulseDelayRecordWIDE	46
#define pulseDelayRecordODLY	47
#define pulseDelayRecordOWID	48
#define pulseDelayRecordCTYP	49
#define pulseDelayRecordCEDG	50
#define pulseDelayRecordECS	51
#define pulseDelayRecordECR	52
#define pulseDelayRecordLLOW	53
#define pulseDelayRecordVAL	54
#define pulseDelayRecordTTYP	55
#define pulseDelayRecordHTS	56
#define pulseDelayRecordSTL	57
#define pulseDelayRecordSTV	58
#define pulseDelayRecordGLNK	59
#define pulseDelayRecordGATE	60
#define pulseDelayRecordHOPR	61
#define pulseDelayRecordLOPR	62
#define pulseDelayRecordPREC	63
#define pulseDelayRecordPFLD	64
#endif /*INCpulseDelayH*/
#ifdef GEN_SIZE_OFFSET
int pulseDelayRecordSizeOffset(dbRecordType *pdbRecordType)
{
    pulseDelayRecord *prec = 0;
  pdbRecordType->papFldDes[0]->size=sizeof(prec->name);
  pdbRecordType->papFldDes[0]->offset=(short)((char *)&prec->name - (char *)prec);
  pdbRecordType->papFldDes[1]->size=sizeof(prec->desc);
  pdbRecordType->papFldDes[1]->offset=(short)((char *)&prec->desc - (char *)prec);
  pdbRecordType->papFldDes[2]->size=sizeof(prec->asg);
  pdbRecordType->papFldDes[2]->offset=(short)((char *)&prec->asg - (char *)prec);
  pdbRecordType->papFldDes[3]->size=sizeof(prec->scan);
  pdbRecordType->papFldDes[3]->offset=(short)((char *)&prec->scan - (char *)prec);
  pdbRecordType->papFldDes[4]->size=sizeof(prec->pini);
  pdbRecordType->papFldDes[4]->offset=(short)((char *)&prec->pini - (char *)prec);
  pdbRecordType->papFldDes[5]->size=sizeof(prec->phas);
  pdbRecordType->papFldDes[5]->offset=(short)((char *)&prec->phas - (char *)prec);
  pdbRecordType->papFldDes[6]->size=sizeof(prec->evnt);
  pdbRecordType->papFldDes[6]->offset=(short)((char *)&prec->evnt - (char *)prec);
  pdbRecordType->papFldDes[7]->size=sizeof(prec->tse);
  pdbRecordType->papFldDes[7]->offset=(short)((char *)&prec->tse - (char *)prec);
  pdbRecordType->papFldDes[8]->size=sizeof(prec->tsel);
  pdbRecordType->papFldDes[8]->offset=(short)((char *)&prec->tsel - (char *)prec);
  pdbRecordType->papFldDes[9]->size=sizeof(prec->dtyp);
  pdbRecordType->papFldDes[9]->offset=(short)((char *)&prec->dtyp - (char *)prec);
  pdbRecordType->papFldDes[10]->size=sizeof(prec->disv);
  pdbRecordType->papFldDes[10]->offset=(short)((char *)&prec->disv - (char *)prec);
  pdbRecordType->papFldDes[11]->size=sizeof(prec->disa);
  pdbRecordType->papFldDes[11]->offset=(short)((char *)&prec->disa - (char *)prec);
  pdbRecordType->papFldDes[12]->size=sizeof(prec->sdis);
  pdbRecordType->papFldDes[12]->offset=(short)((char *)&prec->sdis - (char *)prec);
  pdbRecordType->papFldDes[13]->size=sizeof(prec->mlok);
  pdbRecordType->papFldDes[13]->offset=(short)((char *)&prec->mlok - (char *)prec);
  pdbRecordType->papFldDes[14]->size=sizeof(prec->mlis);
  pdbRecordType->papFldDes[14]->offset=(short)((char *)&prec->mlis - (char *)prec);
  pdbRecordType->papFldDes[15]->size=sizeof(prec->disp);
  pdbRecordType->papFldDes[15]->offset=(short)((char *)&prec->disp - (char *)prec);
  pdbRecordType->papFldDes[16]->size=sizeof(prec->proc);
  pdbRecordType->papFldDes[16]->offset=(short)((char *)&prec->proc - (char *)prec);
  pdbRecordType->papFldDes[17]->size=sizeof(prec->stat);
  pdbRecordType->papFldDes[17]->offset=(short)((char *)&prec->stat - (char *)prec);
  pdbRecordType->papFldDes[18]->size=sizeof(prec->sevr);
  pdbRecordType->papFldDes[18]->offset=(short)((char *)&prec->sevr - (char *)prec);
  pdbRecordType->papFldDes[19]->size=sizeof(prec->nsta);
  pdbRecordType->papFldDes[19]->offset=(short)((char *)&prec->nsta - (char *)prec);
  pdbRecordType->papFldDes[20]->size=sizeof(prec->nsev);
  pdbRecordType->papFldDes[20]->offset=(short)((char *)&prec->nsev - (char *)prec);
  pdbRecordType->papFldDes[21]->size=sizeof(prec->acks);
  pdbRecordType->papFldDes[21]->offset=(short)((char *)&prec->acks - (char *)prec);
  pdbRecordType->papFldDes[22]->size=sizeof(prec->ackt);
  pdbRecordType->papFldDes[22]->offset=(short)((char *)&prec->ackt - (char *)prec);
  pdbRecordType->papFldDes[23]->size=sizeof(prec->diss);
  pdbRecordType->papFldDes[23]->offset=(short)((char *)&prec->diss - (char *)prec);
  pdbRecordType->papFldDes[24]->size=sizeof(prec->lcnt);
  pdbRecordType->papFldDes[24]->offset=(short)((char *)&prec->lcnt - (char *)prec);
  pdbRecordType->papFldDes[25]->size=sizeof(prec->pact);
  pdbRecordType->papFldDes[25]->offset=(short)((char *)&prec->pact - (char *)prec);
  pdbRecordType->papFldDes[26]->size=sizeof(prec->putf);
  pdbRecordType->papFldDes[26]->offset=(short)((char *)&prec->putf - (char *)prec);
  pdbRecordType->papFldDes[27]->size=sizeof(prec->rpro);
  pdbRecordType->papFldDes[27]->offset=(short)((char *)&prec->rpro - (char *)prec);
  pdbRecordType->papFldDes[28]->size=sizeof(prec->asp);
  pdbRecordType->papFldDes[28]->offset=(short)((char *)&prec->asp - (char *)prec);
  pdbRecordType->papFldDes[29]->size=sizeof(prec->ppn);
  pdbRecordType->papFldDes[29]->offset=(short)((char *)&prec->ppn - (char *)prec);
  pdbRecordType->papFldDes[30]->size=sizeof(prec->ppnn);
  pdbRecordType->papFldDes[30]->offset=(short)((char *)&prec->ppnn - (char *)prec);
  pdbRecordType->papFldDes[31]->size=sizeof(prec->spvt);
  pdbRecordType->papFldDes[31]->offset=(short)((char *)&prec->spvt - (char *)prec);
  pdbRecordType->papFldDes[32]->size=sizeof(prec->rset);
  pdbRecordType->papFldDes[32]->offset=(short)((char *)&prec->rset - (char *)prec);
  pdbRecordType->papFldDes[33]->size=sizeof(prec->dset);
  pdbRecordType->papFldDes[33]->offset=(short)((char *)&prec->dset - (char *)prec);
  pdbRecordType->papFldDes[34]->size=sizeof(prec->dpvt);
  pdbRecordType->papFldDes[34]->offset=(short)((char *)&prec->dpvt - (char *)prec);
  pdbRecordType->papFldDes[35]->size=sizeof(prec->rdes);
  pdbRecordType->papFldDes[35]->offset=(short)((char *)&prec->rdes - (char *)prec);
  pdbRecordType->papFldDes[36]->size=sizeof(prec->lset);
  pdbRecordType->papFldDes[36]->offset=(short)((char *)&prec->lset - (char *)prec);
  pdbRecordType->papFldDes[37]->size=sizeof(prec->prio);
  pdbRecordType->papFldDes[37]->offset=(short)((char *)&prec->prio - (char *)prec);
  pdbRecordType->papFldDes[38]->size=sizeof(prec->tpro);
  pdbRecordType->papFldDes[38]->offset=(short)((char *)&prec->tpro - (char *)prec);
  pdbRecordType->papFldDes[39]->size=sizeof(prec->bkpt);
  pdbRecordType->papFldDes[39]->offset=(short)((char *)&prec->bkpt - (char *)prec);
  pdbRecordType->papFldDes[40]->size=sizeof(prec->udf);
  pdbRecordType->papFldDes[40]->offset=(short)((char *)&prec->udf - (char *)prec);
  pdbRecordType->papFldDes[41]->size=sizeof(prec->time);
  pdbRecordType->papFldDes[41]->offset=(short)((char *)&prec->time - (char *)prec);
  pdbRecordType->papFldDes[42]->size=sizeof(prec->flnk);
  pdbRecordType->papFldDes[42]->offset=(short)((char *)&prec->flnk - (char *)prec);
  pdbRecordType->papFldDes[43]->size=sizeof(prec->out);
  pdbRecordType->papFldDes[43]->offset=(short)((char *)&prec->out - (char *)prec);
  pdbRecordType->papFldDes[44]->size=sizeof(prec->unit);
  pdbRecordType->papFldDes[44]->offset=(short)((char *)&prec->unit - (char *)prec);
  pdbRecordType->papFldDes[45]->size=sizeof(prec->dly);
  pdbRecordType->papFldDes[45]->offset=(short)((char *)&prec->dly - (char *)prec);
  pdbRecordType->papFldDes[46]->size=sizeof(prec->wide);
  pdbRecordType->papFldDes[46]->offset=(short)((char *)&prec->wide - (char *)prec);
  pdbRecordType->papFldDes[47]->size=sizeof(prec->odly);
  pdbRecordType->papFldDes[47]->offset=(short)((char *)&prec->odly - (char *)prec);
  pdbRecordType->papFldDes[48]->size=sizeof(prec->owid);
  pdbRecordType->papFldDes[48]->offset=(short)((char *)&prec->owid - (char *)prec);
  pdbRecordType->papFldDes[49]->size=sizeof(prec->ctyp);
  pdbRecordType->papFldDes[49]->offset=(short)((char *)&prec->ctyp - (char *)prec);
  pdbRecordType->papFldDes[50]->size=sizeof(prec->cedg);
  pdbRecordType->papFldDes[50]->offset=(short)((char *)&prec->cedg - (char *)prec);
  pdbRecordType->papFldDes[51]->size=sizeof(prec->ecs);
  pdbRecordType->papFldDes[51]->offset=(short)((char *)&prec->ecs - (char *)prec);
  pdbRecordType->papFldDes[52]->size=sizeof(prec->ecr);
  pdbRecordType->papFldDes[52]->offset=(short)((char *)&prec->ecr - (char *)prec);
  pdbRecordType->papFldDes[53]->size=sizeof(prec->llow);
  pdbRecordType->papFldDes[53]->offset=(short)((char *)&prec->llow - (char *)prec);
  pdbRecordType->papFldDes[54]->size=sizeof(prec->val);
  pdbRecordType->papFldDes[54]->offset=(short)((char *)&prec->val - (char *)prec);
  pdbRecordType->papFldDes[55]->size=sizeof(prec->ttyp);
  pdbRecordType->papFldDes[55]->offset=(short)((char *)&prec->ttyp - (char *)prec);
  pdbRecordType->papFldDes[56]->size=sizeof(prec->hts);
  pdbRecordType->papFldDes[56]->offset=(short)((char *)&prec->hts - (char *)prec);
  pdbRecordType->papFldDes[57]->size=sizeof(prec->stl);
  pdbRecordType->papFldDes[57]->offset=(short)((char *)&prec->stl - (char *)prec);
  pdbRecordType->papFldDes[58]->size=sizeof(prec->stv);
  pdbRecordType->papFldDes[58]->offset=(short)((char *)&prec->stv - (char *)prec);
  pdbRecordType->papFldDes[59]->size=sizeof(prec->glnk);
  pdbRecordType->papFldDes[59]->offset=(short)((char *)&prec->glnk - (char *)prec);
  pdbRecordType->papFldDes[60]->size=sizeof(prec->gate);
  pdbRecordType->papFldDes[60]->offset=(short)((char *)&prec->gate - (char *)prec);
  pdbRecordType->papFldDes[61]->size=sizeof(prec->hopr);
  pdbRecordType->papFldDes[61]->offset=(short)((char *)&prec->hopr - (char *)prec);
  pdbRecordType->papFldDes[62]->size=sizeof(prec->lopr);
  pdbRecordType->papFldDes[62]->offset=(short)((char *)&prec->lopr - (char *)prec);
  pdbRecordType->papFldDes[63]->size=sizeof(prec->prec);
  pdbRecordType->papFldDes[63]->offset=(short)((char *)&prec->prec - (char *)prec);
  pdbRecordType->papFldDes[64]->size=sizeof(prec->pfld);
  pdbRecordType->papFldDes[64]->offset=(short)((char *)&prec->pfld - (char *)prec);
    pdbRecordType->rec_size = sizeof(*prec);
    return(0);
}
#endif /*GEN_SIZE_OFFSET*/
