#include <vxWorks.h>
#include <semLib.h>
#include "ellLib.h"
#include "fast_lock.h"
#include "link.h"
#include "tsDefs.h"

#ifndef INCpulseTrainUNITH
#define INCpulseTrainUNITH
typedef enum {
	pulseTrainUNIT_Seconds,
	pulseTrainUNIT_Milliseconds,
	pulseTrainUNIT_Microseconds,
	pulseTrainUNIT_Nanoseconds,
	pulseTrainUNIT_Picoseconds
}pulseTrainUNIT;
#endif /*INCpulseTrainUNITH*/

#ifndef INCpulseTrainSGVH
#define INCpulseTrainSGVH
typedef enum {
	pulseTrainSGV_Inactive,
	pulseTrainSGV_Active
}pulseTrainSGV;
#endif /*INCpulseTrainSGVH*/

#ifndef INCpulseTrainLLOWH
#define INCpulseTrainLLOWH
typedef enum {
	pulseTrainLLOW_Logic_Low_0,
	pulseTrainLLOW_Logic_Low_1
}pulseTrainLLOW;
#endif /*INCpulseTrainLLOWH*/

#ifndef INCpulseTrainGTYPH
#define INCpulseTrainGTYPH
typedef enum {
	pulseTrainGTYP_Hardware,
	pulseTrainGTYP_Software
}pulseTrainGTYP;
#endif /*INCpulseTrainGTYPH*/

#ifndef INCpulseTrainCTYPH
#define INCpulseTrainCTYPH
typedef enum {
	pulseTrainCTYP_Internal,
	pulseTrainCTYP_External
}pulseTrainCTYP;
#endif /*INCpulseTrainCTYPH*/

#ifndef INCpulseTrainCEDGH
#define INCpulseTrainCEDGH
typedef enum {
	pulseTrainCEDG_Rising_Edge,
	pulseTrainCEDG_Falling_Edge
}pulseTrainCEDG;
#endif /*INCpulseTrainCEDGH*/
#ifndef INCpulseTrainH
#define INCpulseTrainH
typedef struct pulseTrainRecord {
	char		name[29]; /*Record Name*/
	char		desc[29]; /*Descriptor*/
	char		asg[29]; /*Access Security Group*/
	unsigned short	scan;	/*Scan Mechanism*/
	unsigned short	pini;	/*Process at iocInit*/
	short		phas;	/*Scan Phase*/
	short		evnt;	/*Event Number*/
	short		tse;	/*Time Stamp Event*/
	DBLINK		tsel;	/*Time Stamp Link*/
	unsigned short	dtyp;	/*Device Type*/
	short		disv;	/*Disable Value*/
	short		disa;	/*Disable*/
	DBLINK		sdis;	/*Scanning Disable*/
	FAST_LOCK	mlok;	/*Monitor fastlock*/
	ELLLIST		mlis;	/*Monitor List*/
	unsigned char	disp;	/*Disable putField*/
	unsigned char	proc;	/*Force Processing*/
	unsigned short	stat;	/*Alarm Status*/
	unsigned short	sevr;	/*Alarm Severity*/
	unsigned short	nsta;	/*New Alarm Status*/
	unsigned short	nsev;	/*New Alarm Severity*/
	unsigned short	acks;	/*Alarm Ack Severity*/
	unsigned short	ackt;	/*Alarm Ack Transient*/
	unsigned short	diss;	/*Disable Alarm Sevrty*/
	unsigned char	lcnt;	/*Lock Count*/
	unsigned char	pact;	/*Record active*/
	unsigned char	putf;	/*dbPutField process*/
	unsigned char	rpro;	/*Reprocess */
	void		*asp;	/*Access Security Pvt*/
	void		*ppn;	/*addr of PUTNOTIFY*/
	void		*ppnn;	/*next record PUTNOTIFY*/
	void		*spvt;	/*Scan Private*/
	void		*rset;	/*Address of RSET*/
	struct dset	*dset;	/*DSET address*/
	void		*dpvt;	/*Device Private*/
	void		*rdes;	/*Address of dbRecordType*/
	void		*lset;	/*Lock Set*/
	unsigned short	prio;	/*Scheduling Priority*/
	unsigned char	tpro;	/*Trace Processing*/
	char bkpt;	/*Break Point*/
	unsigned char	udf;	/*Undefined*/
	TS_STAMP	time;	/*Time*/
	DBLINK		flnk;	/*Forward Process Link*/
	DBLINK		out;	/*Output Specification*/
	unsigned short	unit;	/*Delay Time Units*/
	double		per;	/*Pulse Period*/
	double		dcy;	/*Duty Cycle %*/
	double		oper;	/*Old pulse Period*/
	double		odcy;	/*Old duty Cycle %*/
	unsigned short	gtyp;	/*Gate Type*/
	short		hgv;	/*Hardware Gate Value*/
	unsigned short	sgv;	/*Soft Gate Value*/
	DBLINK		sgl;	/*Soft Gate Location*/
	unsigned short	osgv;	/*Old Soft Gate Value*/
	short		val;	/*Not Used*/
	unsigned short	ctyp;	/*Clock Type*/
	unsigned short	cedg;	/*Clock Signal Edge*/
	short		ecs;	/*Ext Clock Source*/
	double		ecr;	/*Ext Clock Rate (HZ)*/
	float		hopr;	/*High Operating Range*/
	float		lopr;	/*Low Operating Range*/
	short		prec;	/*Display Precision*/
	unsigned short	llow;	/*Low Logic Level*/
} pulseTrainRecord;
#define pulseTrainRecordNAME	0
#define pulseTrainRecordDESC	1
#define pulseTrainRecordASG	2
#define pulseTrainRecordSCAN	3
#define pulseTrainRecordPINI	4
#define pulseTrainRecordPHAS	5
#define pulseTrainRecordEVNT	6
#define pulseTrainRecordTSE	7
#define pulseTrainRecordTSEL	8
#define pulseTrainRecordDTYP	9
#define pulseTrainRecordDISV	10
#define pulseTrainRecordDISA	11
#define pulseTrainRecordSDIS	12
#define pulseTrainRecordMLOK	13
#define pulseTrainRecordMLIS	14
#define pulseTrainRecordDISP	15
#define pulseTrainRecordPROC	16
#define pulseTrainRecordSTAT	17
#define pulseTrainRecordSEVR	18
#define pulseTrainRecordNSTA	19
#define pulseTrainRecordNSEV	20
#define pulseTrainRecordACKS	21
#define pulseTrainRecordACKT	22
#define pulseTrainRecordDISS	23
#define pulseTrainRecordLCNT	24
#define pulseTrainRecordPACT	25
#define pulseTrainRecordPUTF	26
#define pulseTrainRecordRPRO	27
#define pulseTrainRecordASP	28
#define pulseTrainRecordPPN	29
#define pulseTrainRecordPPNN	30
#define pulseTrainRecordSPVT	31
#define pulseTrainRecordRSET	32
#define pulseTrainRecordDSET	33
#define pulseTrainRecordDPVT	34
#define pulseTrainRecordRDES	35
#define pulseTrainRecordLSET	36
#define pulseTrainRecordPRIO	37
#define pulseTrainRecordTPRO	38
#define pulseTrainRecordBKPT	39
#define pulseTrainRecordUDF	40
#define pulseTrainRecordTIME	41
#define pulseTrainRecordFLNK	42
#define pulseTrainRecordOUT	43
#define pulseTrainRecordUNIT	44
#define pulseTrainRecordPER	45
#define pulseTrainRecordDCY	46
#define pulseTrainRecordOPER	47
#define pulseTrainRecordODCY	48
#define pulseTrainRecordGTYP	49
#define pulseTrainRecordHGV	50
#define pulseTrainRecordSGV	51
#define pulseTrainRecordSGL	52
#define pulseTrainRecordOSGV	53
#define pulseTrainRecordVAL	54
#define pulseTrainRecordCTYP	55
#define pulseTrainRecordCEDG	56
#define pulseTrainRecordECS	57
#define pulseTrainRecordECR	58
#define pulseTrainRecordHOPR	59
#define pulseTrainRecordLOPR	60
#define pulseTrainRecordPREC	61
#define pulseTrainRecordLLOW	62
#endif /*INCpulseTrainH*/
#ifdef GEN_SIZE_OFFSET
int pulseTrainRecordSizeOffset(dbRecordType *pdbRecordType)
{
    pulseTrainRecord *prec = 0;
  pdbRecordType->papFldDes[0]->size=sizeof(prec->name);
  pdbRecordType->papFldDes[0]->offset=(short)((char *)&prec->name - (char *)prec);
  pdbRecordType->papFldDes[1]->size=sizeof(prec->desc);
  pdbRecordType->papFldDes[1]->offset=(short)((char *)&prec->desc - (char *)prec);
  pdbRecordType->papFldDes[2]->size=sizeof(prec->asg);
  pdbRecordType->papFldDes[2]->offset=(short)((char *)&prec->asg - (char *)prec);
  pdbRecordType->papFldDes[3]->size=sizeof(prec->scan);
  pdbRecordType->papFldDes[3]->offset=(short)((char *)&prec->scan - (char *)prec);
  pdbRecordType->papFldDes[4]->size=sizeof(prec->pini);
  pdbRecordType->papFldDes[4]->offset=(short)((char *)&prec->pini - (char *)prec);
  pdbRecordType->papFldDes[5]->size=sizeof(prec->phas);
  pdbRecordType->papFldDes[5]->offset=(short)((char *)&prec->phas - (char *)prec);
  pdbRecordType->papFldDes[6]->size=sizeof(prec->evnt);
  pdbRecordType->papFldDes[6]->offset=(short)((char *)&prec->evnt - (char *)prec);
  pdbRecordType->papFldDes[7]->size=sizeof(prec->tse);
  pdbRecordType->papFldDes[7]->offset=(short)((char *)&prec->tse - (char *)prec);
  pdbRecordType->papFldDes[8]->size=sizeof(prec->tsel);
  pdbRecordType->papFldDes[8]->offset=(short)((char *)&prec->tsel - (char *)prec);
  pdbRecordType->papFldDes[9]->size=sizeof(prec->dtyp);
  pdbRecordType->papFldDes[9]->offset=(short)((char *)&prec->dtyp - (char *)prec);
  pdbRecordType->papFldDes[10]->size=sizeof(prec->disv);
  pdbRecordType->papFldDes[10]->offset=(short)((char *)&prec->disv - (char *)prec);
  pdbRecordType->papFldDes[11]->size=sizeof(prec->disa);
  pdbRecordType->papFldDes[11]->offset=(short)((char *)&prec->disa - (char *)prec);
  pdbRecordType->papFldDes[12]->size=sizeof(prec->sdis);
  pdbRecordType->papFldDes[12]->offset=(short)((char *)&prec->sdis - (char *)prec);
  pdbRecordType->papFldDes[13]->size=sizeof(prec->mlok);
  pdbRecordType->papFldDes[13]->offset=(short)((char *)&prec->mlok - (char *)prec);
  pdbRecordType->papFldDes[14]->size=sizeof(prec->mlis);
  pdbRecordType->papFldDes[14]->offset=(short)((char *)&prec->mlis - (char *)prec);
  pdbRecordType->papFldDes[15]->size=sizeof(prec->disp);
  pdbRecordType->papFldDes[15]->offset=(short)((char *)&prec->disp - (char *)prec);
  pdbRecordType->papFldDes[16]->size=sizeof(prec->proc);
  pdbRecordType->papFldDes[16]->offset=(short)((char *)&prec->proc - (char *)prec);
  pdbRecordType->papFldDes[17]->size=sizeof(prec->stat);
  pdbRecordType->papFldDes[17]->offset=(short)((char *)&prec->stat - (char *)prec);
  pdbRecordType->papFldDes[18]->size=sizeof(prec->sevr);
  pdbRecordType->papFldDes[18]->offset=(short)((char *)&prec->sevr - (char *)prec);
  pdbRecordType->papFldDes[19]->size=sizeof(prec->nsta);
  pdbRecordType->papFldDes[19]->offset=(short)((char *)&prec->nsta - (char *)prec);
  pdbRecordType->papFldDes[20]->size=sizeof(prec->nsev);
  pdbRecordType->papFldDes[20]->offset=(short)((char *)&prec->nsev - (char *)prec);
  pdbRecordType->papFldDes[21]->size=sizeof(prec->acks);
  pdbRecordType->papFldDes[21]->offset=(short)((char *)&prec->acks - (char *)prec);
  pdbRecordType->papFldDes[22]->size=sizeof(prec->ackt);
  pdbRecordType->papFldDes[22]->offset=(short)((char *)&prec->ackt - (char *)prec);
  pdbRecordType->papFldDes[23]->size=sizeof(prec->diss);
  pdbRecordType->papFldDes[23]->offset=(short)((char *)&prec->diss - (char *)prec);
  pdbRecordType->papFldDes[24]->size=sizeof(prec->lcnt);
  pdbRecordType->papFldDes[24]->offset=(short)((char *)&prec->lcnt - (char *)prec);
  pdbRecordType->papFldDes[25]->size=sizeof(prec->pact);
  pdbRecordType->papFldDes[25]->offset=(short)((char *)&prec->pact - (char *)prec);
  pdbRecordType->papFldDes[26]->size=sizeof(prec->putf);
  pdbRecordType->papFldDes[26]->offset=(short)((char *)&prec->putf - (char *)prec);
  pdbRecordType->papFldDes[27]->size=sizeof(prec->rpro);
  pdbRecordType->papFldDes[27]->offset=(short)((char *)&prec->rpro - (char *)prec);
  pdbRecordType->papFldDes[28]->size=sizeof(prec->asp);
  pdbRecordType->papFldDes[28]->offset=(short)((char *)&prec->asp - (char *)prec);
  pdbRecordType->papFldDes[29]->size=sizeof(prec->ppn);
  pdbRecordType->papFldDes[29]->offset=(short)((char *)&prec->ppn - (char *)prec);
  pdbRecordType->papFldDes[30]->size=sizeof(prec->ppnn);
  pdbRecordType->papFldDes[30]->offset=(short)((char *)&prec->ppnn - (char *)prec);
  pdbRecordType->papFldDes[31]->size=sizeof(prec->spvt);
  pdbRecordType->papFldDes[31]->offset=(short)((char *)&prec->spvt - (char *)prec);
  pdbRecordType->papFldDes[32]->size=sizeof(prec->rset);
  pdbRecordType->papFldDes[32]->offset=(short)((char *)&prec->rset - (char *)prec);
  pdbRecordType->papFldDes[33]->size=sizeof(prec->dset);
  pdbRecordType->papFldDes[33]->offset=(short)((char *)&prec->dset - (char *)prec);
  pdbRecordType->papFldDes[34]->size=sizeof(prec->dpvt);
  pdbRecordType->papFldDes[34]->offset=(short)((char *)&prec->dpvt - (char *)prec);
  pdbRecordType->papFldDes[35]->size=sizeof(prec->rdes);
  pdbRecordType->papFldDes[35]->offset=(short)((char *)&prec->rdes - (char *)prec);
  pdbRecordType->papFldDes[36]->size=sizeof(prec->lset);
  pdbRecordType->papFldDes[36]->offset=(short)((char *)&prec->lset - (char *)prec);
  pdbRecordType->papFldDes[37]->size=sizeof(prec->prio);
  pdbRecordType->papFldDes[37]->offset=(short)((char *)&prec->prio - (char *)prec);
  pdbRecordType->papFldDes[38]->size=sizeof(prec->tpro);
  pdbRecordType->papFldDes[38]->offset=(short)((char *)&prec->tpro - (char *)prec);
  pdbRecordType->papFldDes[39]->size=sizeof(prec->bkpt);
  pdbRecordType->papFldDes[39]->offset=(short)((char *)&prec->bkpt - (char *)prec);
  pdbRecordType->papFldDes[40]->size=sizeof(prec->udf);
  pdbRecordType->papFldDes[40]->offset=(short)((char *)&prec->udf - (char *)prec);
  pdbRecordType->papFldDes[41]->size=sizeof(prec->time);
  pdbRecordType->papFldDes[41]->offset=(short)((char *)&prec->time - (char *)prec);
  pdbRecordType->papFldDes[42]->size=sizeof(prec->flnk);
  pdbRecordType->papFldDes[42]->offset=(short)((char *)&prec->flnk - (char *)prec);
  pdbRecordType->papFldDes[43]->size=sizeof(prec->out);
  pdbRecordType->papFldDes[43]->offset=(short)((char *)&prec->out - (char *)prec);
  pdbRecordType->papFldDes[44]->size=sizeof(prec->unit);
  pdbRecordType->papFldDes[44]->offset=(short)((char *)&prec->unit - (char *)prec);
  pdbRecordType->papFldDes[45]->size=sizeof(prec->per);
  pdbRecordType->papFldDes[45]->offset=(short)((char *)&prec->per - (char *)prec);
  pdbRecordType->papFldDes[46]->size=sizeof(prec->dcy);
  pdbRecordType->papFldDes[46]->offset=(short)((char *)&prec->dcy - (char *)prec);
  pdbRecordType->papFldDes[47]->size=sizeof(prec->oper);
  pdbRecordType->papFldDes[47]->offset=(short)((char *)&prec->oper - (char *)prec);
  pdbRecordType->papFldDes[48]->size=sizeof(prec->odcy);
  pdbRecordType->papFldDes[48]->offset=(short)((char *)&prec->odcy - (char *)prec);
  pdbRecordType->papFldDes[49]->size=sizeof(prec->gtyp);
  pdbRecordType->papFldDes[49]->offset=(short)((char *)&prec->gtyp - (char *)prec);
  pdbRecordType->papFldDes[50]->size=sizeof(prec->hgv);
  pdbRecordType->papFldDes[50]->offset=(short)((char *)&prec->hgv - (char *)prec);
  pdbRecordType->papFldDes[51]->size=sizeof(prec->sgv);
  pdbRecordType->papFldDes[51]->offset=(short)((char *)&prec->sgv - (char *)prec);
  pdbRecordType->papFldDes[52]->size=sizeof(prec->sgl);
  pdbRecordType->papFldDes[52]->offset=(short)((char *)&prec->sgl - (char *)prec);
  pdbRecordType->papFldDes[53]->size=sizeof(prec->osgv);
  pdbRecordType->papFldDes[53]->offset=(short)((char *)&prec->osgv - (char *)prec);
  pdbRecordType->papFldDes[54]->size=sizeof(prec->val);
  pdbRecordType->papFldDes[54]->offset=(short)((char *)&prec->val - (char *)prec);
  pdbRecordType->papFldDes[55]->size=sizeof(prec->ctyp);
  pdbRecordType->papFldDes[55]->offset=(short)((char *)&prec->ctyp - (char *)prec);
  pdbRecordType->papFldDes[56]->size=sizeof(prec->cedg);
  pdbRecordType->papFldDes[56]->offset=(short)((char *)&prec->cedg - (char *)prec);
  pdbRecordType->papFldDes[57]->size=sizeof(prec->ecs);
  pdbRecordType->papFldDes[57]->offset=(short)((char *)&prec->ecs - (char *)prec);
  pdbRecordType->papFldDes[58]->size=sizeof(prec->ecr);
  pdbRecordType->papFldDes[58]->offset=(short)((char *)&prec->ecr - (char *)prec);
  pdbRecordType->papFldDes[59]->size=sizeof(prec->hopr);
  pdbRecordType->papFldDes[59]->offset=(short)((char *)&prec->hopr - (char *)prec);
  pdbRecordType->papFldDes[60]->size=sizeof(prec->lopr);
  pdbRecordType->papFldDes[60]->offset=(short)((char *)&prec->lopr - (char *)prec);
  pdbRecordType->papFldDes[61]->size=sizeof(prec->prec);
  pdbRecordType->papFldDes[61]->offset=(short)((char *)&prec->prec - (char *)prec);
  pdbRecordType->papFldDes[62]->size=sizeof(prec->llow);
  pdbRecordType->papFldDes[62]->offset=(short)((char *)&prec->llow - (char *)prec);
    pdbRecordType->rec_size = sizeof(*prec);
    return(0);
}
#endif /*GEN_SIZE_OFFSET*/
