#include <vxWorks.h>
#include <semLib.h>
#include "ellLib.h"
#include "fast_lock.h"
#include "link.h"
#include "tsDefs.h"

#ifndef INCscanPASMH
#define INCscanPASMH
typedef enum {
	scanPASM_Stay,
	scanPASM_Start_Pos,
	scanPASM_Prior_Pos
}scanPASM;
#endif /*INCscanPASMH*/

#ifndef INCscanP1SMH
#define INCscanP1SMH
typedef enum {
	scanP1SM_Linear,
	scanP1SM_Table,
	scanP1SM_On_The_Fly
}scanP1SM;
#endif /*INCscanP1SMH*/

#ifndef INCscanP1NVH
#define INCscanP1NVH
typedef enum {
	scanP1NV_PV_OK,
	scanP1NV_PV_BAD,
	scanP1NV_No_PV
}scanP1NV;
#endif /*INCscanP1NVH*/

#ifndef INCscanP1ARH
#define INCscanP1ARH
typedef enum {
	scanP1AR_Absolute,
	scanP1AR_Relative
}scanP1AR;
#endif /*INCscanP1ARH*/

#ifndef INCscanFPTSH
#define INCscanFPTSH
typedef enum {
	scanFPTS_No,
	scanFPTS_Freeze
}scanFPTS;
#endif /*INCscanFPTSH*/

#ifndef INCscanFFOH
#define INCscanFFOH
typedef enum {
	scanFFO_Use_F_Flags,
	scanFFO_Override
}scanFFO;
#endif /*INCscanFFOH*/
#ifndef INCscanH
#define INCscanH
typedef struct scanRecord {
	char		name[29]; /*Record Name*/
	char		desc[29]; /*Descriptor*/
	char		asg[29]; /*Access Security Group*/
	unsigned short	scan;	/*Scan Mechanism*/
	unsigned short	pini;	/*Process at iocInit*/
	short		phas;	/*Scan Phase*/
	short		evnt;	/*Event Number*/
	short		tse;	/*Time Stamp Event*/
	DBLINK		tsel;	/*Time Stamp Link*/
	unsigned short	dtyp;	/*Device Type*/
	short		disv;	/*Disable Value*/
	short		disa;	/*Disable*/
	DBLINK		sdis;	/*Scanning Disable*/
	FAST_LOCK	mlok;	/*Monitor fastlock*/
	ELLLIST		mlis;	/*Monitor List*/
	unsigned char	disp;	/*Disable putField*/
	unsigned char	proc;	/*Force Processing*/
	unsigned short	stat;	/*Alarm Status*/
	unsigned short	sevr;	/*Alarm Severity*/
	unsigned short	nsta;	/*New Alarm Status*/
	unsigned short	nsev;	/*New Alarm Severity*/
	unsigned short	acks;	/*Alarm Ack Severity*/
	unsigned short	ackt;	/*Alarm Ack Transient*/
	unsigned short	diss;	/*Disable Alarm Sevrty*/
	unsigned char	lcnt;	/*Lock Count*/
	unsigned char	pact;	/*Record active*/
	unsigned char	putf;	/*dbPutField process*/
	unsigned char	rpro;	/*Reprocess */
	void		*asp;	/*Access Security Pvt*/
	void		*ppn;	/*addr of PUTNOTIFY*/
	void		*ppnn;	/*next record PUTNOTIFY*/
	void		*spvt;	/*Scan Private*/
	void		*rset;	/*Address of RSET*/
	struct dset	*dset;	/*DSET address*/
	void		*dpvt;	/*Device Private*/
	void		*rdes;	/*Address of dbRecordType*/
	void		*lset;	/*Lock Set*/
	unsigned short	prio;	/*Scheduling Priority*/
	unsigned char	tpro;	/*Trace Processing*/
	char bkpt;	/*Break Point*/
	unsigned char	udf;	/*Undefined*/
	TS_STAMP	time;	/*Time*/
	DBLINK		flnk;	/*Forward Process Link*/
	double		vers;	/*Code Version*/
	double		val;	/*Value Field*/
	char		smsg[40]; /*Record State Msg*/
	unsigned short	cmnd;	/*Command Field*/
	unsigned char	alrt;	/*Operator Alert*/
	void *           rpvt;	/*Ptr to Pvt Struct*/
	short		mpts;	/*Max # of Points*/
	short		exsc;	/*Execute Scan*/
	unsigned char	pxsc;	/*Previous XScan*/
	short		npts;	/*Number of Points*/
	unsigned short	fpts;	/*Freeze Num of Points*/
	unsigned short	ffo;	/*Freeze Flag Override*/
	short		cpt;	/*Current Point*/
	short		dpt;	/*Desired Point*/
	short		pcpt;	/*Point ofLast Posting*/
	unsigned short	pasm;	/*After Scan Mode*/
	unsigned long	tolp;	/*Time of Last Posting*/
	char		p1pv[40]; /*Positioner 1 PV Name*/
	char		p2pv[40]; /*Positioner 2 PV Name*/
	char		p3pv[40]; /*Positioner 3 PV Name*/
	char		p4pv[40]; /*Positioner 4 PV Name*/
	char		r1pv[40]; /*P1 Readback  PV Name*/
	char		r2pv[40]; /*P2 Readback  PV Name*/
	char		r3pv[40]; /*P3 Readback  PV Name*/
	char		r4pv[40]; /*P4 Readback  PV Name*/
	char		d1pv[40]; /*Detector 1   PV Name*/
	char		d2pv[40]; /*Detector 2   PV Name*/
	char		d3pv[40]; /*Detector 3   PV Name*/
	char		d4pv[40]; /*Detector 4   PV Name*/
	char		d5pv[40]; /*Detector 5   PV Name*/
	char		d6pv[40]; /*Detector 6   PV Name*/
	char		d7pv[40]; /*Detector 7   PV Name*/
	char		d8pv[40]; /*Detector 8   PV Name*/
	char		d9pv[40]; /*Detector 9   PV Name*/
	char		dapv[40]; /*Detector 10  PV Name*/
	char		dbpv[40]; /*Detector 11  PV Name*/
	char		dcpv[40]; /*Detector 12  PV Name*/
	char		ddpv[40]; /*Detector 13  PV Name*/
	char		depv[40]; /*Detector 14  PV Name*/
	char		dfpv[40]; /*Detector 15  PV Name*/
	char		t1pv[40]; /*Trigger 1    PV Name*/
	char		t2pv[40]; /*Trigger 2    PV Name*/
	char		bspv[40]; /*Before Scan  PV Name*/
	char		aspv[40]; /*After Scan   PV Name*/
	unsigned short	p1nv;	/*P1  PV Status*/
	unsigned short	p2nv;	/*P2  PV Status*/
	unsigned short	p3nv;	/*P3  PV Status*/
	unsigned short	p4nv;	/*P4  PV Status*/
	unsigned short	r1nv;	/*R1  PV Status*/
	unsigned short	r2nv;	/*R2  PV Status*/
	unsigned short	r3nv;	/*R3  PV Status*/
	unsigned short	r4nv;	/*R4  PV Status*/
	unsigned short	d1nv;	/*D1  PV Status*/
	unsigned short	d2nv;	/*D2  PV Status*/
	unsigned short	d3nv;	/*D3  PV Status*/
	unsigned short	d4nv;	/*D4  PV Status*/
	unsigned short	d5nv;	/*D5  PV Status*/
	unsigned short	d6nv;	/*D6  PV Status*/
	unsigned short	d7nv;	/*D7  PV Status*/
	unsigned short	d8nv;	/*D8  PV Status*/
	unsigned short	d9nv;	/*D9  PV Status*/
	unsigned short	danv;	/*D10 PV Status*/
	unsigned short	dbnv;	/*D11 PV Status*/
	unsigned short	dcnv;	/*D12 PV Status*/
	unsigned short	ddnv;	/*D13 PV Status*/
	unsigned short	denv;	/*D14 PV Status*/
	unsigned short	dfnv;	/*D15 PV Status*/
	unsigned short	t1nv;	/*T1  PV Status*/
	unsigned short	t2nv;	/*T2  PV Status*/
	unsigned short	bsnv;	/*BeforeScan PV Status*/
	unsigned short	asnv;	/*After Scan PV Status*/
	double		p1pp;	/*P1 Previous Position*/
	double		p1cv;	/*P1 Current Value*/
	double		p1dv;	/*P1 Desired Value*/
	double		p1lv;	/*P1 Last Value Posted*/
	double		p1sp;	/*P1 Start Position*/
	double		p1si;	/*P1 Step Increment*/
	double		p1ep;	/*P1 End Position*/
	double		p1cp;	/*P1 Center Position*/
	double		p1wd;	/*P1 Scan Width*/
	double		r1cv;	/*P1 Readback Value*/
	double		r1lv;	/*P1 Rdbk Last Val Pst*/
	double		r1dl;	/*P1 Readback Delta*/
	double		p1hr;	/*P1 High Oper Range*/
	double		p1lr;	/*P1 Low  Oper Range*/
	double *         p1pa;	/*P1 Step Array*/
	double *         p1ra;	/*P1 Readback Array*/
	unsigned short	p1fs;	/*P1 Freeze Start Pos*/
	unsigned short	p1fi;	/*P1 Freeze Step Inc*/
	unsigned short	p1fe;	/*P1 Freeze End Pos*/
	unsigned short	p1fc;	/*P1 Freeze Center Pos*/
	unsigned short	p1fw;	/*P1 Freeze Width*/
	unsigned short	p1sm;	/*P1 Step Mode*/
	unsigned short	p1ar;	/*P1 Absolute/Relative*/
	char		p1eu[16]; /*P1 Engineering Units*/
	short		p1pr;	/*P1 Display Precision*/
	double		p2pp;	/*P2 Previous Position*/
	double		p2cv;	/*P2 Current Value*/
	double		p2dv;	/*P2 Desired Value*/
	double		p2lv;	/*P2 Last Value Posted*/
	double		p2sp;	/*P2 Start Position*/
	double		p2si;	/*P2 Step Increment*/
	double		p2ep;	/*P2 End Position*/
	double		p2cp;	/*P2 Center Position*/
	double		p2wd;	/*P2 Scan Width*/
	double		r2cv;	/*P2 Readback Value*/
	double		r2lv;	/*P2 Rdbk Last Val Pst*/
	double		r2dl;	/*P2 Readback Delta*/
	double		p2hr;	/*P2 High Oper Range*/
	double		p2lr;	/*P2 Low  Oper Range*/
	double *         p2pa;	/*P2 Step Array*/
	double *         p2ra;	/*P2 Readback Array*/
	unsigned short	p2fs;	/*P2 Freeze Start Pos*/
	unsigned short	p2fi;	/*P2 Freeze Step Inc*/
	unsigned short	p2fe;	/*P2 Freeze End Pos*/
	unsigned short	p2fc;	/*P2 Freeze Center Pos*/
	unsigned short	p2fw;	/*P2 Freeze Width*/
	unsigned short	p2sm;	/*P2 Step Mode*/
	unsigned short	p2ar;	/*P2 Absolute/Relative*/
	char		p2eu[16]; /*P2 Engineering Units*/
	short		p2pr;	/*P2 Display Precision*/
	double		p3pp;	/*P3 Previous Position*/
	double		p3cv;	/*P3 Current Value*/
	double		p3dv;	/*P3 Desired Value*/
	double		p3lv;	/*P3 Last Value Posted*/
	double		p3sp;	/*P3 Start Position*/
	double		p3si;	/*P3 Step Increment*/
	double		p3ep;	/*P3 End Position*/
	double		p3cp;	/*P3 Center Position*/
	double		p3wd;	/*P3 Scan Width*/
	double		r3cv;	/*P3 Readback Value*/
	double		r3lv;	/*P3 Rdbk Last Val Pst*/
	double		r3dl;	/*P3 Readback Delta*/
	double		p3hr;	/*P3 High Oper Range*/
	double		p3lr;	/*P3 Low  Oper Range*/
	double *         p3pa;	/*P3 Step Array*/
	double *         p3ra;	/*P3 Readback Array*/
	unsigned short	p3fs;	/*P3 Freeze Start Pos*/
	unsigned short	p3fi;	/*P3 Freeze Step Inc*/
	unsigned short	p3fe;	/*P3 Freeze End Pos*/
	unsigned short	p3fc;	/*P3 Freeze Center Pos*/
	unsigned short	p3fw;	/*P3 Freeze Width*/
	unsigned short	p3sm;	/*P3 Step Mode*/
	unsigned short	p3ar;	/*P3 Absolute/Relative*/
	char		p3eu[16]; /*P3 Engineering Units*/
	short		p3pr;	/*P3 Display Precision*/
	double		p4pp;	/*P4 Previous Position*/
	double		p4cv;	/*P4 Current Value*/
	double		p4dv;	/*P4 Desired Value*/
	double		p4lv;	/*P4 Last Value Posted*/
	double		p4sp;	/*P4 Start Position*/
	double		p4si;	/*P4 Step Increment*/
	double		p4ep;	/*P4 End Position*/
	double		p4cp;	/*P4 Center Position*/
	double		p4wd;	/*P4 Scan Width*/
	double		r4cv;	/*P4 Readback Value*/
	double		r4lv;	/*P4 Rdbk Last Val Pst*/
	double		r4dl;	/*P4 Readback Delta*/
	double		p4hr;	/*P4 High Oper Range*/
	double		p4lr;	/*P4 Low  Oper Range*/
	double *         p4pa;	/*P4 Step Array*/
	double *         p4ra;	/*P4 Readback Array*/
	unsigned short	p4fs;	/*P4 Freeze Start Pos*/
	unsigned short	p4fi;	/*P4 Freeze Step Inc*/
	unsigned short	p4fe;	/*P4 Freeze End Pos*/
	unsigned short	p4fc;	/*P4 Freeze Center Pos*/
	unsigned short	p4fw;	/*P4 Freeze Width*/
	unsigned short	p4sm;	/*P4 Step Mode*/
	unsigned short	p4ar;	/*P4 Absolute/Relative*/
	char		p4eu[16]; /*P4 Engineering Units*/
	short		p4pr;	/*P4 Display Precision*/
	double		d1hr;	/*D1 High Oper Range*/
	double		d1lr;	/*D1 Low  Oper Range*/
	float *          d1da;	/*D1 Data Array*/
	float		d1cv;	/*D1 Current Value*/
	float		d1lv;	/*D1 Last Value Posted*/
	unsigned long	d1ne;	/*D1 # of Elements/Pt*/
	char		d1eu[16]; /*D1 Engineering Units*/
	short		d1pr;	/*D1 Display Precision*/
	double		d2hr;	/*D2 High Oper Range*/
	double		d2lr;	/*D2 Low  Oper Range*/
	float *          d2da;	/*D2 Data Array*/
	float		d2cv;	/*D2 Current Value*/
	float		d2lv;	/*D2 Last Value Posted*/
	unsigned long	d2ne;	/*D2 # of Elements/Pt*/
	char		d2eu[16]; /*D2 Engineering Units*/
	short		d2pr;	/*D2 Display Precision*/
	double		d3hr;	/*D3 High Oper Range*/
	double		d3lr;	/*D3 Low  Oper Range*/
	float *          d3da;	/*D3 Data Array*/
	float		d3cv;	/*D3 Current Value*/
	float		d3lv;	/*D3 Last Value Posted*/
	unsigned long	d3ne;	/*D3 # of Elements/Pt*/
	char		d3eu[16]; /*D3 Engineering Units*/
	short		d3pr;	/*D3 Display Precision*/
	double		d4hr;	/*D4 High Oper Range*/
	double		d4lr;	/*D4 Low  Oper Range*/
	float *          d4da;	/*D4 Data Array*/
	float		d4cv;	/*D4 Current Value*/
	float		d4lv;	/*D4 Last Value Posted*/
	unsigned long	d4ne;	/*D4 # of Elements/Pt*/
	char		d4eu[16]; /*D4 Engineering Units*/
	short		d4pr;	/*D4 Display Precision*/
	double		d5hr;	/*D5 High Oper Range*/
	double		d5lr;	/*D5 Low  Oper Range*/
	float *          d5da;	/*D5 Data Array*/
	float		d5cv;	/*D5 Current Value*/
	float		d5lv;	/*D5 Last Value Posted*/
	unsigned long	d5ne;	/*D5 # of Elements/Pt*/
	char		d5eu[16]; /*D5 Engineering Units*/
	short		d5pr;	/*D5 Display Precision*/
	double		d6hr;	/*D6 High Oper Range*/
	double		d6lr;	/*D6 Low  Oper Range*/
	float *          d6da;	/*D6 Data Array*/
	float		d6cv;	/*D6 Current Value*/
	float		d6lv;	/*D6 Last Value Posted*/
	unsigned long	d6ne;	/*D6 # of Elements/Pt*/
	char		d6eu[16]; /*D6 Engineering Units*/
	short		d6pr;	/*D6 Display Precision*/
	double		d7hr;	/*D7 High Oper Range*/
	double		d7lr;	/*D7 Low  Oper Range*/
	float *          d7da;	/*D7 Data Array*/
	float		d7cv;	/*D7 Current Value*/
	float		d7lv;	/*D7 Last Value Posted*/
	unsigned long	d7ne;	/*D7 # of Elements/Pt*/
	char		d7eu[16]; /*D7 Engineering Units*/
	short		d7pr;	/*D7 Display Precision*/
	double		d8hr;	/*D8 High Oper Range*/
	double		d8lr;	/*D8 Low  Oper Range*/
	float *          d8da;	/*D8 Data Array*/
	float		d8cv;	/*D8 Current Value*/
	float		d8lv;	/*D8 Last Value Posted*/
	unsigned long	d8ne;	/*D8 # of Elements/Pt*/
	char		d8eu[16]; /*D8 Engineering Units*/
	short		d8pr;	/*D8 Display Precision*/
	double		d9hr;	/*D9 High Oper Range*/
	double		d9lr;	/*D9 Low  Oper Range*/
	float *          d9da;	/*D9 Data Array*/
	float		d9cv;	/*D9 Current Value*/
	float		d9lv;	/*D9 Last Value Posted*/
	unsigned long	d9ne;	/*D9 # of Elements/Pt*/
	char		d9eu[16]; /*D9 Engineering Units*/
	short		d9pr;	/*D9 Display Precision*/
	double		dahr;	/*D10 High Oper Range*/
	double		dalr;	/*D10 Low  Oper Range*/
	float *          dada;	/*D10 Data Array*/
	float		dacv;	/*D10 Current Value*/
	float		dalv;	/*D10 LastValue Posted*/
	unsigned long	dane;	/*D10 # of Elements/Pt*/
	char		daeu[16]; /*D10 EngineeringUnits*/
	short		dapr;	/*D10 DisplayPrecision*/
	double		dbhr;	/*D11 High Oper Range*/
	double		dblr;	/*D11 Low  Oper Range*/
	float *          dbda;	/*D11 Data Array*/
	float		dbcv;	/*D11 Current Value*/
	float		dblv;	/*D11 LastValue Posted*/
	unsigned long	dbne;	/*D11 # of Elements/Pt*/
	char		dbeu[16]; /*D11 EngineeringUnits*/
	short		dbpr;	/*D11 DisplayPrecision*/
	double		dchr;	/*D12 High Oper Range*/
	double		dclr;	/*D12 Low  Oper Range*/
	float *          dcda;	/*D12 Data Array*/
	float		dccv;	/*D12 Current Value*/
	float		dclv;	/*D12 LastValue Posted*/
	unsigned long	dcne;	/*D12 # of Elements/Pt*/
	char		dceu[16]; /*D12 EngineeringUnits*/
	short		dcpr;	/*D12 DisplayPrecision*/
	double		ddhr;	/*D13 High Oper Range*/
	double		ddlr;	/*D13 Low  Oper Range*/
	float *          ddda;	/*D13 Data Array*/
	float		ddcv;	/*D13 Current Value*/
	float		ddlv;	/*D13 LastValue Posted*/
	unsigned long	ddne;	/*D13 # of Elements/Pt*/
	char		ddeu[16]; /*D13 EngineeringUnits*/
	short		ddpr;	/*D13 DisplayPrecision*/
	double		dehr;	/*D14 High Oper Range*/
	double		delr;	/*D14 Low  Oper Range*/
	float *          deda;	/*D14 Data Array*/
	float		decv;	/*D14 Current Value*/
	float		delv;	/*D14 LastValue Posted*/
	unsigned long	dene;	/*D14 # of Elements/Pt*/
	char		deeu[16]; /*D14 EngineeringUnits*/
	short		depr;	/*D14 DisplayPrecision*/
	double		dfhr;	/*D15 High Oper Range*/
	double		dflr;	/*D15 Low  Oper Range*/
	float *          dfda;	/*D15 Data Array*/
	float		dfcv;	/*D15 Current Value*/
	float		dflv;	/*D15 LastValue Posted*/
	unsigned long	dfne;	/*D15 # of Elements/Pt*/
	char		dfeu[16]; /*D15 EngineeringUnits*/
	short		dfpr;	/*D15 DisplayPrecision*/
	float		t1cd;	/*T1 Cmnd*/
	float		t2cd;	/*T2 Cmnd*/
	float		bscd;	/*Before Scan Cmnd*/
	float		ascd;	/*After Scan Cmnd*/
} scanRecord;
#define scanRecordNAME	0
#define scanRecordDESC	1
#define scanRecordASG	2
#define scanRecordSCAN	3
#define scanRecordPINI	4
#define scanRecordPHAS	5
#define scanRecordEVNT	6
#define scanRecordTSE	7
#define scanRecordTSEL	8
#define scanRecordDTYP	9
#define scanRecordDISV	10
#define scanRecordDISA	11
#define scanRecordSDIS	12
#define scanRecordMLOK	13
#define scanRecordMLIS	14
#define scanRecordDISP	15
#define scanRecordPROC	16
#define scanRecordSTAT	17
#define scanRecordSEVR	18
#define scanRecordNSTA	19
#define scanRecordNSEV	20
#define scanRecordACKS	21
#define scanRecordACKT	22
#define scanRecordDISS	23
#define scanRecordLCNT	24
#define scanRecordPACT	25
#define scanRecordPUTF	26
#define scanRecordRPRO	27
#define scanRecordASP	28
#define scanRecordPPN	29
#define scanRecordPPNN	30
#define scanRecordSPVT	31
#define scanRecordRSET	32
#define scanRecordDSET	33
#define scanRecordDPVT	34
#define scanRecordRDES	35
#define scanRecordLSET	36
#define scanRecordPRIO	37
#define scanRecordTPRO	38
#define scanRecordBKPT	39
#define scanRecordUDF	40
#define scanRecordTIME	41
#define scanRecordFLNK	42
#define scanRecordVERS	43
#define scanRecordVAL	44
#define scanRecordSMSG	45
#define scanRecordCMND	46
#define scanRecordALRT	47
#define scanRecordRPVT	48
#define scanRecordMPTS	49
#define scanRecordEXSC	50
#define scanRecordPXSC	51
#define scanRecordNPTS	52
#define scanRecordFPTS	53
#define scanRecordFFO	54
#define scanRecordCPT	55
#define scanRecordDPT	56
#define scanRecordPCPT	57
#define scanRecordPASM	58
#define scanRecordTOLP	59
#define scanRecordP1PV	60
#define scanRecordP2PV	61
#define scanRecordP3PV	62
#define scanRecordP4PV	63
#define scanRecordR1PV	64
#define scanRecordR2PV	65
#define scanRecordR3PV	66
#define scanRecordR4PV	67
#define scanRecordD1PV	68
#define scanRecordD2PV	69
#define scanRecordD3PV	70
#define scanRecordD4PV	71
#define scanRecordD5PV	72
#define scanRecordD6PV	73
#define scanRecordD7PV	74
#define scanRecordD8PV	75
#define scanRecordD9PV	76
#define scanRecordDAPV	77
#define scanRecordDBPV	78
#define scanRecordDCPV	79
#define scanRecordDDPV	80
#define scanRecordDEPV	81
#define scanRecordDFPV	82
#define scanRecordT1PV	83
#define scanRecordT2PV	84
#define scanRecordBSPV	85
#define scanRecordASPV	86
#define scanRecordP1NV	87
#define scanRecordP2NV	88
#define scanRecordP3NV	89
#define scanRecordP4NV	90
#define scanRecordR1NV	91
#define scanRecordR2NV	92
#define scanRecordR3NV	93
#define scanRecordR4NV	94
#define scanRecordD1NV	95
#define scanRecordD2NV	96
#define scanRecordD3NV	97
#define scanRecordD4NV	98
#define scanRecordD5NV	99
#define scanRecordD6NV	100
#define scanRecordD7NV	101
#define scanRecordD8NV	102
#define scanRecordD9NV	103
#define scanRecordDANV	104
#define scanRecordDBNV	105
#define scanRecordDCNV	106
#define scanRecordDDNV	107
#define scanRecordDENV	108
#define scanRecordDFNV	109
#define scanRecordT1NV	110
#define scanRecordT2NV	111
#define scanRecordBSNV	112
#define scanRecordASNV	113
#define scanRecordP1PP	114
#define scanRecordP1CV	115
#define scanRecordP1DV	116
#define scanRecordP1LV	117
#define scanRecordP1SP	118
#define scanRecordP1SI	119
#define scanRecordP1EP	120
#define scanRecordP1CP	121
#define scanRecordP1WD	122
#define scanRecordR1CV	123
#define scanRecordR1LV	124
#define scanRecordR1DL	125
#define scanRecordP1HR	126
#define scanRecordP1LR	127
#define scanRecordP1PA	128
#define scanRecordP1RA	129
#define scanRecordP1FS	130
#define scanRecordP1FI	131
#define scanRecordP1FE	132
#define scanRecordP1FC	133
#define scanRecordP1FW	134
#define scanRecordP1SM	135
#define scanRecordP1AR	136
#define scanRecordP1EU	137
#define scanRecordP1PR	138
#define scanRecordP2PP	139
#define scanRecordP2CV	140
#define scanRecordP2DV	141
#define scanRecordP2LV	142
#define scanRecordP2SP	143
#define scanRecordP2SI	144
#define scanRecordP2EP	145
#define scanRecordP2CP	146
#define scanRecordP2WD	147
#define scanRecordR2CV	148
#define scanRecordR2LV	149
#define scanRecordR2DL	150
#define scanRecordP2HR	151
#define scanRecordP2LR	152
#define scanRecordP2PA	153
#define scanRecordP2RA	154
#define scanRecordP2FS	155
#define scanRecordP2FI	156
#define scanRecordP2FE	157
#define scanRecordP2FC	158
#define scanRecordP2FW	159
#define scanRecordP2SM	160
#define scanRecordP2AR	161
#define scanRecordP2EU	162
#define scanRecordP2PR	163
#define scanRecordP3PP	164
#define scanRecordP3CV	165
#define scanRecordP3DV	166
#define scanRecordP3LV	167
#define scanRecordP3SP	168
#define scanRecordP3SI	169
#define scanRecordP3EP	170
#define scanRecordP3CP	171
#define scanRecordP3WD	172
#define scanRecordR3CV	173
#define scanRecordR3LV	174
#define scanRecordR3DL	175
#define scanRecordP3HR	176
#define scanRecordP3LR	177
#define scanRecordP3PA	178
#define scanRecordP3RA	179
#define scanRecordP3FS	180
#define scanRecordP3FI	181
#define scanRecordP3FE	182
#define scanRecordP3FC	183
#define scanRecordP3FW	184
#define scanRecordP3SM	185
#define scanRecordP3AR	186
#define scanRecordP3EU	187
#define scanRecordP3PR	188
#define scanRecordP4PP	189
#define scanRecordP4CV	190
#define scanRecordP4DV	191
#define scanRecordP4LV	192
#define scanRecordP4SP	193
#define scanRecordP4SI	194
#define scanRecordP4EP	195
#define scanRecordP4CP	196
#define scanRecordP4WD	197
#define scanRecordR4CV	198
#define scanRecordR4LV	199
#define scanRecordR4DL	200
#define scanRecordP4HR	201
#define scanRecordP4LR	202
#define scanRecordP4PA	203
#define scanRecordP4RA	204
#define scanRecordP4FS	205
#define scanRecordP4FI	206
#define scanRecordP4FE	207
#define scanRecordP4FC	208
#define scanRecordP4FW	209
#define scanRecordP4SM	210
#define scanRecordP4AR	211
#define scanRecordP4EU	212
#define scanRecordP4PR	213
#define scanRecordD1HR	214
#define scanRecordD1LR	215
#define scanRecordD1DA	216
#define scanRecordD1CV	217
#define scanRecordD1LV	218
#define scanRecordD1NE	219
#define scanRecordD1EU	220
#define scanRecordD1PR	221
#define scanRecordD2HR	222
#define scanRecordD2LR	223
#define scanRecordD2DA	224
#define scanRecordD2CV	225
#define scanRecordD2LV	226
#define scanRecordD2NE	227
#define scanRecordD2EU	228
#define scanRecordD2PR	229
#define scanRecordD3HR	230
#define scanRecordD3LR	231
#define scanRecordD3DA	232
#define scanRecordD3CV	233
#define scanRecordD3LV	234
#define scanRecordD3NE	235
#define scanRecordD3EU	236
#define scanRecordD3PR	237
#define scanRecordD4HR	238
#define scanRecordD4LR	239
#define scanRecordD4DA	240
#define scanRecordD4CV	241
#define scanRecordD4LV	242
#define scanRecordD4NE	243
#define scanRecordD4EU	244
#define scanRecordD4PR	245
#define scanRecordD5HR	246
#define scanRecordD5LR	247
#define scanRecordD5DA	248
#define scanRecordD5CV	249
#define scanRecordD5LV	250
#define scanRecordD5NE	251
#define scanRecordD5EU	252
#define scanRecordD5PR	253
#define scanRecordD6HR	254
#define scanRecordD6LR	255
#define scanRecordD6DA	256
#define scanRecordD6CV	257
#define scanRecordD6LV	258
#define scanRecordD6NE	259
#define scanRecordD6EU	260
#define scanRecordD6PR	261
#define scanRecordD7HR	262
#define scanRecordD7LR	263
#define scanRecordD7DA	264
#define scanRecordD7CV	265
#define scanRecordD7LV	266
#define scanRecordD7NE	267
#define scanRecordD7EU	268
#define scanRecordD7PR	269
#define scanRecordD8HR	270
#define scanRecordD8LR	271
#define scanRecordD8DA	272
#define scanRecordD8CV	273
#define scanRecordD8LV	274
#define scanRecordD8NE	275
#define scanRecordD8EU	276
#define scanRecordD8PR	277
#define scanRecordD9HR	278
#define scanRecordD9LR	279
#define scanRecordD9DA	280
#define scanRecordD9CV	281
#define scanRecordD9LV	282
#define scanRecordD9NE	283
#define scanRecordD9EU	284
#define scanRecordD9PR	285
#define scanRecordDAHR	286
#define scanRecordDALR	287
#define scanRecordDADA	288
#define scanRecordDACV	289
#define scanRecordDALV	290
#define scanRecordDANE	291
#define scanRecordDAEU	292
#define scanRecordDAPR	293
#define scanRecordDBHR	294
#define scanRecordDBLR	295
#define scanRecordDBDA	296
#define scanRecordDBCV	297
#define scanRecordDBLV	298
#define scanRecordDBNE	299
#define scanRecordDBEU	300
#define scanRecordDBPR	301
#define scanRecordDCHR	302
#define scanRecordDCLR	303
#define scanRecordDCDA	304
#define scanRecordDCCV	305
#define scanRecordDCLV	306
#define scanRecordDCNE	307
#define scanRecordDCEU	308
#define scanRecordDCPR	309
#define scanRecordDDHR	310
#define scanRecordDDLR	311
#define scanRecordDDDA	312
#define scanRecordDDCV	313
#define scanRecordDDLV	314
#define scanRecordDDNE	315
#define scanRecordDDEU	316
#define scanRecordDDPR	317
#define scanRecordDEHR	318
#define scanRecordDELR	319
#define scanRecordDEDA	320
#define scanRecordDECV	321
#define scanRecordDELV	322
#define scanRecordDENE	323
#define scanRecordDEEU	324
#define scanRecordDEPR	325
#define scanRecordDFHR	326
#define scanRecordDFLR	327
#define scanRecordDFDA	328
#define scanRecordDFCV	329
#define scanRecordDFLV	330
#define scanRecordDFNE	331
#define scanRecordDFEU	332
#define scanRecordDFPR	333
#define scanRecordT1CD	334
#define scanRecordT2CD	335
#define scanRecordBSCD	336
#define scanRecordASCD	337
#endif /*INCscanH*/
#ifdef GEN_SIZE_OFFSET
int scanRecordSizeOffset(dbRecordType *pdbRecordType)
{
    scanRecord *prec = 0;
  pdbRecordType->papFldDes[0]->size=sizeof(prec->name);
  pdbRecordType->papFldDes[0]->offset=(short)((char *)&prec->name - (char *)prec);
  pdbRecordType->papFldDes[1]->size=sizeof(prec->desc);
  pdbRecordType->papFldDes[1]->offset=(short)((char *)&prec->desc - (char *)prec);
  pdbRecordType->papFldDes[2]->size=sizeof(prec->asg);
  pdbRecordType->papFldDes[2]->offset=(short)((char *)&prec->asg - (char *)prec);
  pdbRecordType->papFldDes[3]->size=sizeof(prec->scan);
  pdbRecordType->papFldDes[3]->offset=(short)((char *)&prec->scan - (char *)prec);
  pdbRecordType->papFldDes[4]->size=sizeof(prec->pini);
  pdbRecordType->papFldDes[4]->offset=(short)((char *)&prec->pini - (char *)prec);
  pdbRecordType->papFldDes[5]->size=sizeof(prec->phas);
  pdbRecordType->papFldDes[5]->offset=(short)((char *)&prec->phas - (char *)prec);
  pdbRecordType->papFldDes[6]->size=sizeof(prec->evnt);
  pdbRecordType->papFldDes[6]->offset=(short)((char *)&prec->evnt - (char *)prec);
  pdbRecordType->papFldDes[7]->size=sizeof(prec->tse);
  pdbRecordType->papFldDes[7]->offset=(short)((char *)&prec->tse - (char *)prec);
  pdbRecordType->papFldDes[8]->size=sizeof(prec->tsel);
  pdbRecordType->papFldDes[8]->offset=(short)((char *)&prec->tsel - (char *)prec);
  pdbRecordType->papFldDes[9]->size=sizeof(prec->dtyp);
  pdbRecordType->papFldDes[9]->offset=(short)((char *)&prec->dtyp - (char *)prec);
  pdbRecordType->papFldDes[10]->size=sizeof(prec->disv);
  pdbRecordType->papFldDes[10]->offset=(short)((char *)&prec->disv - (char *)prec);
  pdbRecordType->papFldDes[11]->size=sizeof(prec->disa);
  pdbRecordType->papFldDes[11]->offset=(short)((char *)&prec->disa - (char *)prec);
  pdbRecordType->papFldDes[12]->size=sizeof(prec->sdis);
  pdbRecordType->papFldDes[12]->offset=(short)((char *)&prec->sdis - (char *)prec);
  pdbRecordType->papFldDes[13]->size=sizeof(prec->mlok);
  pdbRecordType->papFldDes[13]->offset=(short)((char *)&prec->mlok - (char *)prec);
  pdbRecordType->papFldDes[14]->size=sizeof(prec->mlis);
  pdbRecordType->papFldDes[14]->offset=(short)((char *)&prec->mlis - (char *)prec);
  pdbRecordType->papFldDes[15]->size=sizeof(prec->disp);
  pdbRecordType->papFldDes[15]->offset=(short)((char *)&prec->disp - (char *)prec);
  pdbRecordType->papFldDes[16]->size=sizeof(prec->proc);
  pdbRecordType->papFldDes[16]->offset=(short)((char *)&prec->proc - (char *)prec);
  pdbRecordType->papFldDes[17]->size=sizeof(prec->stat);
  pdbRecordType->papFldDes[17]->offset=(short)((char *)&prec->stat - (char *)prec);
  pdbRecordType->papFldDes[18]->size=sizeof(prec->sevr);
  pdbRecordType->papFldDes[18]->offset=(short)((char *)&prec->sevr - (char *)prec);
  pdbRecordType->papFldDes[19]->size=sizeof(prec->nsta);
  pdbRecordType->papFldDes[19]->offset=(short)((char *)&prec->nsta - (char *)prec);
  pdbRecordType->papFldDes[20]->size=sizeof(prec->nsev);
  pdbRecordType->papFldDes[20]->offset=(short)((char *)&prec->nsev - (char *)prec);
  pdbRecordType->papFldDes[21]->size=sizeof(prec->acks);
  pdbRecordType->papFldDes[21]->offset=(short)((char *)&prec->acks - (char *)prec);
  pdbRecordType->papFldDes[22]->size=sizeof(prec->ackt);
  pdbRecordType->papFldDes[22]->offset=(short)((char *)&prec->ackt - (char *)prec);
  pdbRecordType->papFldDes[23]->size=sizeof(prec->diss);
  pdbRecordType->papFldDes[23]->offset=(short)((char *)&prec->diss - (char *)prec);
  pdbRecordType->papFldDes[24]->size=sizeof(prec->lcnt);
  pdbRecordType->papFldDes[24]->offset=(short)((char *)&prec->lcnt - (char *)prec);
  pdbRecordType->papFldDes[25]->size=sizeof(prec->pact);
  pdbRecordType->papFldDes[25]->offset=(short)((char *)&prec->pact - (char *)prec);
  pdbRecordType->papFldDes[26]->size=sizeof(prec->putf);
  pdbRecordType->papFldDes[26]->offset=(short)((char *)&prec->putf - (char *)prec);
  pdbRecordType->papFldDes[27]->size=sizeof(prec->rpro);
  pdbRecordType->papFldDes[27]->offset=(short)((char *)&prec->rpro - (char *)prec);
  pdbRecordType->papFldDes[28]->size=sizeof(prec->asp);
  pdbRecordType->papFldDes[28]->offset=(short)((char *)&prec->asp - (char *)prec);
  pdbRecordType->papFldDes[29]->size=sizeof(prec->ppn);
  pdbRecordType->papFldDes[29]->offset=(short)((char *)&prec->ppn - (char *)prec);
  pdbRecordType->papFldDes[30]->size=sizeof(prec->ppnn);
  pdbRecordType->papFldDes[30]->offset=(short)((char *)&prec->ppnn - (char *)prec);
  pdbRecordType->papFldDes[31]->size=sizeof(prec->spvt);
  pdbRecordType->papFldDes[31]->offset=(short)((char *)&prec->spvt - (char *)prec);
  pdbRecordType->papFldDes[32]->size=sizeof(prec->rset);
  pdbRecordType->papFldDes[32]->offset=(short)((char *)&prec->rset - (char *)prec);
  pdbRecordType->papFldDes[33]->size=sizeof(prec->dset);
  pdbRecordType->papFldDes[33]->offset=(short)((char *)&prec->dset - (char *)prec);
  pdbRecordType->papFldDes[34]->size=sizeof(prec->dpvt);
  pdbRecordType->papFldDes[34]->offset=(short)((char *)&prec->dpvt - (char *)prec);
  pdbRecordType->papFldDes[35]->size=sizeof(prec->rdes);
  pdbRecordType->papFldDes[35]->offset=(short)((char *)&prec->rdes - (char *)prec);
  pdbRecordType->papFldDes[36]->size=sizeof(prec->lset);
  pdbRecordType->papFldDes[36]->offset=(short)((char *)&prec->lset - (char *)prec);
  pdbRecordType->papFldDes[37]->size=sizeof(prec->prio);
  pdbRecordType->papFldDes[37]->offset=(short)((char *)&prec->prio - (char *)prec);
  pdbRecordType->papFldDes[38]->size=sizeof(prec->tpro);
  pdbRecordType->papFldDes[38]->offset=(short)((char *)&prec->tpro - (char *)prec);
  pdbRecordType->papFldDes[39]->size=sizeof(prec->bkpt);
  pdbRecordType->papFldDes[39]->offset=(short)((char *)&prec->bkpt - (char *)prec);
  pdbRecordType->papFldDes[40]->size=sizeof(prec->udf);
  pdbRecordType->papFldDes[40]->offset=(short)((char *)&prec->udf - (char *)prec);
  pdbRecordType->papFldDes[41]->size=sizeof(prec->time);
  pdbRecordType->papFldDes[41]->offset=(short)((char *)&prec->time - (char *)prec);
  pdbRecordType->papFldDes[42]->size=sizeof(prec->flnk);
  pdbRecordType->papFldDes[42]->offset=(short)((char *)&prec->flnk - (char *)prec);
  pdbRecordType->papFldDes[43]->size=sizeof(prec->vers);
  pdbRecordType->papFldDes[43]->offset=(short)((char *)&prec->vers - (char *)prec);
  pdbRecordType->papFldDes[44]->size=sizeof(prec->val);
  pdbRecordType->papFldDes[44]->offset=(short)((char *)&prec->val - (char *)prec);
  pdbRecordType->papFldDes[45]->size=sizeof(prec->smsg);
  pdbRecordType->papFldDes[45]->offset=(short)((char *)&prec->smsg - (char *)prec);
  pdbRecordType->papFldDes[46]->size=sizeof(prec->cmnd);
  pdbRecordType->papFldDes[46]->offset=(short)((char *)&prec->cmnd - (char *)prec);
  pdbRecordType->papFldDes[47]->size=sizeof(prec->alrt);
  pdbRecordType->papFldDes[47]->offset=(short)((char *)&prec->alrt - (char *)prec);
  pdbRecordType->papFldDes[48]->size=sizeof(prec->rpvt);
  pdbRecordType->papFldDes[48]->offset=(short)((char *)&prec->rpvt - (char *)prec);
  pdbRecordType->papFldDes[49]->size=sizeof(prec->mpts);
  pdbRecordType->papFldDes[49]->offset=(short)((char *)&prec->mpts - (char *)prec);
  pdbRecordType->papFldDes[50]->size=sizeof(prec->exsc);
  pdbRecordType->papFldDes[50]->offset=(short)((char *)&prec->exsc - (char *)prec);
  pdbRecordType->papFldDes[51]->size=sizeof(prec->pxsc);
  pdbRecordType->papFldDes[51]->offset=(short)((char *)&prec->pxsc - (char *)prec);
  pdbRecordType->papFldDes[52]->size=sizeof(prec->npts);
  pdbRecordType->papFldDes[52]->offset=(short)((char *)&prec->npts - (char *)prec);
  pdbRecordType->papFldDes[53]->size=sizeof(prec->fpts);
  pdbRecordType->papFldDes[53]->offset=(short)((char *)&prec->fpts - (char *)prec);
  pdbRecordType->papFldDes[54]->size=sizeof(prec->ffo);
  pdbRecordType->papFldDes[54]->offset=(short)((char *)&prec->ffo - (char *)prec);
  pdbRecordType->papFldDes[55]->size=sizeof(prec->cpt);
  pdbRecordType->papFldDes[55]->offset=(short)((char *)&prec->cpt - (char *)prec);
  pdbRecordType->papFldDes[56]->size=sizeof(prec->dpt);
  pdbRecordType->papFldDes[56]->offset=(short)((char *)&prec->dpt - (char *)prec);
  pdbRecordType->papFldDes[57]->size=sizeof(prec->pcpt);
  pdbRecordType->papFldDes[57]->offset=(short)((char *)&prec->pcpt - (char *)prec);
  pdbRecordType->papFldDes[58]->size=sizeof(prec->pasm);
  pdbRecordType->papFldDes[58]->offset=(short)((char *)&prec->pasm - (char *)prec);
  pdbRecordType->papFldDes[59]->size=sizeof(prec->tolp);
  pdbRecordType->papFldDes[59]->offset=(short)((char *)&prec->tolp - (char *)prec);
  pdbRecordType->papFldDes[60]->size=sizeof(prec->p1pv);
  pdbRecordType->papFldDes[60]->offset=(short)((char *)&prec->p1pv - (char *)prec);
  pdbRecordType->papFldDes[61]->size=sizeof(prec->p2pv);
  pdbRecordType->papFldDes[61]->offset=(short)((char *)&prec->p2pv - (char *)prec);
  pdbRecordType->papFldDes[62]->size=sizeof(prec->p3pv);
  pdbRecordType->papFldDes[62]->offset=(short)((char *)&prec->p3pv - (char *)prec);
  pdbRecordType->papFldDes[63]->size=sizeof(prec->p4pv);
  pdbRecordType->papFldDes[63]->offset=(short)((char *)&prec->p4pv - (char *)prec);
  pdbRecordType->papFldDes[64]->size=sizeof(prec->r1pv);
  pdbRecordType->papFldDes[64]->offset=(short)((char *)&prec->r1pv - (char *)prec);
  pdbRecordType->papFldDes[65]->size=sizeof(prec->r2pv);
  pdbRecordType->papFldDes[65]->offset=(short)((char *)&prec->r2pv - (char *)prec);
  pdbRecordType->papFldDes[66]->size=sizeof(prec->r3pv);
  pdbRecordType->papFldDes[66]->offset=(short)((char *)&prec->r3pv - (char *)prec);
  pdbRecordType->papFldDes[67]->size=sizeof(prec->r4pv);
  pdbRecordType->papFldDes[67]->offset=(short)((char *)&prec->r4pv - (char *)prec);
  pdbRecordType->papFldDes[68]->size=sizeof(prec->d1pv);
  pdbRecordType->papFldDes[68]->offset=(short)((char *)&prec->d1pv - (char *)prec);
  pdbRecordType->papFldDes[69]->size=sizeof(prec->d2pv);
  pdbRecordType->papFldDes[69]->offset=(short)((char *)&prec->d2pv - (char *)prec);
  pdbRecordType->papFldDes[70]->size=sizeof(prec->d3pv);
  pdbRecordType->papFldDes[70]->offset=(short)((char *)&prec->d3pv - (char *)prec);
  pdbRecordType->papFldDes[71]->size=sizeof(prec->d4pv);
  pdbRecordType->papFldDes[71]->offset=(short)((char *)&prec->d4pv - (char *)prec);
  pdbRecordType->papFldDes[72]->size=sizeof(prec->d5pv);
  pdbRecordType->papFldDes[72]->offset=(short)((char *)&prec->d5pv - (char *)prec);
  pdbRecordType->papFldDes[73]->size=sizeof(prec->d6pv);
  pdbRecordType->papFldDes[73]->offset=(short)((char *)&prec->d6pv - (char *)prec);
  pdbRecordType->papFldDes[74]->size=sizeof(prec->d7pv);
  pdbRecordType->papFldDes[74]->offset=(short)((char *)&prec->d7pv - (char *)prec);
  pdbRecordType->papFldDes[75]->size=sizeof(prec->d8pv);
  pdbRecordType->papFldDes[75]->offset=(short)((char *)&prec->d8pv - (char *)prec);
  pdbRecordType->papFldDes[76]->size=sizeof(prec->d9pv);
  pdbRecordType->papFldDes[76]->offset=(short)((char *)&prec->d9pv - (char *)prec);
  pdbRecordType->papFldDes[77]->size=sizeof(prec->dapv);
  pdbRecordType->papFldDes[77]->offset=(short)((char *)&prec->dapv - (char *)prec);
  pdbRecordType->papFldDes[78]->size=sizeof(prec->dbpv);
  pdbRecordType->papFldDes[78]->offset=(short)((char *)&prec->dbpv - (char *)prec);
  pdbRecordType->papFldDes[79]->size=sizeof(prec->dcpv);
  pdbRecordType->papFldDes[79]->offset=(short)((char *)&prec->dcpv - (char *)prec);
  pdbRecordType->papFldDes[80]->size=sizeof(prec->ddpv);
  pdbRecordType->papFldDes[80]->offset=(short)((char *)&prec->ddpv - (char *)prec);
  pdbRecordType->papFldDes[81]->size=sizeof(prec->depv);
  pdbRecordType->papFldDes[81]->offset=(short)((char *)&prec->depv - (char *)prec);
  pdbRecordType->papFldDes[82]->size=sizeof(prec->dfpv);
  pdbRecordType->papFldDes[82]->offset=(short)((char *)&prec->dfpv - (char *)prec);
  pdbRecordType->papFldDes[83]->size=sizeof(prec->t1pv);
  pdbRecordType->papFldDes[83]->offset=(short)((char *)&prec->t1pv - (char *)prec);
  pdbRecordType->papFldDes[84]->size=sizeof(prec->t2pv);
  pdbRecordType->papFldDes[84]->offset=(short)((char *)&prec->t2pv - (char *)prec);
  pdbRecordType->papFldDes[85]->size=sizeof(prec->bspv);
  pdbRecordType->papFldDes[85]->offset=(short)((char *)&prec->bspv - (char *)prec);
  pdbRecordType->papFldDes[86]->size=sizeof(prec->aspv);
  pdbRecordType->papFldDes[86]->offset=(short)((char *)&prec->aspv - (char *)prec);
  pdbRecordType->papFldDes[87]->size=sizeof(prec->p1nv);
  pdbRecordType->papFldDes[87]->offset=(short)((char *)&prec->p1nv - (char *)prec);
  pdbRecordType->papFldDes[88]->size=sizeof(prec->p2nv);
  pdbRecordType->papFldDes[88]->offset=(short)((char *)&prec->p2nv - (char *)prec);
  pdbRecordType->papFldDes[89]->size=sizeof(prec->p3nv);
  pdbRecordType->papFldDes[89]->offset=(short)((char *)&prec->p3nv - (char *)prec);
  pdbRecordType->papFldDes[90]->size=sizeof(prec->p4nv);
  pdbRecordType->papFldDes[90]->offset=(short)((char *)&prec->p4nv - (char *)prec);
  pdbRecordType->papFldDes[91]->size=sizeof(prec->r1nv);
  pdbRecordType->papFldDes[91]->offset=(short)((char *)&prec->r1nv - (char *)prec);
  pdbRecordType->papFldDes[92]->size=sizeof(prec->r2nv);
  pdbRecordType->papFldDes[92]->offset=(short)((char *)&prec->r2nv - (char *)prec);
  pdbRecordType->papFldDes[93]->size=sizeof(prec->r3nv);
  pdbRecordType->papFldDes[93]->offset=(short)((char *)&prec->r3nv - (char *)prec);
  pdbRecordType->papFldDes[94]->size=sizeof(prec->r4nv);
  pdbRecordType->papFldDes[94]->offset=(short)((char *)&prec->r4nv - (char *)prec);
  pdbRecordType->papFldDes[95]->size=sizeof(prec->d1nv);
  pdbRecordType->papFldDes[95]->offset=(short)((char *)&prec->d1nv - (char *)prec);
  pdbRecordType->papFldDes[96]->size=sizeof(prec->d2nv);
  pdbRecordType->papFldDes[96]->offset=(short)((char *)&prec->d2nv - (char *)prec);
  pdbRecordType->papFldDes[97]->size=sizeof(prec->d3nv);
  pdbRecordType->papFldDes[97]->offset=(short)((char *)&prec->d3nv - (char *)prec);
  pdbRecordType->papFldDes[98]->size=sizeof(prec->d4nv);
  pdbRecordType->papFldDes[98]->offset=(short)((char *)&prec->d4nv - (char *)prec);
  pdbRecordType->papFldDes[99]->size=sizeof(prec->d5nv);
  pdbRecordType->papFldDes[99]->offset=(short)((char *)&prec->d5nv - (char *)prec);
  pdbRecordType->papFldDes[100]->size=sizeof(prec->d6nv);
  pdbRecordType->papFldDes[100]->offset=(short)((char *)&prec->d6nv - (char *)prec);
  pdbRecordType->papFldDes[101]->size=sizeof(prec->d7nv);
  pdbRecordType->papFldDes[101]->offset=(short)((char *)&prec->d7nv - (char *)prec);
  pdbRecordType->papFldDes[102]->size=sizeof(prec->d8nv);
  pdbRecordType->papFldDes[102]->offset=(short)((char *)&prec->d8nv - (char *)prec);
  pdbRecordType->papFldDes[103]->size=sizeof(prec->d9nv);
  pdbRecordType->papFldDes[103]->offset=(short)((char *)&prec->d9nv - (char *)prec);
  pdbRecordType->papFldDes[104]->size=sizeof(prec->danv);
  pdbRecordType->papFldDes[104]->offset=(short)((char *)&prec->danv - (char *)prec);
  pdbRecordType->papFldDes[105]->size=sizeof(prec->dbnv);
  pdbRecordType->papFldDes[105]->offset=(short)((char *)&prec->dbnv - (char *)prec);
  pdbRecordType->papFldDes[106]->size=sizeof(prec->dcnv);
  pdbRecordType->papFldDes[106]->offset=(short)((char *)&prec->dcnv - (char *)prec);
  pdbRecordType->papFldDes[107]->size=sizeof(prec->ddnv);
  pdbRecordType->papFldDes[107]->offset=(short)((char *)&prec->ddnv - (char *)prec);
  pdbRecordType->papFldDes[108]->size=sizeof(prec->denv);
  pdbRecordType->papFldDes[108]->offset=(short)((char *)&prec->denv - (char *)prec);
  pdbRecordType->papFldDes[109]->size=sizeof(prec->dfnv);
  pdbRecordType->papFldDes[109]->offset=(short)((char *)&prec->dfnv - (char *)prec);
  pdbRecordType->papFldDes[110]->size=sizeof(prec->t1nv);
  pdbRecordType->papFldDes[110]->offset=(short)((char *)&prec->t1nv - (char *)prec);
  pdbRecordType->papFldDes[111]->size=sizeof(prec->t2nv);
  pdbRecordType->papFldDes[111]->offset=(short)((char *)&prec->t2nv - (char *)prec);
  pdbRecordType->papFldDes[112]->size=sizeof(prec->bsnv);
  pdbRecordType->papFldDes[112]->offset=(short)((char *)&prec->bsnv - (char *)prec);
  pdbRecordType->papFldDes[113]->size=sizeof(prec->asnv);
  pdbRecordType->papFldDes[113]->offset=(short)((char *)&prec->asnv - (char *)prec);
  pdbRecordType->papFldDes[114]->size=sizeof(prec->p1pp);
  pdbRecordType->papFldDes[114]->offset=(short)((char *)&prec->p1pp - (char *)prec);
  pdbRecordType->papFldDes[115]->size=sizeof(prec->p1cv);
  pdbRecordType->papFldDes[115]->offset=(short)((char *)&prec->p1cv - (char *)prec);
  pdbRecordType->papFldDes[116]->size=sizeof(prec->p1dv);
  pdbRecordType->papFldDes[116]->offset=(short)((char *)&prec->p1dv - (char *)prec);
  pdbRecordType->papFldDes[117]->size=sizeof(prec->p1lv);
  pdbRecordType->papFldDes[117]->offset=(short)((char *)&prec->p1lv - (char *)prec);
  pdbRecordType->papFldDes[118]->size=sizeof(prec->p1sp);
  pdbRecordType->papFldDes[118]->offset=(short)((char *)&prec->p1sp - (char *)prec);
  pdbRecordType->papFldDes[119]->size=sizeof(prec->p1si);
  pdbRecordType->papFldDes[119]->offset=(short)((char *)&prec->p1si - (char *)prec);
  pdbRecordType->papFldDes[120]->size=sizeof(prec->p1ep);
  pdbRecordType->papFldDes[120]->offset=(short)((char *)&prec->p1ep - (char *)prec);
  pdbRecordType->papFldDes[121]->size=sizeof(prec->p1cp);
  pdbRecordType->papFldDes[121]->offset=(short)((char *)&prec->p1cp - (char *)prec);
  pdbRecordType->papFldDes[122]->size=sizeof(prec->p1wd);
  pdbRecordType->papFldDes[122]->offset=(short)((char *)&prec->p1wd - (char *)prec);
  pdbRecordType->papFldDes[123]->size=sizeof(prec->r1cv);
  pdbRecordType->papFldDes[123]->offset=(short)((char *)&prec->r1cv - (char *)prec);
  pdbRecordType->papFldDes[124]->size=sizeof(prec->r1lv);
  pdbRecordType->papFldDes[124]->offset=(short)((char *)&prec->r1lv - (char *)prec);
  pdbRecordType->papFldDes[125]->size=sizeof(prec->r1dl);
  pdbRecordType->papFldDes[125]->offset=(short)((char *)&prec->r1dl - (char *)prec);
  pdbRecordType->papFldDes[126]->size=sizeof(prec->p1hr);
  pdbRecordType->papFldDes[126]->offset=(short)((char *)&prec->p1hr - (char *)prec);
  pdbRecordType->papFldDes[127]->size=sizeof(prec->p1lr);
  pdbRecordType->papFldDes[127]->offset=(short)((char *)&prec->p1lr - (char *)prec);
  pdbRecordType->papFldDes[128]->size=sizeof(prec->p1pa);
  pdbRecordType->papFldDes[128]->offset=(short)((char *)&prec->p1pa - (char *)prec);
  pdbRecordType->papFldDes[129]->size=sizeof(prec->p1ra);
  pdbRecordType->papFldDes[129]->offset=(short)((char *)&prec->p1ra - (char *)prec);
  pdbRecordType->papFldDes[130]->size=sizeof(prec->p1fs);
  pdbRecordType->papFldDes[130]->offset=(short)((char *)&prec->p1fs - (char *)prec);
  pdbRecordType->papFldDes[131]->size=sizeof(prec->p1fi);
  pdbRecordType->papFldDes[131]->offset=(short)((char *)&prec->p1fi - (char *)prec);
  pdbRecordType->papFldDes[132]->size=sizeof(prec->p1fe);
  pdbRecordType->papFldDes[132]->offset=(short)((char *)&prec->p1fe - (char *)prec);
  pdbRecordType->papFldDes[133]->size=sizeof(prec->p1fc);
  pdbRecordType->papFldDes[133]->offset=(short)((char *)&prec->p1fc - (char *)prec);
  pdbRecordType->papFldDes[134]->size=sizeof(prec->p1fw);
  pdbRecordType->papFldDes[134]->offset=(short)((char *)&prec->p1fw - (char *)prec);
  pdbRecordType->papFldDes[135]->size=sizeof(prec->p1sm);
  pdbRecordType->papFldDes[135]->offset=(short)((char *)&prec->p1sm - (char *)prec);
  pdbRecordType->papFldDes[136]->size=sizeof(prec->p1ar);
  pdbRecordType->papFldDes[136]->offset=(short)((char *)&prec->p1ar - (char *)prec);
  pdbRecordType->papFldDes[137]->size=sizeof(prec->p1eu);
  pdbRecordType->papFldDes[137]->offset=(short)((char *)&prec->p1eu - (char *)prec);
  pdbRecordType->papFldDes[138]->size=sizeof(prec->p1pr);
  pdbRecordType->papFldDes[138]->offset=(short)((char *)&prec->p1pr - (char *)prec);
  pdbRecordType->papFldDes[139]->size=sizeof(prec->p2pp);
  pdbRecordType->papFldDes[139]->offset=(short)((char *)&prec->p2pp - (char *)prec);
  pdbRecordType->papFldDes[140]->size=sizeof(prec->p2cv);
  pdbRecordType->papFldDes[140]->offset=(short)((char *)&prec->p2cv - (char *)prec);
  pdbRecordType->papFldDes[141]->size=sizeof(prec->p2dv);
  pdbRecordType->papFldDes[141]->offset=(short)((char *)&prec->p2dv - (char *)prec);
  pdbRecordType->papFldDes[142]->size=sizeof(prec->p2lv);
  pdbRecordType->papFldDes[142]->offset=(short)((char *)&prec->p2lv - (char *)prec);
  pdbRecordType->papFldDes[143]->size=sizeof(prec->p2sp);
  pdbRecordType->papFldDes[143]->offset=(short)((char *)&prec->p2sp - (char *)prec);
  pdbRecordType->papFldDes[144]->size=sizeof(prec->p2si);
  pdbRecordType->papFldDes[144]->offset=(short)((char *)&prec->p2si - (char *)prec);
  pdbRecordType->papFldDes[145]->size=sizeof(prec->p2ep);
  pdbRecordType->papFldDes[145]->offset=(short)((char *)&prec->p2ep - (char *)prec);
  pdbRecordType->papFldDes[146]->size=sizeof(prec->p2cp);
  pdbRecordType->papFldDes[146]->offset=(short)((char *)&prec->p2cp - (char *)prec);
  pdbRecordType->papFldDes[147]->size=sizeof(prec->p2wd);
  pdbRecordType->papFldDes[147]->offset=(short)((char *)&prec->p2wd - (char *)prec);
  pdbRecordType->papFldDes[148]->size=sizeof(prec->r2cv);
  pdbRecordType->papFldDes[148]->offset=(short)((char *)&prec->r2cv - (char *)prec);
  pdbRecordType->papFldDes[149]->size=sizeof(prec->r2lv);
  pdbRecordType->papFldDes[149]->offset=(short)((char *)&prec->r2lv - (char *)prec);
  pdbRecordType->papFldDes[150]->size=sizeof(prec->r2dl);
  pdbRecordType->papFldDes[150]->offset=(short)((char *)&prec->r2dl - (char *)prec);
  pdbRecordType->papFldDes[151]->size=sizeof(prec->p2hr);
  pdbRecordType->papFldDes[151]->offset=(short)((char *)&prec->p2hr - (char *)prec);
  pdbRecordType->papFldDes[152]->size=sizeof(prec->p2lr);
  pdbRecordType->papFldDes[152]->offset=(short)((char *)&prec->p2lr - (char *)prec);
  pdbRecordType->papFldDes[153]->size=sizeof(prec->p2pa);
  pdbRecordType->papFldDes[153]->offset=(short)((char *)&prec->p2pa - (char *)prec);
  pdbRecordType->papFldDes[154]->size=sizeof(prec->p2ra);
  pdbRecordType->papFldDes[154]->offset=(short)((char *)&prec->p2ra - (char *)prec);
  pdbRecordType->papFldDes[155]->size=sizeof(prec->p2fs);
  pdbRecordType->papFldDes[155]->offset=(short)((char *)&prec->p2fs - (char *)prec);
  pdbRecordType->papFldDes[156]->size=sizeof(prec->p2fi);
  pdbRecordType->papFldDes[156]->offset=(short)((char *)&prec->p2fi - (char *)prec);
  pdbRecordType->papFldDes[157]->size=sizeof(prec->p2fe);
  pdbRecordType->papFldDes[157]->offset=(short)((char *)&prec->p2fe - (char *)prec);
  pdbRecordType->papFldDes[158]->size=sizeof(prec->p2fc);
  pdbRecordType->papFldDes[158]->offset=(short)((char *)&prec->p2fc - (char *)prec);
  pdbRecordType->papFldDes[159]->size=sizeof(prec->p2fw);
  pdbRecordType->papFldDes[159]->offset=(short)((char *)&prec->p2fw - (char *)prec);
  pdbRecordType->papFldDes[160]->size=sizeof(prec->p2sm);
  pdbRecordType->papFldDes[160]->offset=(short)((char *)&prec->p2sm - (char *)prec);
  pdbRecordType->papFldDes[161]->size=sizeof(prec->p2ar);
  pdbRecordType->papFldDes[161]->offset=(short)((char *)&prec->p2ar - (char *)prec);
  pdbRecordType->papFldDes[162]->size=sizeof(prec->p2eu);
  pdbRecordType->papFldDes[162]->offset=(short)((char *)&prec->p2eu - (char *)prec);
  pdbRecordType->papFldDes[163]->size=sizeof(prec->p2pr);
  pdbRecordType->papFldDes[163]->offset=(short)((char *)&prec->p2pr - (char *)prec);
  pdbRecordType->papFldDes[164]->size=sizeof(prec->p3pp);
  pdbRecordType->papFldDes[164]->offset=(short)((char *)&prec->p3pp - (char *)prec);
  pdbRecordType->papFldDes[165]->size=sizeof(prec->p3cv);
  pdbRecordType->papFldDes[165]->offset=(short)((char *)&prec->p3cv - (char *)prec);
  pdbRecordType->papFldDes[166]->size=sizeof(prec->p3dv);
  pdbRecordType->papFldDes[166]->offset=(short)((char *)&prec->p3dv - (char *)prec);
  pdbRecordType->papFldDes[167]->size=sizeof(prec->p3lv);
  pdbRecordType->papFldDes[167]->offset=(short)((char *)&prec->p3lv - (char *)prec);
  pdbRecordType->papFldDes[168]->size=sizeof(prec->p3sp);
  pdbRecordType->papFldDes[168]->offset=(short)((char *)&prec->p3sp - (char *)prec);
  pdbRecordType->papFldDes[169]->size=sizeof(prec->p3si);
  pdbRecordType->papFldDes[169]->offset=(short)((char *)&prec->p3si - (char *)prec);
  pdbRecordType->papFldDes[170]->size=sizeof(prec->p3ep);
  pdbRecordType->papFldDes[170]->offset=(short)((char *)&prec->p3ep - (char *)prec);
  pdbRecordType->papFldDes[171]->size=sizeof(prec->p3cp);
  pdbRecordType->papFldDes[171]->offset=(short)((char *)&prec->p3cp - (char *)prec);
  pdbRecordType->papFldDes[172]->size=sizeof(prec->p3wd);
  pdbRecordType->papFldDes[172]->offset=(short)((char *)&prec->p3wd - (char *)prec);
  pdbRecordType->papFldDes[173]->size=sizeof(prec->r3cv);
  pdbRecordType->papFldDes[173]->offset=(short)((char *)&prec->r3cv - (char *)prec);
  pdbRecordType->papFldDes[174]->size=sizeof(prec->r3lv);
  pdbRecordType->papFldDes[174]->offset=(short)((char *)&prec->r3lv - (char *)prec);
  pdbRecordType->papFldDes[175]->size=sizeof(prec->r3dl);
  pdbRecordType->papFldDes[175]->offset=(short)((char *)&prec->r3dl - (char *)prec);
  pdbRecordType->papFldDes[176]->size=sizeof(prec->p3hr);
  pdbRecordType->papFldDes[176]->offset=(short)((char *)&prec->p3hr - (char *)prec);
  pdbRecordType->papFldDes[177]->size=sizeof(prec->p3lr);
  pdbRecordType->papFldDes[177]->offset=(short)((char *)&prec->p3lr - (char *)prec);
  pdbRecordType->papFldDes[178]->size=sizeof(prec->p3pa);
  pdbRecordType->papFldDes[178]->offset=(short)((char *)&prec->p3pa - (char *)prec);
  pdbRecordType->papFldDes[179]->size=sizeof(prec->p3ra);
  pdbRecordType->papFldDes[179]->offset=(short)((char *)&prec->p3ra - (char *)prec);
  pdbRecordType->papFldDes[180]->size=sizeof(prec->p3fs);
  pdbRecordType->papFldDes[180]->offset=(short)((char *)&prec->p3fs - (char *)prec);
  pdbRecordType->papFldDes[181]->size=sizeof(prec->p3fi);
  pdbRecordType->papFldDes[181]->offset=(short)((char *)&prec->p3fi - (char *)prec);
  pdbRecordType->papFldDes[182]->size=sizeof(prec->p3fe);
  pdbRecordType->papFldDes[182]->offset=(short)((char *)&prec->p3fe - (char *)prec);
  pdbRecordType->papFldDes[183]->size=sizeof(prec->p3fc);
  pdbRecordType->papFldDes[183]->offset=(short)((char *)&prec->p3fc - (char *)prec);
  pdbRecordType->papFldDes[184]->size=sizeof(prec->p3fw);
  pdbRecordType->papFldDes[184]->offset=(short)((char *)&prec->p3fw - (char *)prec);
  pdbRecordType->papFldDes[185]->size=sizeof(prec->p3sm);
  pdbRecordType->papFldDes[185]->offset=(short)((char *)&prec->p3sm - (char *)prec);
  pdbRecordType->papFldDes[186]->size=sizeof(prec->p3ar);
  pdbRecordType->papFldDes[186]->offset=(short)((char *)&prec->p3ar - (char *)prec);
  pdbRecordType->papFldDes[187]->size=sizeof(prec->p3eu);
  pdbRecordType->papFldDes[187]->offset=(short)((char *)&prec->p3eu - (char *)prec);
  pdbRecordType->papFldDes[188]->size=sizeof(prec->p3pr);
  pdbRecordType->papFldDes[188]->offset=(short)((char *)&prec->p3pr - (char *)prec);
  pdbRecordType->papFldDes[189]->size=sizeof(prec->p4pp);
  pdbRecordType->papFldDes[189]->offset=(short)((char *)&prec->p4pp - (char *)prec);
  pdbRecordType->papFldDes[190]->size=sizeof(prec->p4cv);
  pdbRecordType->papFldDes[190]->offset=(short)((char *)&prec->p4cv - (char *)prec);
  pdbRecordType->papFldDes[191]->size=sizeof(prec->p4dv);
  pdbRecordType->papFldDes[191]->offset=(short)((char *)&prec->p4dv - (char *)prec);
  pdbRecordType->papFldDes[192]->size=sizeof(prec->p4lv);
  pdbRecordType->papFldDes[192]->offset=(short)((char *)&prec->p4lv - (char *)prec);
  pdbRecordType->papFldDes[193]->size=sizeof(prec->p4sp);
  pdbRecordType->papFldDes[193]->offset=(short)((char *)&prec->p4sp - (char *)prec);
  pdbRecordType->papFldDes[194]->size=sizeof(prec->p4si);
  pdbRecordType->papFldDes[194]->offset=(short)((char *)&prec->p4si - (char *)prec);
  pdbRecordType->papFldDes[195]->size=sizeof(prec->p4ep);
  pdbRecordType->papFldDes[195]->offset=(short)((char *)&prec->p4ep - (char *)prec);
  pdbRecordType->papFldDes[196]->size=sizeof(prec->p4cp);
  pdbRecordType->papFldDes[196]->offset=(short)((char *)&prec->p4cp - (char *)prec);
  pdbRecordType->papFldDes[197]->size=sizeof(prec->p4wd);
  pdbRecordType->papFldDes[197]->offset=(short)((char *)&prec->p4wd - (char *)prec);
  pdbRecordType->papFldDes[198]->size=sizeof(prec->r4cv);
  pdbRecordType->papFldDes[198]->offset=(short)((char *)&prec->r4cv - (char *)prec);
  pdbRecordType->papFldDes[199]->size=sizeof(prec->r4lv);
  pdbRecordType->papFldDes[199]->offset=(short)((char *)&prec->r4lv - (char *)prec);
  pdbRecordType->papFldDes[200]->size=sizeof(prec->r4dl);
  pdbRecordType->papFldDes[200]->offset=(short)((char *)&prec->r4dl - (char *)prec);
  pdbRecordType->papFldDes[201]->size=sizeof(prec->p4hr);
  pdbRecordType->papFldDes[201]->offset=(short)((char *)&prec->p4hr - (char *)prec);
  pdbRecordType->papFldDes[202]->size=sizeof(prec->p4lr);
  pdbRecordType->papFldDes[202]->offset=(short)((char *)&prec->p4lr - (char *)prec);
  pdbRecordType->papFldDes[203]->size=sizeof(prec->p4pa);
  pdbRecordType->papFldDes[203]->offset=(short)((char *)&prec->p4pa - (char *)prec);
  pdbRecordType->papFldDes[204]->size=sizeof(prec->p4ra);
  pdbRecordType->papFldDes[204]->offset=(short)((char *)&prec->p4ra - (char *)prec);
  pdbRecordType->papFldDes[205]->size=sizeof(prec->p4fs);
  pdbRecordType->papFldDes[205]->offset=(short)((char *)&prec->p4fs - (char *)prec);
  pdbRecordType->papFldDes[206]->size=sizeof(prec->p4fi);
  pdbRecordType->papFldDes[206]->offset=(short)((char *)&prec->p4fi - (char *)prec);
  pdbRecordType->papFldDes[207]->size=sizeof(prec->p4fe);
  pdbRecordType->papFldDes[207]->offset=(short)((char *)&prec->p4fe - (char *)prec);
  pdbRecordType->papFldDes[208]->size=sizeof(prec->p4fc);
  pdbRecordType->papFldDes[208]->offset=(short)((char *)&prec->p4fc - (char *)prec);
  pdbRecordType->papFldDes[209]->size=sizeof(prec->p4fw);
  pdbRecordType->papFldDes[209]->offset=(short)((char *)&prec->p4fw - (char *)prec);
  pdbRecordType->papFldDes[210]->size=sizeof(prec->p4sm);
  pdbRecordType->papFldDes[210]->offset=(short)((char *)&prec->p4sm - (char *)prec);
  pdbRecordType->papFldDes[211]->size=sizeof(prec->p4ar);
  pdbRecordType->papFldDes[211]->offset=(short)((char *)&prec->p4ar - (char *)prec);
  pdbRecordType->papFldDes[212]->size=sizeof(prec->p4eu);
  pdbRecordType->papFldDes[212]->offset=(short)((char *)&prec->p4eu - (char *)prec);
  pdbRecordType->papFldDes[213]->size=sizeof(prec->p4pr);
  pdbRecordType->papFldDes[213]->offset=(short)((char *)&prec->p4pr - (char *)prec);
  pdbRecordType->papFldDes[214]->size=sizeof(prec->d1hr);
  pdbRecordType->papFldDes[214]->offset=(short)((char *)&prec->d1hr - (char *)prec);
  pdbRecordType->papFldDes[215]->size=sizeof(prec->d1lr);
  pdbRecordType->papFldDes[215]->offset=(short)((char *)&prec->d1lr - (char *)prec);
  pdbRecordType->papFldDes[216]->size=sizeof(prec->d1da);
  pdbRecordType->papFldDes[216]->offset=(short)((char *)&prec->d1da - (char *)prec);
  pdbRecordType->papFldDes[217]->size=sizeof(prec->d1cv);
  pdbRecordType->papFldDes[217]->offset=(short)((char *)&prec->d1cv - (char *)prec);
  pdbRecordType->papFldDes[218]->size=sizeof(prec->d1lv);
  pdbRecordType->papFldDes[218]->offset=(short)((char *)&prec->d1lv - (char *)prec);
  pdbRecordType->papFldDes[219]->size=sizeof(prec->d1ne);
  pdbRecordType->papFldDes[219]->offset=(short)((char *)&prec->d1ne - (char *)prec);
  pdbRecordType->papFldDes[220]->size=sizeof(prec->d1eu);
  pdbRecordType->papFldDes[220]->offset=(short)((char *)&prec->d1eu - (char *)prec);
  pdbRecordType->papFldDes[221]->size=sizeof(prec->d1pr);
  pdbRecordType->papFldDes[221]->offset=(short)((char *)&prec->d1pr - (char *)prec);
  pdbRecordType->papFldDes[222]->size=sizeof(prec->d2hr);
  pdbRecordType->papFldDes[222]->offset=(short)((char *)&prec->d2hr - (char *)prec);
  pdbRecordType->papFldDes[223]->size=sizeof(prec->d2lr);
  pdbRecordType->papFldDes[223]->offset=(short)((char *)&prec->d2lr - (char *)prec);
  pdbRecordType->papFldDes[224]->size=sizeof(prec->d2da);
  pdbRecordType->papFldDes[224]->offset=(short)((char *)&prec->d2da - (char *)prec);
  pdbRecordType->papFldDes[225]->size=sizeof(prec->d2cv);
  pdbRecordType->papFldDes[225]->offset=(short)((char *)&prec->d2cv - (char *)prec);
  pdbRecordType->papFldDes[226]->size=sizeof(prec->d2lv);
  pdbRecordType->papFldDes[226]->offset=(short)((char *)&prec->d2lv - (char *)prec);
  pdbRecordType->papFldDes[227]->size=sizeof(prec->d2ne);
  pdbRecordType->papFldDes[227]->offset=(short)((char *)&prec->d2ne - (char *)prec);
  pdbRecordType->papFldDes[228]->size=sizeof(prec->d2eu);
  pdbRecordType->papFldDes[228]->offset=(short)((char *)&prec->d2eu - (char *)prec);
  pdbRecordType->papFldDes[229]->size=sizeof(prec->d2pr);
  pdbRecordType->papFldDes[229]->offset=(short)((char *)&prec->d2pr - (char *)prec);
  pdbRecordType->papFldDes[230]->size=sizeof(prec->d3hr);
  pdbRecordType->papFldDes[230]->offset=(short)((char *)&prec->d3hr - (char *)prec);
  pdbRecordType->papFldDes[231]->size=sizeof(prec->d3lr);
  pdbRecordType->papFldDes[231]->offset=(short)((char *)&prec->d3lr - (char *)prec);
  pdbRecordType->papFldDes[232]->size=sizeof(prec->d3da);
  pdbRecordType->papFldDes[232]->offset=(short)((char *)&prec->d3da - (char *)prec);
  pdbRecordType->papFldDes[233]->size=sizeof(prec->d3cv);
  pdbRecordType->papFldDes[233]->offset=(short)((char *)&prec->d3cv - (char *)prec);
  pdbRecordType->papFldDes[234]->size=sizeof(prec->d3lv);
  pdbRecordType->papFldDes[234]->offset=(short)((char *)&prec->d3lv - (char *)prec);
  pdbRecordType->papFldDes[235]->size=sizeof(prec->d3ne);
  pdbRecordType->papFldDes[235]->offset=(short)((char *)&prec->d3ne - (char *)prec);
  pdbRecordType->papFldDes[236]->size=sizeof(prec->d3eu);
  pdbRecordType->papFldDes[236]->offset=(short)((char *)&prec->d3eu - (char *)prec);
  pdbRecordType->papFldDes[237]->size=sizeof(prec->d3pr);
  pdbRecordType->papFldDes[237]->offset=(short)((char *)&prec->d3pr - (char *)prec);
  pdbRecordType->papFldDes[238]->size=sizeof(prec->d4hr);
  pdbRecordType->papFldDes[238]->offset=(short)((char *)&prec->d4hr - (char *)prec);
  pdbRecordType->papFldDes[239]->size=sizeof(prec->d4lr);
  pdbRecordType->papFldDes[239]->offset=(short)((char *)&prec->d4lr - (char *)prec);
  pdbRecordType->papFldDes[240]->size=sizeof(prec->d4da);
  pdbRecordType->papFldDes[240]->offset=(short)((char *)&prec->d4da - (char *)prec);
  pdbRecordType->papFldDes[241]->size=sizeof(prec->d4cv);
  pdbRecordType->papFldDes[241]->offset=(short)((char *)&prec->d4cv - (char *)prec);
  pdbRecordType->papFldDes[242]->size=sizeof(prec->d4lv);
  pdbRecordType->papFldDes[242]->offset=(short)((char *)&prec->d4lv - (char *)prec);
  pdbRecordType->papFldDes[243]->size=sizeof(prec->d4ne);
  pdbRecordType->papFldDes[243]->offset=(short)((char *)&prec->d4ne - (char *)prec);
  pdbRecordType->papFldDes[244]->size=sizeof(prec->d4eu);
  pdbRecordType->papFldDes[244]->offset=(short)((char *)&prec->d4eu - (char *)prec);
  pdbRecordType->papFldDes[245]->size=sizeof(prec->d4pr);
  pdbRecordType->papFldDes[245]->offset=(short)((char *)&prec->d4pr - (char *)prec);
  pdbRecordType->papFldDes[246]->size=sizeof(prec->d5hr);
  pdbRecordType->papFldDes[246]->offset=(short)((char *)&prec->d5hr - (char *)prec);
  pdbRecordType->papFldDes[247]->size=sizeof(prec->d5lr);
  pdbRecordType->papFldDes[247]->offset=(short)((char *)&prec->d5lr - (char *)prec);
  pdbRecordType->papFldDes[248]->size=sizeof(prec->d5da);
  pdbRecordType->papFldDes[248]->offset=(short)((char *)&prec->d5da - (char *)prec);
  pdbRecordType->papFldDes[249]->size=sizeof(prec->d5cv);
  pdbRecordType->papFldDes[249]->offset=(short)((char *)&prec->d5cv - (char *)prec);
  pdbRecordType->papFldDes[250]->size=sizeof(prec->d5lv);
  pdbRecordType->papFldDes[250]->offset=(short)((char *)&prec->d5lv - (char *)prec);
  pdbRecordType->papFldDes[251]->size=sizeof(prec->d5ne);
  pdbRecordType->papFldDes[251]->offset=(short)((char *)&prec->d5ne - (char *)prec);
  pdbRecordType->papFldDes[252]->size=sizeof(prec->d5eu);
  pdbRecordType->papFldDes[252]->offset=(short)((char *)&prec->d5eu - (char *)prec);
  pdbRecordType->papFldDes[253]->size=sizeof(prec->d5pr);
  pdbRecordType->papFldDes[253]->offset=(short)((char *)&prec->d5pr - (char *)prec);
  pdbRecordType->papFldDes[254]->size=sizeof(prec->d6hr);
  pdbRecordType->papFldDes[254]->offset=(short)((char *)&prec->d6hr - (char *)prec);
  pdbRecordType->papFldDes[255]->size=sizeof(prec->d6lr);
  pdbRecordType->papFldDes[255]->offset=(short)((char *)&prec->d6lr - (char *)prec);
  pdbRecordType->papFldDes[256]->size=sizeof(prec->d6da);
  pdbRecordType->papFldDes[256]->offset=(short)((char *)&prec->d6da - (char *)prec);
  pdbRecordType->papFldDes[257]->size=sizeof(prec->d6cv);
  pdbRecordType->papFldDes[257]->offset=(short)((char *)&prec->d6cv - (char *)prec);
  pdbRecordType->papFldDes[258]->size=sizeof(prec->d6lv);
  pdbRecordType->papFldDes[258]->offset=(short)((char *)&prec->d6lv - (char *)prec);
  pdbRecordType->papFldDes[259]->size=sizeof(prec->d6ne);
  pdbRecordType->papFldDes[259]->offset=(short)((char *)&prec->d6ne - (char *)prec);
  pdbRecordType->papFldDes[260]->size=sizeof(prec->d6eu);
  pdbRecordType->papFldDes[260]->offset=(short)((char *)&prec->d6eu - (char *)prec);
  pdbRecordType->papFldDes[261]->size=sizeof(prec->d6pr);
  pdbRecordType->papFldDes[261]->offset=(short)((char *)&prec->d6pr - (char *)prec);
  pdbRecordType->papFldDes[262]->size=sizeof(prec->d7hr);
  pdbRecordType->papFldDes[262]->offset=(short)((char *)&prec->d7hr - (char *)prec);
  pdbRecordType->papFldDes[263]->size=sizeof(prec->d7lr);
  pdbRecordType->papFldDes[263]->offset=(short)((char *)&prec->d7lr - (char *)prec);
  pdbRecordType->papFldDes[264]->size=sizeof(prec->d7da);
  pdbRecordType->papFldDes[264]->offset=(short)((char *)&prec->d7da - (char *)prec);
  pdbRecordType->papFldDes[265]->size=sizeof(prec->d7cv);
  pdbRecordType->papFldDes[265]->offset=(short)((char *)&prec->d7cv - (char *)prec);
  pdbRecordType->papFldDes[266]->size=sizeof(prec->d7lv);
  pdbRecordType->papFldDes[266]->offset=(short)((char *)&prec->d7lv - (char *)prec);
  pdbRecordType->papFldDes[267]->size=sizeof(prec->d7ne);
  pdbRecordType->papFldDes[267]->offset=(short)((char *)&prec->d7ne - (char *)prec);
  pdbRecordType->papFldDes[268]->size=sizeof(prec->d7eu);
  pdbRecordType->papFldDes[268]->offset=(short)((char *)&prec->d7eu - (char *)prec);
  pdbRecordType->papFldDes[269]->size=sizeof(prec->d7pr);
  pdbRecordType->papFldDes[269]->offset=(short)((char *)&prec->d7pr - (char *)prec);
  pdbRecordType->papFldDes[270]->size=sizeof(prec->d8hr);
  pdbRecordType->papFldDes[270]->offset=(short)((char *)&prec->d8hr - (char *)prec);
  pdbRecordType->papFldDes[271]->size=sizeof(prec->d8lr);
  pdbRecordType->papFldDes[271]->offset=(short)((char *)&prec->d8lr - (char *)prec);
  pdbRecordType->papFldDes[272]->size=sizeof(prec->d8da);
  pdbRecordType->papFldDes[272]->offset=(short)((char *)&prec->d8da - (char *)prec);
  pdbRecordType->papFldDes[273]->size=sizeof(prec->d8cv);
  pdbRecordType->papFldDes[273]->offset=(short)((char *)&prec->d8cv - (char *)prec);
  pdbRecordType->papFldDes[274]->size=sizeof(prec->d8lv);
  pdbRecordType->papFldDes[274]->offset=(short)((char *)&prec->d8lv - (char *)prec);
  pdbRecordType->papFldDes[275]->size=sizeof(prec->d8ne);
  pdbRecordType->papFldDes[275]->offset=(short)((char *)&prec->d8ne - (char *)prec);
  pdbRecordType->papFldDes[276]->size=sizeof(prec->d8eu);
  pdbRecordType->papFldDes[276]->offset=(short)((char *)&prec->d8eu - (char *)prec);
  pdbRecordType->papFldDes[277]->size=sizeof(prec->d8pr);
  pdbRecordType->papFldDes[277]->offset=(short)((char *)&prec->d8pr - (char *)prec);
  pdbRecordType->papFldDes[278]->size=sizeof(prec->d9hr);
  pdbRecordType->papFldDes[278]->offset=(short)((char *)&prec->d9hr - (char *)prec);
  pdbRecordType->papFldDes[279]->size=sizeof(prec->d9lr);
  pdbRecordType->papFldDes[279]->offset=(short)((char *)&prec->d9lr - (char *)prec);
  pdbRecordType->papFldDes[280]->size=sizeof(prec->d9da);
  pdbRecordType->papFldDes[280]->offset=(short)((char *)&prec->d9da - (char *)prec);
  pdbRecordType->papFldDes[281]->size=sizeof(prec->d9cv);
  pdbRecordType->papFldDes[281]->offset=(short)((char *)&prec->d9cv - (char *)prec);
  pdbRecordType->papFldDes[282]->size=sizeof(prec->d9lv);
  pdbRecordType->papFldDes[282]->offset=(short)((char *)&prec->d9lv - (char *)prec);
  pdbRecordType->papFldDes[283]->size=sizeof(prec->d9ne);
  pdbRecordType->papFldDes[283]->offset=(short)((char *)&prec->d9ne - (char *)prec);
  pdbRecordType->papFldDes[284]->size=sizeof(prec->d9eu);
  pdbRecordType->papFldDes[284]->offset=(short)((char *)&prec->d9eu - (char *)prec);
  pdbRecordType->papFldDes[285]->size=sizeof(prec->d9pr);
  pdbRecordType->papFldDes[285]->offset=(short)((char *)&prec->d9pr - (char *)prec);
  pdbRecordType->papFldDes[286]->size=sizeof(prec->dahr);
  pdbRecordType->papFldDes[286]->offset=(short)((char *)&prec->dahr - (char *)prec);
  pdbRecordType->papFldDes[287]->size=sizeof(prec->dalr);
  pdbRecordType->papFldDes[287]->offset=(short)((char *)&prec->dalr - (char *)prec);
  pdbRecordType->papFldDes[288]->size=sizeof(prec->dada);
  pdbRecordType->papFldDes[288]->offset=(short)((char *)&prec->dada - (char *)prec);
  pdbRecordType->papFldDes[289]->size=sizeof(prec->dacv);
  pdbRecordType->papFldDes[289]->offset=(short)((char *)&prec->dacv - (char *)prec);
  pdbRecordType->papFldDes[290]->size=sizeof(prec->dalv);
  pdbRecordType->papFldDes[290]->offset=(short)((char *)&prec->dalv - (char *)prec);
  pdbRecordType->papFldDes[291]->size=sizeof(prec->dane);
  pdbRecordType->papFldDes[291]->offset=(short)((char *)&prec->dane - (char *)prec);
  pdbRecordType->papFldDes[292]->size=sizeof(prec->daeu);
  pdbRecordType->papFldDes[292]->offset=(short)((char *)&prec->daeu - (char *)prec);
  pdbRecordType->papFldDes[293]->size=sizeof(prec->dapr);
  pdbRecordType->papFldDes[293]->offset=(short)((char *)&prec->dapr - (char *)prec);
  pdbRecordType->papFldDes[294]->size=sizeof(prec->dbhr);
  pdbRecordType->papFldDes[294]->offset=(short)((char *)&prec->dbhr - (char *)prec);
  pdbRecordType->papFldDes[295]->size=sizeof(prec->dblr);
  pdbRecordType->papFldDes[295]->offset=(short)((char *)&prec->dblr - (char *)prec);
  pdbRecordType->papFldDes[296]->size=sizeof(prec->dbda);
  pdbRecordType->papFldDes[296]->offset=(short)((char *)&prec->dbda - (char *)prec);
  pdbRecordType->papFldDes[297]->size=sizeof(prec->dbcv);
  pdbRecordType->papFldDes[297]->offset=(short)((char *)&prec->dbcv - (char *)prec);
  pdbRecordType->papFldDes[298]->size=sizeof(prec->dblv);
  pdbRecordType->papFldDes[298]->offset=(short)((char *)&prec->dblv - (char *)prec);
  pdbRecordType->papFldDes[299]->size=sizeof(prec->dbne);
  pdbRecordType->papFldDes[299]->offset=(short)((char *)&prec->dbne - (char *)prec);
  pdbRecordType->papFldDes[300]->size=sizeof(prec->dbeu);
  pdbRecordType->papFldDes[300]->offset=(short)((char *)&prec->dbeu - (char *)prec);
  pdbRecordType->papFldDes[301]->size=sizeof(prec->dbpr);
  pdbRecordType->papFldDes[301]->offset=(short)((char *)&prec->dbpr - (char *)prec);
  pdbRecordType->papFldDes[302]->size=sizeof(prec->dchr);
  pdbRecordType->papFldDes[302]->offset=(short)((char *)&prec->dchr - (char *)prec);
  pdbRecordType->papFldDes[303]->size=sizeof(prec->dclr);
  pdbRecordType->papFldDes[303]->offset=(short)((char *)&prec->dclr - (char *)prec);
  pdbRecordType->papFldDes[304]->size=sizeof(prec->dcda);
  pdbRecordType->papFldDes[304]->offset=(short)((char *)&prec->dcda - (char *)prec);
  pdbRecordType->papFldDes[305]->size=sizeof(prec->dccv);
  pdbRecordType->papFldDes[305]->offset=(short)((char *)&prec->dccv - (char *)prec);
  pdbRecordType->papFldDes[306]->size=sizeof(prec->dclv);
  pdbRecordType->papFldDes[306]->offset=(short)((char *)&prec->dclv - (char *)prec);
  pdbRecordType->papFldDes[307]->size=sizeof(prec->dcne);
  pdbRecordType->papFldDes[307]->offset=(short)((char *)&prec->dcne - (char *)prec);
  pdbRecordType->papFldDes[308]->size=sizeof(prec->dceu);
  pdbRecordType->papFldDes[308]->offset=(short)((char *)&prec->dceu - (char *)prec);
  pdbRecordType->papFldDes[309]->size=sizeof(prec->dcpr);
  pdbRecordType->papFldDes[309]->offset=(short)((char *)&prec->dcpr - (char *)prec);
  pdbRecordType->papFldDes[310]->size=sizeof(prec->ddhr);
  pdbRecordType->papFldDes[310]->offset=(short)((char *)&prec->ddhr - (char *)prec);
  pdbRecordType->papFldDes[311]->size=sizeof(prec->ddlr);
  pdbRecordType->papFldDes[311]->offset=(short)((char *)&prec->ddlr - (char *)prec);
  pdbRecordType->papFldDes[312]->size=sizeof(prec->ddda);
  pdbRecordType->papFldDes[312]->offset=(short)((char *)&prec->ddda - (char *)prec);
  pdbRecordType->papFldDes[313]->size=sizeof(prec->ddcv);
  pdbRecordType->papFldDes[313]->offset=(short)((char *)&prec->ddcv - (char *)prec);
  pdbRecordType->papFldDes[314]->size=sizeof(prec->ddlv);
  pdbRecordType->papFldDes[314]->offset=(short)((char *)&prec->ddlv - (char *)prec);
  pdbRecordType->papFldDes[315]->size=sizeof(prec->ddne);
  pdbRecordType->papFldDes[315]->offset=(short)((char *)&prec->ddne - (char *)prec);
  pdbRecordType->papFldDes[316]->size=sizeof(prec->ddeu);
  pdbRecordType->papFldDes[316]->offset=(short)((char *)&prec->ddeu - (char *)prec);
  pdbRecordType->papFldDes[317]->size=sizeof(prec->ddpr);
  pdbRecordType->papFldDes[317]->offset=(short)((char *)&prec->ddpr - (char *)prec);
  pdbRecordType->papFldDes[318]->size=sizeof(prec->dehr);
  pdbRecordType->papFldDes[318]->offset=(short)((char *)&prec->dehr - (char *)prec);
  pdbRecordType->papFldDes[319]->size=sizeof(prec->delr);
  pdbRecordType->papFldDes[319]->offset=(short)((char *)&prec->delr - (char *)prec);
  pdbRecordType->papFldDes[320]->size=sizeof(prec->deda);
  pdbRecordType->papFldDes[320]->offset=(short)((char *)&prec->deda - (char *)prec);
  pdbRecordType->papFldDes[321]->size=sizeof(prec->decv);
  pdbRecordType->papFldDes[321]->offset=(short)((char *)&prec->decv - (char *)prec);
  pdbRecordType->papFldDes[322]->size=sizeof(prec->delv);
  pdbRecordType->papFldDes[322]->offset=(short)((char *)&prec->delv - (char *)prec);
  pdbRecordType->papFldDes[323]->size=sizeof(prec->dene);
  pdbRecordType->papFldDes[323]->offset=(short)((char *)&prec->dene - (char *)prec);
  pdbRecordType->papFldDes[324]->size=sizeof(prec->deeu);
  pdbRecordType->papFldDes[324]->offset=(short)((char *)&prec->deeu - (char *)prec);
  pdbRecordType->papFldDes[325]->size=sizeof(prec->depr);
  pdbRecordType->papFldDes[325]->offset=(short)((char *)&prec->depr - (char *)prec);
  pdbRecordType->papFldDes[326]->size=sizeof(prec->dfhr);
  pdbRecordType->papFldDes[326]->offset=(short)((char *)&prec->dfhr - (char *)prec);
  pdbRecordType->papFldDes[327]->size=sizeof(prec->dflr);
  pdbRecordType->papFldDes[327]->offset=(short)((char *)&prec->dflr - (char *)prec);
  pdbRecordType->papFldDes[328]->size=sizeof(prec->dfda);
  pdbRecordType->papFldDes[328]->offset=(short)((char *)&prec->dfda - (char *)prec);
  pdbRecordType->papFldDes[329]->size=sizeof(prec->dfcv);
  pdbRecordType->papFldDes[329]->offset=(short)((char *)&prec->dfcv - (char *)prec);
  pdbRecordType->papFldDes[330]->size=sizeof(prec->dflv);
  pdbRecordType->papFldDes[330]->offset=(short)((char *)&prec->dflv - (char *)prec);
  pdbRecordType->papFldDes[331]->size=sizeof(prec->dfne);
  pdbRecordType->papFldDes[331]->offset=(short)((char *)&prec->dfne - (char *)prec);
  pdbRecordType->papFldDes[332]->size=sizeof(prec->dfeu);
  pdbRecordType->papFldDes[332]->offset=(short)((char *)&prec->dfeu - (char *)prec);
  pdbRecordType->papFldDes[333]->size=sizeof(prec->dfpr);
  pdbRecordType->papFldDes[333]->offset=(short)((char *)&prec->dfpr - (char *)prec);
  pdbRecordType->papFldDes[334]->size=sizeof(prec->t1cd);
  pdbRecordType->papFldDes[334]->offset=(short)((char *)&prec->t1cd - (char *)prec);
  pdbRecordType->papFldDes[335]->size=sizeof(prec->t2cd);
  pdbRecordType->papFldDes[335]->offset=(short)((char *)&prec->t2cd - (char *)prec);
  pdbRecordType->papFldDes[336]->size=sizeof(prec->bscd);
  pdbRecordType->papFldDes[336]->offset=(short)((char *)&prec->bscd - (char *)prec);
  pdbRecordType->papFldDes[337]->size=sizeof(prec->ascd);
  pdbRecordType->papFldDes[337]->offset=(short)((char *)&prec->ascd - (char *)prec);
    pdbRecordType->rec_size = sizeof(*prec);
    return(0);
}
#endif /*GEN_SIZE_OFFSET*/
