#include <vxWorks.h>
#include <semLib.h>
#include "ellLib.h"
#include "fast_lock.h"
#include "link.h"
#include "tsDefs.h"

#ifndef INCsteppermotorMODEH
#define INCsteppermotorMODEH
typedef enum {
	steppermotorMODE_Velocity,
	steppermotorMODE_Position
}steppermotorMODE;
#endif /*INCsteppermotorMODEH*/

#ifndef INCsteppermotorIALGH
#define INCsteppermotorIALGH
typedef enum {
	steppermotorIALG_No_Initialization,
	steppermotorIALG_Move_to_the_Positive_Limit,
	steppermotorIALG_Move_to_the_Negative_Limit,
	steppermotorIALG_Move_to_Positive_Home,
	steppermotorIALG_Move_to_Negative_Home
}steppermotorIALG;
#endif /*INCsteppermotorIALGH*/
#ifndef INCsteppermotorH
#define INCsteppermotorH
typedef struct steppermotorRecord {
	char		name[29]; /*Record Name*/
	char		desc[29]; /*Descriptor*/
	char		asg[29]; /*Access Security Group*/
	unsigned short	scan;	/*Scan Mechanism*/
	unsigned short	pini;	/*Process at iocInit*/
	short		phas;	/*Scan Phase*/
	short		evnt;	/*Event Number*/
	short		tse;	/*Time Stamp Event*/
	DBLINK		tsel;	/*Time Stamp Link*/
	unsigned short	dtyp;	/*Device Type*/
	short		disv;	/*Disable Value*/
	short		disa;	/*Disable*/
	DBLINK		sdis;	/*Scanning Disable*/
	FAST_LOCK	mlok;	/*Monitor fastlock*/
	ELLLIST		mlis;	/*Monitor List*/
	unsigned char	disp;	/*Disable putField*/
	unsigned char	proc;	/*Force Processing*/
	unsigned short	stat;	/*Alarm Status*/
	unsigned short	sevr;	/*Alarm Severity*/
	unsigned short	nsta;	/*New Alarm Status*/
	unsigned short	nsev;	/*New Alarm Severity*/
	unsigned short	acks;	/*Alarm Ack Severity*/
	unsigned short	ackt;	/*Alarm Ack Transient*/
	unsigned short	diss;	/*Disable Alarm Sevrty*/
	unsigned char	lcnt;	/*Lock Count*/
	unsigned char	pact;	/*Record active*/
	unsigned char	putf;	/*dbPutField process*/
	unsigned char	rpro;	/*Reprocess */
	void		*asp;	/*Access Security Pvt*/
	void		*ppn;	/*addr of PUTNOTIFY*/
	void		*ppnn;	/*next record PUTNOTIFY*/
	void		*spvt;	/*Scan Private*/
	void		*rset;	/*Address of RSET*/
	struct dset	*dset;	/*DSET address*/
	void		*dpvt;	/*Device Private*/
	void		*rdes;	/*Address of dbRecordType*/
	void		*lset;	/*Lock Set*/
	unsigned short	prio;	/*Scheduling Priority*/
	unsigned char	tpro;	/*Trace Processing*/
	char bkpt;	/*Break Point*/
	unsigned char	udf;	/*Undefined*/
	TS_STAMP	time;	/*Time*/
	DBLINK		flnk;	/*Forward Process Link*/
	float		val;	/*Desired Value*/
	DBLINK		out;	/*Output Specification*/
	DBLINK		rdbl;	/*Readback Location*/
	DBLINK		dol;	/*Desired Output Loc*/
	unsigned short	omsl;	/*Output Mode Select*/
	float		accl;	/*Seconds to Velocity*/
	float		velo;	/*Velocity Rotation/Sec*/
	float		dist;	/*Dist of One Pulse*/
	float		ival;	/*Value at init*/
	unsigned short	mode;	/*Operating Mode*/
	unsigned short	cmod;	/*Current Operating Mode*/
	unsigned short	ialg;	/*Initialization Alg*/
	unsigned short	mres;	/*Motor Pulses/Revolution*/
	unsigned short	eres;	/*Encoder Pulses/Rev*/
	short		prec;	/*Display Precision*/
	char		egu[16]; /*Engineering Units*/
	float		drvh;	/*Drive High Limit*/
	float		drvl;	/*Drive Low Limit*/
	float		hopr;	/*High Operating Range*/
	float		lopr;	/*Low Operating Range*/
	float		hihi;	/*Hihi Alarm Limit*/
	float		lolo;	/*Lolo Alarm Limit*/
	float		high;	/*High Alarm Limit*/
	float		low;	/*Low Alarm Limit*/
	unsigned short	hhsv;	/*Hihi Severity*/
	unsigned short	llsv;	/*Lolo Severity*/
	unsigned short	hsv;	/*High Severity*/
	unsigned short	lsv;	/*Low Severity*/
	unsigned short	hlsv;	/*HW Limit Violation Svr*/
	float		mdel;	/*Monitor Deadband*/
	float		adel;	/*Archive Deadband*/
	float		rdbd;	/*Retry Deadband*/
	short		rtry;	/*Number of retries*/
	short		sthm;	/*Set Home*/
	short		stop;	/*Stop motor*/
	short		dmov;	/*Done moving to value*/
	long		rval;	/*Current Raw Value*/
	float		rbv;	/*Readback Value*/
	long		rrbv;	/*Raw Readback Value*/
	float		alst;	/*Last Value Archived*/
	float		mlst;	/*Last Value Monitored*/
	short		init;	/*Initialize*/
	short		mcw;	/*Mtr Clckws Lim*/
	short		mccw;	/*Mtr Cntr Clockwise Lmt*/
	short		cw;	/*Clockwise Limit*/
	short		ccw;	/*Counter Clockwise Lmt*/
	short		dir;	/*Direction of Travel*/
	short		movn;	/*Moving Status*/
	short		cvel;	/*Constant Velocity*/
	short		rcnt;	/*Retry count*/
	short		posm;	/*Positive motion*/
	float		lval;	/*Last Value*/
	float		epos;	/*Encoder position rdbck*/
	float		mpos;	/*Motor position rdbck*/
	float		miss;	/*First attemp error*/
	float		lvel;	/*Last Velocity set*/
	float		lacc;	/*Last acc set*/
} steppermotorRecord;
#define steppermotorRecordNAME	0
#define steppermotorRecordDESC	1
#define steppermotorRecordASG	2
#define steppermotorRecordSCAN	3
#define steppermotorRecordPINI	4
#define steppermotorRecordPHAS	5
#define steppermotorRecordEVNT	6
#define steppermotorRecordTSE	7
#define steppermotorRecordTSEL	8
#define steppermotorRecordDTYP	9
#define steppermotorRecordDISV	10
#define steppermotorRecordDISA	11
#define steppermotorRecordSDIS	12
#define steppermotorRecordMLOK	13
#define steppermotorRecordMLIS	14
#define steppermotorRecordDISP	15
#define steppermotorRecordPROC	16
#define steppermotorRecordSTAT	17
#define steppermotorRecordSEVR	18
#define steppermotorRecordNSTA	19
#define steppermotorRecordNSEV	20
#define steppermotorRecordACKS	21
#define steppermotorRecordACKT	22
#define steppermotorRecordDISS	23
#define steppermotorRecordLCNT	24
#define steppermotorRecordPACT	25
#define steppermotorRecordPUTF	26
#define steppermotorRecordRPRO	27
#define steppermotorRecordASP	28
#define steppermotorRecordPPN	29
#define steppermotorRecordPPNN	30
#define steppermotorRecordSPVT	31
#define steppermotorRecordRSET	32
#define steppermotorRecordDSET	33
#define steppermotorRecordDPVT	34
#define steppermotorRecordRDES	35
#define steppermotorRecordLSET	36
#define steppermotorRecordPRIO	37
#define steppermotorRecordTPRO	38
#define steppermotorRecordBKPT	39
#define steppermotorRecordUDF	40
#define steppermotorRecordTIME	41
#define steppermotorRecordFLNK	42
#define steppermotorRecordVAL	43
#define steppermotorRecordOUT	44
#define steppermotorRecordRDBL	45
#define steppermotorRecordDOL	46
#define steppermotorRecordOMSL	47
#define steppermotorRecordACCL	48
#define steppermotorRecordVELO	49
#define steppermotorRecordDIST	50
#define steppermotorRecordIVAL	51
#define steppermotorRecordMODE	52
#define steppermotorRecordCMOD	53
#define steppermotorRecordIALG	54
#define steppermotorRecordMRES	55
#define steppermotorRecordERES	56
#define steppermotorRecordPREC	57
#define steppermotorRecordEGU	58
#define steppermotorRecordDRVH	59
#define steppermotorRecordDRVL	60
#define steppermotorRecordHOPR	61
#define steppermotorRecordLOPR	62
#define steppermotorRecordHIHI	63
#define steppermotorRecordLOLO	64
#define steppermotorRecordHIGH	65
#define steppermotorRecordLOW	66
#define steppermotorRecordHHSV	67
#define steppermotorRecordLLSV	68
#define steppermotorRecordHSV	69
#define steppermotorRecordLSV	70
#define steppermotorRecordHLSV	71
#define steppermotorRecordMDEL	72
#define steppermotorRecordADEL	73
#define steppermotorRecordRDBD	74
#define steppermotorRecordRTRY	75
#define steppermotorRecordSTHM	76
#define steppermotorRecordSTOP	77
#define steppermotorRecordDMOV	78
#define steppermotorRecordRVAL	79
#define steppermotorRecordRBV	80
#define steppermotorRecordRRBV	81
#define steppermotorRecordALST	82
#define steppermotorRecordMLST	83
#define steppermotorRecordINIT	84
#define steppermotorRecordMCW	85
#define steppermotorRecordMCCW	86
#define steppermotorRecordCW	87
#define steppermotorRecordCCW	88
#define steppermotorRecordDIR	89
#define steppermotorRecordMOVN	90
#define steppermotorRecordCVEL	91
#define steppermotorRecordRCNT	92
#define steppermotorRecordPOSM	93
#define steppermotorRecordLVAL	94
#define steppermotorRecordEPOS	95
#define steppermotorRecordMPOS	96
#define steppermotorRecordMISS	97
#define steppermotorRecordLVEL	98
#define steppermotorRecordLACC	99
#endif /*INCsteppermotorH*/
#ifdef GEN_SIZE_OFFSET
int steppermotorRecordSizeOffset(dbRecordType *pdbRecordType)
{
    steppermotorRecord *prec = 0;
  pdbRecordType->papFldDes[0]->size=sizeof(prec->name);
  pdbRecordType->papFldDes[0]->offset=(short)((char *)&prec->name - (char *)prec);
  pdbRecordType->papFldDes[1]->size=sizeof(prec->desc);
  pdbRecordType->papFldDes[1]->offset=(short)((char *)&prec->desc - (char *)prec);
  pdbRecordType->papFldDes[2]->size=sizeof(prec->asg);
  pdbRecordType->papFldDes[2]->offset=(short)((char *)&prec->asg - (char *)prec);
  pdbRecordType->papFldDes[3]->size=sizeof(prec->scan);
  pdbRecordType->papFldDes[3]->offset=(short)((char *)&prec->scan - (char *)prec);
  pdbRecordType->papFldDes[4]->size=sizeof(prec->pini);
  pdbRecordType->papFldDes[4]->offset=(short)((char *)&prec->pini - (char *)prec);
  pdbRecordType->papFldDes[5]->size=sizeof(prec->phas);
  pdbRecordType->papFldDes[5]->offset=(short)((char *)&prec->phas - (char *)prec);
  pdbRecordType->papFldDes[6]->size=sizeof(prec->evnt);
  pdbRecordType->papFldDes[6]->offset=(short)((char *)&prec->evnt - (char *)prec);
  pdbRecordType->papFldDes[7]->size=sizeof(prec->tse);
  pdbRecordType->papFldDes[7]->offset=(short)((char *)&prec->tse - (char *)prec);
  pdbRecordType->papFldDes[8]->size=sizeof(prec->tsel);
  pdbRecordType->papFldDes[8]->offset=(short)((char *)&prec->tsel - (char *)prec);
  pdbRecordType->papFldDes[9]->size=sizeof(prec->dtyp);
  pdbRecordType->papFldDes[9]->offset=(short)((char *)&prec->dtyp - (char *)prec);
  pdbRecordType->papFldDes[10]->size=sizeof(prec->disv);
  pdbRecordType->papFldDes[10]->offset=(short)((char *)&prec->disv - (char *)prec);
  pdbRecordType->papFldDes[11]->size=sizeof(prec->disa);
  pdbRecordType->papFldDes[11]->offset=(short)((char *)&prec->disa - (char *)prec);
  pdbRecordType->papFldDes[12]->size=sizeof(prec->sdis);
  pdbRecordType->papFldDes[12]->offset=(short)((char *)&prec->sdis - (char *)prec);
  pdbRecordType->papFldDes[13]->size=sizeof(prec->mlok);
  pdbRecordType->papFldDes[13]->offset=(short)((char *)&prec->mlok - (char *)prec);
  pdbRecordType->papFldDes[14]->size=sizeof(prec->mlis);
  pdbRecordType->papFldDes[14]->offset=(short)((char *)&prec->mlis - (char *)prec);
  pdbRecordType->papFldDes[15]->size=sizeof(prec->disp);
  pdbRecordType->papFldDes[15]->offset=(short)((char *)&prec->disp - (char *)prec);
  pdbRecordType->papFldDes[16]->size=sizeof(prec->proc);
  pdbRecordType->papFldDes[16]->offset=(short)((char *)&prec->proc - (char *)prec);
  pdbRecordType->papFldDes[17]->size=sizeof(prec->stat);
  pdbRecordType->papFldDes[17]->offset=(short)((char *)&prec->stat - (char *)prec);
  pdbRecordType->papFldDes[18]->size=sizeof(prec->sevr);
  pdbRecordType->papFldDes[18]->offset=(short)((char *)&prec->sevr - (char *)prec);
  pdbRecordType->papFldDes[19]->size=sizeof(prec->nsta);
  pdbRecordType->papFldDes[19]->offset=(short)((char *)&prec->nsta - (char *)prec);
  pdbRecordType->papFldDes[20]->size=sizeof(prec->nsev);
  pdbRecordType->papFldDes[20]->offset=(short)((char *)&prec->nsev - (char *)prec);
  pdbRecordType->papFldDes[21]->size=sizeof(prec->acks);
  pdbRecordType->papFldDes[21]->offset=(short)((char *)&prec->acks - (char *)prec);
  pdbRecordType->papFldDes[22]->size=sizeof(prec->ackt);
  pdbRecordType->papFldDes[22]->offset=(short)((char *)&prec->ackt - (char *)prec);
  pdbRecordType->papFldDes[23]->size=sizeof(prec->diss);
  pdbRecordType->papFldDes[23]->offset=(short)((char *)&prec->diss - (char *)prec);
  pdbRecordType->papFldDes[24]->size=sizeof(prec->lcnt);
  pdbRecordType->papFldDes[24]->offset=(short)((char *)&prec->lcnt - (char *)prec);
  pdbRecordType->papFldDes[25]->size=sizeof(prec->pact);
  pdbRecordType->papFldDes[25]->offset=(short)((char *)&prec->pact - (char *)prec);
  pdbRecordType->papFldDes[26]->size=sizeof(prec->putf);
  pdbRecordType->papFldDes[26]->offset=(short)((char *)&prec->putf - (char *)prec);
  pdbRecordType->papFldDes[27]->size=sizeof(prec->rpro);
  pdbRecordType->papFldDes[27]->offset=(short)((char *)&prec->rpro - (char *)prec);
  pdbRecordType->papFldDes[28]->size=sizeof(prec->asp);
  pdbRecordType->papFldDes[28]->offset=(short)((char *)&prec->asp - (char *)prec);
  pdbRecordType->papFldDes[29]->size=sizeof(prec->ppn);
  pdbRecordType->papFldDes[29]->offset=(short)((char *)&prec->ppn - (char *)prec);
  pdbRecordType->papFldDes[30]->size=sizeof(prec->ppnn);
  pdbRecordType->papFldDes[30]->offset=(short)((char *)&prec->ppnn - (char *)prec);
  pdbRecordType->papFldDes[31]->size=sizeof(prec->spvt);
  pdbRecordType->papFldDes[31]->offset=(short)((char *)&prec->spvt - (char *)prec);
  pdbRecordType->papFldDes[32]->size=sizeof(prec->rset);
  pdbRecordType->papFldDes[32]->offset=(short)((char *)&prec->rset - (char *)prec);
  pdbRecordType->papFldDes[33]->size=sizeof(prec->dset);
  pdbRecordType->papFldDes[33]->offset=(short)((char *)&prec->dset - (char *)prec);
  pdbRecordType->papFldDes[34]->size=sizeof(prec->dpvt);
  pdbRecordType->papFldDes[34]->offset=(short)((char *)&prec->dpvt - (char *)prec);
  pdbRecordType->papFldDes[35]->size=sizeof(prec->rdes);
  pdbRecordType->papFldDes[35]->offset=(short)((char *)&prec->rdes - (char *)prec);
  pdbRecordType->papFldDes[36]->size=sizeof(prec->lset);
  pdbRecordType->papFldDes[36]->offset=(short)((char *)&prec->lset - (char *)prec);
  pdbRecordType->papFldDes[37]->size=sizeof(prec->prio);
  pdbRecordType->papFldDes[37]->offset=(short)((char *)&prec->prio - (char *)prec);
  pdbRecordType->papFldDes[38]->size=sizeof(prec->tpro);
  pdbRecordType->papFldDes[38]->offset=(short)((char *)&prec->tpro - (char *)prec);
  pdbRecordType->papFldDes[39]->size=sizeof(prec->bkpt);
  pdbRecordType->papFldDes[39]->offset=(short)((char *)&prec->bkpt - (char *)prec);
  pdbRecordType->papFldDes[40]->size=sizeof(prec->udf);
  pdbRecordType->papFldDes[40]->offset=(short)((char *)&prec->udf - (char *)prec);
  pdbRecordType->papFldDes[41]->size=sizeof(prec->time);
  pdbRecordType->papFldDes[41]->offset=(short)((char *)&prec->time - (char *)prec);
  pdbRecordType->papFldDes[42]->size=sizeof(prec->flnk);
  pdbRecordType->papFldDes[42]->offset=(short)((char *)&prec->flnk - (char *)prec);
  pdbRecordType->papFldDes[43]->size=sizeof(prec->val);
  pdbRecordType->papFldDes[43]->offset=(short)((char *)&prec->val - (char *)prec);
  pdbRecordType->papFldDes[44]->size=sizeof(prec->out);
  pdbRecordType->papFldDes[44]->offset=(short)((char *)&prec->out - (char *)prec);
  pdbRecordType->papFldDes[45]->size=sizeof(prec->rdbl);
  pdbRecordType->papFldDes[45]->offset=(short)((char *)&prec->rdbl - (char *)prec);
  pdbRecordType->papFldDes[46]->size=sizeof(prec->dol);
  pdbRecordType->papFldDes[46]->offset=(short)((char *)&prec->dol - (char *)prec);
  pdbRecordType->papFldDes[47]->size=sizeof(prec->omsl);
  pdbRecordType->papFldDes[47]->offset=(short)((char *)&prec->omsl - (char *)prec);
  pdbRecordType->papFldDes[48]->size=sizeof(prec->accl);
  pdbRecordType->papFldDes[48]->offset=(short)((char *)&prec->accl - (char *)prec);
  pdbRecordType->papFldDes[49]->size=sizeof(prec->velo);
  pdbRecordType->papFldDes[49]->offset=(short)((char *)&prec->velo - (char *)prec);
  pdbRecordType->papFldDes[50]->size=sizeof(prec->dist);
  pdbRecordType->papFldDes[50]->offset=(short)((char *)&prec->dist - (char *)prec);
  pdbRecordType->papFldDes[51]->size=sizeof(prec->ival);
  pdbRecordType->papFldDes[51]->offset=(short)((char *)&prec->ival - (char *)prec);
  pdbRecordType->papFldDes[52]->size=sizeof(prec->mode);
  pdbRecordType->papFldDes[52]->offset=(short)((char *)&prec->mode - (char *)prec);
  pdbRecordType->papFldDes[53]->size=sizeof(prec->cmod);
  pdbRecordType->papFldDes[53]->offset=(short)((char *)&prec->cmod - (char *)prec);
  pdbRecordType->papFldDes[54]->size=sizeof(prec->ialg);
  pdbRecordType->papFldDes[54]->offset=(short)((char *)&prec->ialg - (char *)prec);
  pdbRecordType->papFldDes[55]->size=sizeof(prec->mres);
  pdbRecordType->papFldDes[55]->offset=(short)((char *)&prec->mres - (char *)prec);
  pdbRecordType->papFldDes[56]->size=sizeof(prec->eres);
  pdbRecordType->papFldDes[56]->offset=(short)((char *)&prec->eres - (char *)prec);
  pdbRecordType->papFldDes[57]->size=sizeof(prec->prec);
  pdbRecordType->papFldDes[57]->offset=(short)((char *)&prec->prec - (char *)prec);
  pdbRecordType->papFldDes[58]->size=sizeof(prec->egu);
  pdbRecordType->papFldDes[58]->offset=(short)((char *)&prec->egu - (char *)prec);
  pdbRecordType->papFldDes[59]->size=sizeof(prec->drvh);
  pdbRecordType->papFldDes[59]->offset=(short)((char *)&prec->drvh - (char *)prec);
  pdbRecordType->papFldDes[60]->size=sizeof(prec->drvl);
  pdbRecordType->papFldDes[60]->offset=(short)((char *)&prec->drvl - (char *)prec);
  pdbRecordType->papFldDes[61]->size=sizeof(prec->hopr);
  pdbRecordType->papFldDes[61]->offset=(short)((char *)&prec->hopr - (char *)prec);
  pdbRecordType->papFldDes[62]->size=sizeof(prec->lopr);
  pdbRecordType->papFldDes[62]->offset=(short)((char *)&prec->lopr - (char *)prec);
  pdbRecordType->papFldDes[63]->size=sizeof(prec->hihi);
  pdbRecordType->papFldDes[63]->offset=(short)((char *)&prec->hihi - (char *)prec);
  pdbRecordType->papFldDes[64]->size=sizeof(prec->lolo);
  pdbRecordType->papFldDes[64]->offset=(short)((char *)&prec->lolo - (char *)prec);
  pdbRecordType->papFldDes[65]->size=sizeof(prec->high);
  pdbRecordType->papFldDes[65]->offset=(short)((char *)&prec->high - (char *)prec);
  pdbRecordType->papFldDes[66]->size=sizeof(prec->low);
  pdbRecordType->papFldDes[66]->offset=(short)((char *)&prec->low - (char *)prec);
  pdbRecordType->papFldDes[67]->size=sizeof(prec->hhsv);
  pdbRecordType->papFldDes[67]->offset=(short)((char *)&prec->hhsv - (char *)prec);
  pdbRecordType->papFldDes[68]->size=sizeof(prec->llsv);
  pdbRecordType->papFldDes[68]->offset=(short)((char *)&prec->llsv - (char *)prec);
  pdbRecordType->papFldDes[69]->size=sizeof(prec->hsv);
  pdbRecordType->papFldDes[69]->offset=(short)((char *)&prec->hsv - (char *)prec);
  pdbRecordType->papFldDes[70]->size=sizeof(prec->lsv);
  pdbRecordType->papFldDes[70]->offset=(short)((char *)&prec->lsv - (char *)prec);
  pdbRecordType->papFldDes[71]->size=sizeof(prec->hlsv);
  pdbRecordType->papFldDes[71]->offset=(short)((char *)&prec->hlsv - (char *)prec);
  pdbRecordType->papFldDes[72]->size=sizeof(prec->mdel);
  pdbRecordType->papFldDes[72]->offset=(short)((char *)&prec->mdel - (char *)prec);
  pdbRecordType->papFldDes[73]->size=sizeof(prec->adel);
  pdbRecordType->papFldDes[73]->offset=(short)((char *)&prec->adel - (char *)prec);
  pdbRecordType->papFldDes[74]->size=sizeof(prec->rdbd);
  pdbRecordType->papFldDes[74]->offset=(short)((char *)&prec->rdbd - (char *)prec);
  pdbRecordType->papFldDes[75]->size=sizeof(prec->rtry);
  pdbRecordType->papFldDes[75]->offset=(short)((char *)&prec->rtry - (char *)prec);
  pdbRecordType->papFldDes[76]->size=sizeof(prec->sthm);
  pdbRecordType->papFldDes[76]->offset=(short)((char *)&prec->sthm - (char *)prec);
  pdbRecordType->papFldDes[77]->size=sizeof(prec->stop);
  pdbRecordType->papFldDes[77]->offset=(short)((char *)&prec->stop - (char *)prec);
  pdbRecordType->papFldDes[78]->size=sizeof(prec->dmov);
  pdbRecordType->papFldDes[78]->offset=(short)((char *)&prec->dmov - (char *)prec);
  pdbRecordType->papFldDes[79]->size=sizeof(prec->rval);
  pdbRecordType->papFldDes[79]->offset=(short)((char *)&prec->rval - (char *)prec);
  pdbRecordType->papFldDes[80]->size=sizeof(prec->rbv);
  pdbRecordType->papFldDes[80]->offset=(short)((char *)&prec->rbv - (char *)prec);
  pdbRecordType->papFldDes[81]->size=sizeof(prec->rrbv);
  pdbRecordType->papFldDes[81]->offset=(short)((char *)&prec->rrbv - (char *)prec);
  pdbRecordType->papFldDes[82]->size=sizeof(prec->alst);
  pdbRecordType->papFldDes[82]->offset=(short)((char *)&prec->alst - (char *)prec);
  pdbRecordType->papFldDes[83]->size=sizeof(prec->mlst);
  pdbRecordType->papFldDes[83]->offset=(short)((char *)&prec->mlst - (char *)prec);
  pdbRecordType->papFldDes[84]->size=sizeof(prec->init);
  pdbRecordType->papFldDes[84]->offset=(short)((char *)&prec->init - (char *)prec);
  pdbRecordType->papFldDes[85]->size=sizeof(prec->mcw);
  pdbRecordType->papFldDes[85]->offset=(short)((char *)&prec->mcw - (char *)prec);
  pdbRecordType->papFldDes[86]->size=sizeof(prec->mccw);
  pdbRecordType->papFldDes[86]->offset=(short)((char *)&prec->mccw - (char *)prec);
  pdbRecordType->papFldDes[87]->size=sizeof(prec->cw);
  pdbRecordType->papFldDes[87]->offset=(short)((char *)&prec->cw - (char *)prec);
  pdbRecordType->papFldDes[88]->size=sizeof(prec->ccw);
  pdbRecordType->papFldDes[88]->offset=(short)((char *)&prec->ccw - (char *)prec);
  pdbRecordType->papFldDes[89]->size=sizeof(prec->dir);
  pdbRecordType->papFldDes[89]->offset=(short)((char *)&prec->dir - (char *)prec);
  pdbRecordType->papFldDes[90]->size=sizeof(prec->movn);
  pdbRecordType->papFldDes[90]->offset=(short)((char *)&prec->movn - (char *)prec);
  pdbRecordType->papFldDes[91]->size=sizeof(prec->cvel);
  pdbRecordType->papFldDes[91]->offset=(short)((char *)&prec->cvel - (char *)prec);
  pdbRecordType->papFldDes[92]->size=sizeof(prec->rcnt);
  pdbRecordType->papFldDes[92]->offset=(short)((char *)&prec->rcnt - (char *)prec);
  pdbRecordType->papFldDes[93]->size=sizeof(prec->posm);
  pdbRecordType->papFldDes[93]->offset=(short)((char *)&prec->posm - (char *)prec);
  pdbRecordType->papFldDes[94]->size=sizeof(prec->lval);
  pdbRecordType->papFldDes[94]->offset=(short)((char *)&prec->lval - (char *)prec);
  pdbRecordType->papFldDes[95]->size=sizeof(prec->epos);
  pdbRecordType->papFldDes[95]->offset=(short)((char *)&prec->epos - (char *)prec);
  pdbRecordType->papFldDes[96]->size=sizeof(prec->mpos);
  pdbRecordType->papFldDes[96]->offset=(short)((char *)&prec->mpos - (char *)prec);
  pdbRecordType->papFldDes[97]->size=sizeof(prec->miss);
  pdbRecordType->papFldDes[97]->offset=(short)((char *)&prec->miss - (char *)prec);
  pdbRecordType->papFldDes[98]->size=sizeof(prec->lvel);
  pdbRecordType->papFldDes[98]->offset=(short)((char *)&prec->lvel - (char *)prec);
  pdbRecordType->papFldDes[99]->size=sizeof(prec->lacc);
  pdbRecordType->papFldDes[99]->offset=(short)((char *)&prec->lacc - (char *)prec);
    pdbRecordType->rec_size = sizeof(*prec);
    return(0);
}
#endif /*GEN_SIZE_OFFSET*/
