#include <vxWorks.h>
#include <semLib.h>
#include "ellLib.h"
#include "fast_lock.h"
#include "link.h"
#include "tsDefs.h"

#ifndef INCtimerTSRCH
#define INCtimerTSRCH
typedef enum {
	timerTSRC_external,
	timerTSRC_internal
}timerTSRC;
#endif /*INCtimerTSRCH*/

#ifndef INCtimerTIMUH
#define INCtimerTIMUH
typedef enum {
	timerTIMU_milliseconds,
	timerTIMU_microseconds,
	timerTIMU_nanoseconds,
	timerTIMU_picoseconds
}timerTIMU;
#endif /*INCtimerTIMUH*/

#ifndef INCtimerPTSTH
#define INCtimerPTSTH
typedef enum {
	timerPTST_low,
	timerPTST_high
}timerPTST;
#endif /*INCtimerPTSTH*/
#ifndef INCtimerH
#define INCtimerH
typedef struct timerRecord {
	char		name[29]; /*Record Name*/
	char		desc[29]; /*Descriptor*/
	char		asg[29]; /*Access Security Group*/
	unsigned short	scan;	/*Scan Mechanism*/
	unsigned short	pini;	/*Process at iocInit*/
	short		phas;	/*Scan Phase*/
	short		evnt;	/*Event Number*/
	short		tse;	/*Time Stamp Event*/
	DBLINK		tsel;	/*Time Stamp Link*/
	unsigned short	dtyp;	/*Device Type*/
	short		disv;	/*Disable Value*/
	short		disa;	/*Disable*/
	DBLINK		sdis;	/*Scanning Disable*/
	FAST_LOCK	mlok;	/*Monitor fastlock*/
	ELLLIST		mlis;	/*Monitor List*/
	unsigned char	disp;	/*Disable putField*/
	unsigned char	proc;	/*Force Processing*/
	unsigned short	stat;	/*Alarm Status*/
	unsigned short	sevr;	/*Alarm Severity*/
	unsigned short	nsta;	/*New Alarm Status*/
	unsigned short	nsev;	/*New Alarm Severity*/
	unsigned short	acks;	/*Alarm Ack Severity*/
	unsigned short	ackt;	/*Alarm Ack Transient*/
	unsigned short	diss;	/*Disable Alarm Sevrty*/
	unsigned char	lcnt;	/*Lock Count*/
	unsigned char	pact;	/*Record active*/
	unsigned char	putf;	/*dbPutField process*/
	unsigned char	rpro;	/*Reprocess */
	void		*asp;	/*Access Security Pvt*/
	void		*ppn;	/*addr of PUTNOTIFY*/
	void		*ppnn;	/*next record PUTNOTIFY*/
	void		*spvt;	/*Scan Private*/
	void		*rset;	/*Address of RSET*/
	struct dset	*dset;	/*DSET address*/
	void		*dpvt;	/*Device Private*/
	void		*rdes;	/*Address of dbRecordType*/
	void		*lset;	/*Lock Set*/
	unsigned short	prio;	/*Scheduling Priority*/
	unsigned char	tpro;	/*Trace Processing*/
	char bkpt;	/*Break Point*/
	unsigned char	udf;	/*Undefined*/
	TS_STAMP	time;	/*Time*/
	DBLINK		flnk;	/*Forward Process Link*/
	DBLINK		torg;	/*Trigger Origin*/
	DBLINK		out;	/*Output Specification*/
	short		val;	/*Status*/
	unsigned short	tsrc;	/*Clock Source*/
	unsigned short	ptst;	/*Pre-Trigger State*/
	short		tevt;	/*Event on Trigger*/
	short		prec;	/*Display Precision*/
	unsigned short	timu;	/*Time Units*/
	unsigned short	main;	/*Maintain on reboot*/
	float		rdt1;	/*Reboot Delay of 1*/
	float		rpw1;	/*Reboot Width of 1*/
	float		pdly;	/*Delay Source to Inp*/
	float		dut1;	/*Delay Until Trigger 1*/
	float		opw1;	/*Output Pulse Width  1*/
	float		dut2;	/*Delay Until Trigger 2*/
	float		opw2;	/*Output Pulse Width  2*/
	float		dut3;	/*Delay Until Trigger 3*/
	float		opw3;	/*Output Pulse Width  3*/
	float		dut4;	/*Delay Until Trigger 4*/
	float		opw4;	/*Output Pulse Width  4*/
	float		dut5;	/*Delay Until Trigger 5*/
	float		opw5;	/*Output Pulse Width  5*/
	double		t1dl;	/*Delay for trigger 1*/
	double		t1wd;	/*Width of Trigger 1*/
	double		t2dl;	/*Delay for trigger 2*/
	double		t2wd;	/*Width of Trigger 2*/
	double		t3dl;	/*Delay for trigger 3*/
	double		t3wd;	/*Width of Trigger 3*/
	double		t4dl;	/*Delay for trigger 4*/
	double		t4wd;	/*Width of Trigger 4*/
	double		t5dl;	/*Delay for trigger 5*/
	double		t5wd;	/*Width of Trigger 5*/
	float		t1td;	/*Trailing Delay of 1*/
	float		t1ld;	/*Leading Delay of 1*/
	float		t2td;	/*Trailing Delay of 2*/
	float		t2ld;	/*Leading Delay of 2*/
	float		t3td;	/*Trailing Delay of 3*/
	float		t3ld;	/*Leading Delay of 3*/
	float		t4td;	/*Trailing Delay of 4*/
	float		t4ld;	/*Leading Delay of 4*/
	float		t5td;	/*Trailing Delay of 5*/
	float		t5ld;	/*Leading Delay of 5*/
	float		trdl;	/*Trigger Origin Delay*/
	short		tdis;	/*Timing Pulse Disable*/
} timerRecord;
#define timerRecordNAME	0
#define timerRecordDESC	1
#define timerRecordASG	2
#define timerRecordSCAN	3
#define timerRecordPINI	4
#define timerRecordPHAS	5
#define timerRecordEVNT	6
#define timerRecordTSE	7
#define timerRecordTSEL	8
#define timerRecordDTYP	9
#define timerRecordDISV	10
#define timerRecordDISA	11
#define timerRecordSDIS	12
#define timerRecordMLOK	13
#define timerRecordMLIS	14
#define timerRecordDISP	15
#define timerRecordPROC	16
#define timerRecordSTAT	17
#define timerRecordSEVR	18
#define timerRecordNSTA	19
#define timerRecordNSEV	20
#define timerRecordACKS	21
#define timerRecordACKT	22
#define timerRecordDISS	23
#define timerRecordLCNT	24
#define timerRecordPACT	25
#define timerRecordPUTF	26
#define timerRecordRPRO	27
#define timerRecordASP	28
#define timerRecordPPN	29
#define timerRecordPPNN	30
#define timerRecordSPVT	31
#define timerRecordRSET	32
#define timerRecordDSET	33
#define timerRecordDPVT	34
#define timerRecordRDES	35
#define timerRecordLSET	36
#define timerRecordPRIO	37
#define timerRecordTPRO	38
#define timerRecordBKPT	39
#define timerRecordUDF	40
#define timerRecordTIME	41
#define timerRecordFLNK	42
#define timerRecordTORG	43
#define timerRecordOUT	44
#define timerRecordVAL	45
#define timerRecordTSRC	46
#define timerRecordPTST	47
#define timerRecordTEVT	48
#define timerRecordPREC	49
#define timerRecordTIMU	50
#define timerRecordMAIN	51
#define timerRecordRDT1	52
#define timerRecordRPW1	53
#define timerRecordPDLY	54
#define timerRecordDUT1	55
#define timerRecordOPW1	56
#define timerRecordDUT2	57
#define timerRecordOPW2	58
#define timerRecordDUT3	59
#define timerRecordOPW3	60
#define timerRecordDUT4	61
#define timerRecordOPW4	62
#define timerRecordDUT5	63
#define timerRecordOPW5	64
#define timerRecordT1DL	65
#define timerRecordT1WD	66
#define timerRecordT2DL	67
#define timerRecordT2WD	68
#define timerRecordT3DL	69
#define timerRecordT3WD	70
#define timerRecordT4DL	71
#define timerRecordT4WD	72
#define timerRecordT5DL	73
#define timerRecordT5WD	74
#define timerRecordT1TD	75
#define timerRecordT1LD	76
#define timerRecordT2TD	77
#define timerRecordT2LD	78
#define timerRecordT3TD	79
#define timerRecordT3LD	80
#define timerRecordT4TD	81
#define timerRecordT4LD	82
#define timerRecordT5TD	83
#define timerRecordT5LD	84
#define timerRecordTRDL	85
#define timerRecordTDIS	86
#endif /*INCtimerH*/
#ifdef GEN_SIZE_OFFSET
int timerRecordSizeOffset(dbRecordType *pdbRecordType)
{
    timerRecord *prec = 0;
  pdbRecordType->papFldDes[0]->size=sizeof(prec->name);
  pdbRecordType->papFldDes[0]->offset=(short)((char *)&prec->name - (char *)prec);
  pdbRecordType->papFldDes[1]->size=sizeof(prec->desc);
  pdbRecordType->papFldDes[1]->offset=(short)((char *)&prec->desc - (char *)prec);
  pdbRecordType->papFldDes[2]->size=sizeof(prec->asg);
  pdbRecordType->papFldDes[2]->offset=(short)((char *)&prec->asg - (char *)prec);
  pdbRecordType->papFldDes[3]->size=sizeof(prec->scan);
  pdbRecordType->papFldDes[3]->offset=(short)((char *)&prec->scan - (char *)prec);
  pdbRecordType->papFldDes[4]->size=sizeof(prec->pini);
  pdbRecordType->papFldDes[4]->offset=(short)((char *)&prec->pini - (char *)prec);
  pdbRecordType->papFldDes[5]->size=sizeof(prec->phas);
  pdbRecordType->papFldDes[5]->offset=(short)((char *)&prec->phas - (char *)prec);
  pdbRecordType->papFldDes[6]->size=sizeof(prec->evnt);
  pdbRecordType->papFldDes[6]->offset=(short)((char *)&prec->evnt - (char *)prec);
  pdbRecordType->papFldDes[7]->size=sizeof(prec->tse);
  pdbRecordType->papFldDes[7]->offset=(short)((char *)&prec->tse - (char *)prec);
  pdbRecordType->papFldDes[8]->size=sizeof(prec->tsel);
  pdbRecordType->papFldDes[8]->offset=(short)((char *)&prec->tsel - (char *)prec);
  pdbRecordType->papFldDes[9]->size=sizeof(prec->dtyp);
  pdbRecordType->papFldDes[9]->offset=(short)((char *)&prec->dtyp - (char *)prec);
  pdbRecordType->papFldDes[10]->size=sizeof(prec->disv);
  pdbRecordType->papFldDes[10]->offset=(short)((char *)&prec->disv - (char *)prec);
  pdbRecordType->papFldDes[11]->size=sizeof(prec->disa);
  pdbRecordType->papFldDes[11]->offset=(short)((char *)&prec->disa - (char *)prec);
  pdbRecordType->papFldDes[12]->size=sizeof(prec->sdis);
  pdbRecordType->papFldDes[12]->offset=(short)((char *)&prec->sdis - (char *)prec);
  pdbRecordType->papFldDes[13]->size=sizeof(prec->mlok);
  pdbRecordType->papFldDes[13]->offset=(short)((char *)&prec->mlok - (char *)prec);
  pdbRecordType->papFldDes[14]->size=sizeof(prec->mlis);
  pdbRecordType->papFldDes[14]->offset=(short)((char *)&prec->mlis - (char *)prec);
  pdbRecordType->papFldDes[15]->size=sizeof(prec->disp);
  pdbRecordType->papFldDes[15]->offset=(short)((char *)&prec->disp - (char *)prec);
  pdbRecordType->papFldDes[16]->size=sizeof(prec->proc);
  pdbRecordType->papFldDes[16]->offset=(short)((char *)&prec->proc - (char *)prec);
  pdbRecordType->papFldDes[17]->size=sizeof(prec->stat);
  pdbRecordType->papFldDes[17]->offset=(short)((char *)&prec->stat - (char *)prec);
  pdbRecordType->papFldDes[18]->size=sizeof(prec->sevr);
  pdbRecordType->papFldDes[18]->offset=(short)((char *)&prec->sevr - (char *)prec);
  pdbRecordType->papFldDes[19]->size=sizeof(prec->nsta);
  pdbRecordType->papFldDes[19]->offset=(short)((char *)&prec->nsta - (char *)prec);
  pdbRecordType->papFldDes[20]->size=sizeof(prec->nsev);
  pdbRecordType->papFldDes[20]->offset=(short)((char *)&prec->nsev - (char *)prec);
  pdbRecordType->papFldDes[21]->size=sizeof(prec->acks);
  pdbRecordType->papFldDes[21]->offset=(short)((char *)&prec->acks - (char *)prec);
  pdbRecordType->papFldDes[22]->size=sizeof(prec->ackt);
  pdbRecordType->papFldDes[22]->offset=(short)((char *)&prec->ackt - (char *)prec);
  pdbRecordType->papFldDes[23]->size=sizeof(prec->diss);
  pdbRecordType->papFldDes[23]->offset=(short)((char *)&prec->diss - (char *)prec);
  pdbRecordType->papFldDes[24]->size=sizeof(prec->lcnt);
  pdbRecordType->papFldDes[24]->offset=(short)((char *)&prec->lcnt - (char *)prec);
  pdbRecordType->papFldDes[25]->size=sizeof(prec->pact);
  pdbRecordType->papFldDes[25]->offset=(short)((char *)&prec->pact - (char *)prec);
  pdbRecordType->papFldDes[26]->size=sizeof(prec->putf);
  pdbRecordType->papFldDes[26]->offset=(short)((char *)&prec->putf - (char *)prec);
  pdbRecordType->papFldDes[27]->size=sizeof(prec->rpro);
  pdbRecordType->papFldDes[27]->offset=(short)((char *)&prec->rpro - (char *)prec);
  pdbRecordType->papFldDes[28]->size=sizeof(prec->asp);
  pdbRecordType->papFldDes[28]->offset=(short)((char *)&prec->asp - (char *)prec);
  pdbRecordType->papFldDes[29]->size=sizeof(prec->ppn);
  pdbRecordType->papFldDes[29]->offset=(short)((char *)&prec->ppn - (char *)prec);
  pdbRecordType->papFldDes[30]->size=sizeof(prec->ppnn);
  pdbRecordType->papFldDes[30]->offset=(short)((char *)&prec->ppnn - (char *)prec);
  pdbRecordType->papFldDes[31]->size=sizeof(prec->spvt);
  pdbRecordType->papFldDes[31]->offset=(short)((char *)&prec->spvt - (char *)prec);
  pdbRecordType->papFldDes[32]->size=sizeof(prec->rset);
  pdbRecordType->papFldDes[32]->offset=(short)((char *)&prec->rset - (char *)prec);
  pdbRecordType->papFldDes[33]->size=sizeof(prec->dset);
  pdbRecordType->papFldDes[33]->offset=(short)((char *)&prec->dset - (char *)prec);
  pdbRecordType->papFldDes[34]->size=sizeof(prec->dpvt);
  pdbRecordType->papFldDes[34]->offset=(short)((char *)&prec->dpvt - (char *)prec);
  pdbRecordType->papFldDes[35]->size=sizeof(prec->rdes);
  pdbRecordType->papFldDes[35]->offset=(short)((char *)&prec->rdes - (char *)prec);
  pdbRecordType->papFldDes[36]->size=sizeof(prec->lset);
  pdbRecordType->papFldDes[36]->offset=(short)((char *)&prec->lset - (char *)prec);
  pdbRecordType->papFldDes[37]->size=sizeof(prec->prio);
  pdbRecordType->papFldDes[37]->offset=(short)((char *)&prec->prio - (char *)prec);
  pdbRecordType->papFldDes[38]->size=sizeof(prec->tpro);
  pdbRecordType->papFldDes[38]->offset=(short)((char *)&prec->tpro - (char *)prec);
  pdbRecordType->papFldDes[39]->size=sizeof(prec->bkpt);
  pdbRecordType->papFldDes[39]->offset=(short)((char *)&prec->bkpt - (char *)prec);
  pdbRecordType->papFldDes[40]->size=sizeof(prec->udf);
  pdbRecordType->papFldDes[40]->offset=(short)((char *)&prec->udf - (char *)prec);
  pdbRecordType->papFldDes[41]->size=sizeof(prec->time);
  pdbRecordType->papFldDes[41]->offset=(short)((char *)&prec->time - (char *)prec);
  pdbRecordType->papFldDes[42]->size=sizeof(prec->flnk);
  pdbRecordType->papFldDes[42]->offset=(short)((char *)&prec->flnk - (char *)prec);
  pdbRecordType->papFldDes[43]->size=sizeof(prec->torg);
  pdbRecordType->papFldDes[43]->offset=(short)((char *)&prec->torg - (char *)prec);
  pdbRecordType->papFldDes[44]->size=sizeof(prec->out);
  pdbRecordType->papFldDes[44]->offset=(short)((char *)&prec->out - (char *)prec);
  pdbRecordType->papFldDes[45]->size=sizeof(prec->val);
  pdbRecordType->papFldDes[45]->offset=(short)((char *)&prec->val - (char *)prec);
  pdbRecordType->papFldDes[46]->size=sizeof(prec->tsrc);
  pdbRecordType->papFldDes[46]->offset=(short)((char *)&prec->tsrc - (char *)prec);
  pdbRecordType->papFldDes[47]->size=sizeof(prec->ptst);
  pdbRecordType->papFldDes[47]->offset=(short)((char *)&prec->ptst - (char *)prec);
  pdbRecordType->papFldDes[48]->size=sizeof(prec->tevt);
  pdbRecordType->papFldDes[48]->offset=(short)((char *)&prec->tevt - (char *)prec);
  pdbRecordType->papFldDes[49]->size=sizeof(prec->prec);
  pdbRecordType->papFldDes[49]->offset=(short)((char *)&prec->prec - (char *)prec);
  pdbRecordType->papFldDes[50]->size=sizeof(prec->timu);
  pdbRecordType->papFldDes[50]->offset=(short)((char *)&prec->timu - (char *)prec);
  pdbRecordType->papFldDes[51]->size=sizeof(prec->main);
  pdbRecordType->papFldDes[51]->offset=(short)((char *)&prec->main - (char *)prec);
  pdbRecordType->papFldDes[52]->size=sizeof(prec->rdt1);
  pdbRecordType->papFldDes[52]->offset=(short)((char *)&prec->rdt1 - (char *)prec);
  pdbRecordType->papFldDes[53]->size=sizeof(prec->rpw1);
  pdbRecordType->papFldDes[53]->offset=(short)((char *)&prec->rpw1 - (char *)prec);
  pdbRecordType->papFldDes[54]->size=sizeof(prec->pdly);
  pdbRecordType->papFldDes[54]->offset=(short)((char *)&prec->pdly - (char *)prec);
  pdbRecordType->papFldDes[55]->size=sizeof(prec->dut1);
  pdbRecordType->papFldDes[55]->offset=(short)((char *)&prec->dut1 - (char *)prec);
  pdbRecordType->papFldDes[56]->size=sizeof(prec->opw1);
  pdbRecordType->papFldDes[56]->offset=(short)((char *)&prec->opw1 - (char *)prec);
  pdbRecordType->papFldDes[57]->size=sizeof(prec->dut2);
  pdbRecordType->papFldDes[57]->offset=(short)((char *)&prec->dut2 - (char *)prec);
  pdbRecordType->papFldDes[58]->size=sizeof(prec->opw2);
  pdbRecordType->papFldDes[58]->offset=(short)((char *)&prec->opw2 - (char *)prec);
  pdbRecordType->papFldDes[59]->size=sizeof(prec->dut3);
  pdbRecordType->papFldDes[59]->offset=(short)((char *)&prec->dut3 - (char *)prec);
  pdbRecordType->papFldDes[60]->size=sizeof(prec->opw3);
  pdbRecordType->papFldDes[60]->offset=(short)((char *)&prec->opw3 - (char *)prec);
  pdbRecordType->papFldDes[61]->size=sizeof(prec->dut4);
  pdbRecordType->papFldDes[61]->offset=(short)((char *)&prec->dut4 - (char *)prec);
  pdbRecordType->papFldDes[62]->size=sizeof(prec->opw4);
  pdbRecordType->papFldDes[62]->offset=(short)((char *)&prec->opw4 - (char *)prec);
  pdbRecordType->papFldDes[63]->size=sizeof(prec->dut5);
  pdbRecordType->papFldDes[63]->offset=(short)((char *)&prec->dut5 - (char *)prec);
  pdbRecordType->papFldDes[64]->size=sizeof(prec->opw5);
  pdbRecordType->papFldDes[64]->offset=(short)((char *)&prec->opw5 - (char *)prec);
  pdbRecordType->papFldDes[65]->size=sizeof(prec->t1dl);
  pdbRecordType->papFldDes[65]->offset=(short)((char *)&prec->t1dl - (char *)prec);
  pdbRecordType->papFldDes[66]->size=sizeof(prec->t1wd);
  pdbRecordType->papFldDes[66]->offset=(short)((char *)&prec->t1wd - (char *)prec);
  pdbRecordType->papFldDes[67]->size=sizeof(prec->t2dl);
  pdbRecordType->papFldDes[67]->offset=(short)((char *)&prec->t2dl - (char *)prec);
  pdbRecordType->papFldDes[68]->size=sizeof(prec->t2wd);
  pdbRecordType->papFldDes[68]->offset=(short)((char *)&prec->t2wd - (char *)prec);
  pdbRecordType->papFldDes[69]->size=sizeof(prec->t3dl);
  pdbRecordType->papFldDes[69]->offset=(short)((char *)&prec->t3dl - (char *)prec);
  pdbRecordType->papFldDes[70]->size=sizeof(prec->t3wd);
  pdbRecordType->papFldDes[70]->offset=(short)((char *)&prec->t3wd - (char *)prec);
  pdbRecordType->papFldDes[71]->size=sizeof(prec->t4dl);
  pdbRecordType->papFldDes[71]->offset=(short)((char *)&prec->t4dl - (char *)prec);
  pdbRecordType->papFldDes[72]->size=sizeof(prec->t4wd);
  pdbRecordType->papFldDes[72]->offset=(short)((char *)&prec->t4wd - (char *)prec);
  pdbRecordType->papFldDes[73]->size=sizeof(prec->t5dl);
  pdbRecordType->papFldDes[73]->offset=(short)((char *)&prec->t5dl - (char *)prec);
  pdbRecordType->papFldDes[74]->size=sizeof(prec->t5wd);
  pdbRecordType->papFldDes[74]->offset=(short)((char *)&prec->t5wd - (char *)prec);
  pdbRecordType->papFldDes[75]->size=sizeof(prec->t1td);
  pdbRecordType->papFldDes[75]->offset=(short)((char *)&prec->t1td - (char *)prec);
  pdbRecordType->papFldDes[76]->size=sizeof(prec->t1ld);
  pdbRecordType->papFldDes[76]->offset=(short)((char *)&prec->t1ld - (char *)prec);
  pdbRecordType->papFldDes[77]->size=sizeof(prec->t2td);
  pdbRecordType->papFldDes[77]->offset=(short)((char *)&prec->t2td - (char *)prec);
  pdbRecordType->papFldDes[78]->size=sizeof(prec->t2ld);
  pdbRecordType->papFldDes[78]->offset=(short)((char *)&prec->t2ld - (char *)prec);
  pdbRecordType->papFldDes[79]->size=sizeof(prec->t3td);
  pdbRecordType->papFldDes[79]->offset=(short)((char *)&prec->t3td - (char *)prec);
  pdbRecordType->papFldDes[80]->size=sizeof(prec->t3ld);
  pdbRecordType->papFldDes[80]->offset=(short)((char *)&prec->t3ld - (char *)prec);
  pdbRecordType->papFldDes[81]->size=sizeof(prec->t4td);
  pdbRecordType->papFldDes[81]->offset=(short)((char *)&prec->t4td - (char *)prec);
  pdbRecordType->papFldDes[82]->size=sizeof(prec->t4ld);
  pdbRecordType->papFldDes[82]->offset=(short)((char *)&prec->t4ld - (char *)prec);
  pdbRecordType->papFldDes[83]->size=sizeof(prec->t5td);
  pdbRecordType->papFldDes[83]->offset=(short)((char *)&prec->t5td - (char *)prec);
  pdbRecordType->papFldDes[84]->size=sizeof(prec->t5ld);
  pdbRecordType->papFldDes[84]->offset=(short)((char *)&prec->t5ld - (char *)prec);
  pdbRecordType->papFldDes[85]->size=sizeof(prec->trdl);
  pdbRecordType->papFldDes[85]->offset=(short)((char *)&prec->trdl - (char *)prec);
  pdbRecordType->papFldDes[86]->size=sizeof(prec->tdis);
  pdbRecordType->papFldDes[86]->offset=(short)((char *)&prec->tdis - (char *)prec);
    pdbRecordType->rec_size = sizeof(*prec);
    return(0);
}
#endif /*GEN_SIZE_OFFSET*/
